searchData={"items":[{"type":"module","doc":"This module contains top level functions and macros for Beaver DSL for MLIR.\n\n`use Beaver` will import and alias the essential modules and functions for Beaver'DSL for MLIR. It also imports the sigils used in the DSL.","title":"Beaver","ref":"Beaver.html"},{"type":"module","doc":"To create an MLIR operation and insert it to a block, you can use the `mlir` macro. Here is an example of creating a constant operation:\n    iex> use Beaver\n    iex> {ctx, blk} = {MLIR.Context.create(), MLIR.Block.create()}\n    iex> alias Beaver.MLIR.Dialect.Arith\n    iex> const = mlir ctx: ctx, blk: blk do\n    iex>   Arith.constant(value: ~a{64: i32}) >>> ~t{i32}\n    iex> end\n    iex> const |> MLIR.Value.owner!() |> MLIR.verify!()\n    iex> MLIR.Block.destroy(blk)\n    iex> MLIR.Context.destroy(ctx)","title":"Basic usage - Beaver","ref":"Beaver.html#module-basic-usage"},{"type":"module","doc":"There are some concepts in Elixir and MLIR shared the same name, so it is encouraged to use the following naming conventions for variables:\n- use `ctx` for MLIR context\n- use `blk` for MLIR block","title":"Naming conventions - Beaver","ref":"Beaver.html#module-naming-conventions"},{"type":"module","doc":"In Beaver, various functions and sigils might return a function with a signature like `MLIR.Context.t() -> MLIR.Type.t()`, if the context is not provided. When a creator gets passed to a SSA expression, it will be called with the context to create the entity or later the operation. Deferring the creation of the entity until context available is intended to keep the DSL code clean and succinct. For more information, see the docs of module `Beaver.Deferred`.","title":"Lazy creation of MLIR entities - Beaver","ref":"Beaver.html#module-lazy-creation-of-mlir-entities"},{"type":"function","doc":"Create an MLIR SSA expression with the given arguments and results.\n\nThe right hand of operator `>>>` is used to typing the result of the SSA or an argument of a block. It kind of works like the `::` in specs and types of Elixir.","title":"Beaver.>>>/2","ref":"Beaver.html#%3E%3E%3E/2"},{"type":"function","doc":"By default SSA expression will return the MLIR values or the operation created.\n- For op with multiple result: the results of this op in a list.\n- For op with one single result: the result\n- For op with no result: the op itself (for instance, module, func, and terminators)","title":"The return of SSA expression - Beaver.>>>/2","ref":"Beaver.html#%3E%3E%3E/2-the-return-of-ssa-expression"},{"type":"function","doc":"There are several ways to declare the result of an SSA expression. The most common cases are single result and multi-results.\n\n- Single result\n```\nres = Foo.bar(a, b) >>> res_t\n```\n- Multiple results\n```\n[res1, res2] = Foo.bar(a, b) >>> [res_t, res_t]\n[res1, res2] = Foo.bar(a, b) >>> res_t_list\nres_list = Foo.bar(a, b) >>> res_t_list\n```\n- Zero result\n```\nFoo.bar(a, b) >>> []\n```\n\n- Enable type inference,\n```\nFoo.bar(a, b) >>> :infer\n```\n- To return the op together with the result\n```\n{op, res} = Foo.bar(a, b) >>> {:op, types}\n```","title":"Different result declarations - Beaver.>>>/2","ref":"Beaver.html#%3E%3E%3E/2-different-result-declarations"},{"type":"macro","doc":"Create an anonymous block.\n\nThe block can be used to call CAPI.","title":"Beaver.block/1","ref":"Beaver.html#block/1"},{"type":"macro","doc":"Create a named block.\n\nThe block macro works like the function definition in Elixir, and in the do block of `block` macro you can reference an argument by name.\nIt should follow Elixir's lexical scoping rules and can be referenced by `Beaver.Env.block/1`\n\n> #### MLIR doesn't have named block {: .info}\n>\n> Note that the idea of named block is Beaver's concept. MLIR doesn't have it.","title":"Beaver.block/2","ref":"Beaver.html#block/2"},{"type":"macro","doc":"Transform the given DSL block but without specifying the context and block.\n\nThis is useful when you want to generate partials of quoted code and doesn't want to pass around the context and block.","title":"Beaver.mlir/1","ref":"Beaver.html#mlir/1"},{"type":"macro","doc":"Macro where Beaver's MLIR DSL expressions get transformed to MLIR API calls.\n\n\nThis transformation will works on any expression of the `>>>` form, so it is also possible to call any other vanilla Elixir function/macro.","title":"Beaver.mlir/2","ref":"Beaver.html#mlir/2"},{"type":"macro","doc":"```\n[res0, res1] = TestDialect.some_op(operand0, operand1, attr0: ~a{11 : i32}) >>> ~t{f32}\n```\nwill be transform to:\n```\n[res0, res1] =\n  %SSA{}\n  |> SSA.arguments([operand0, operand1, attr0: ~a{11 : i32}, attr1: ~a{11 : i32}])\n  |> SSA.results([~t{f32}])\n  |> TestDialect.some_op()\n```\nand `TestDialect.some_op()` is an Elixir function to actually create the MLIR operation. So it is possible to replace the left hand of the `>>>` operator with any Elixir function.","title":"How it works under the hood - Beaver.mlir/2","ref":"Beaver.html#mlir/2-how-it-works-under-the-hood"},{"type":"macro","doc":"Create MLIR region. Calling the macro within a do block will create an operation with the region.\n\nOne caveat is that if it is a Op with region, it requires all arguments to be passed in one list to make it to call the macro version of the Op creation function.\n```\nTestDialect.op_with_region [operand0, attr0: ~a{1}i32] do\n  region do\n    block(arg >>> ~t{f32}) do\n      TestDialect.some_op(arg) >>> ~t{f32}\n    end\n  end\nend >>> ~t{f32}\n```","title":"Beaver.region/1","ref":"Beaver.html#region/1"},{"type":"module","doc":"This module defines macros to getting MLIR context, region, block within the do block of mlir/1. It works like __MODULE__/0, __CALLER__/0 of Elixir special forms.","title":"Beaver.Env","ref":"Beaver.Env.html"},{"type":"macro","doc":"Return block in the DSL environment","title":"Beaver.Env.block/0","ref":"Beaver.Env.html#block/0"},{"type":"macro","doc":"Return block with a given name in the DSL environment","title":"Beaver.Env.block/1","ref":"Beaver.Env.html#block/1"},{"type":"macro","doc":"Return context in the DSL environment","title":"Beaver.Env.context/0","ref":"Beaver.Env.html#context/0"},{"type":"macro","doc":"Return region in the DSL environment","title":"Beaver.Env.region/0","ref":"Beaver.Env.html#region/0"},{"type":"behaviour","doc":"Behavior to build and register a dialect not included in LLVM mono repo. It is called \"Exterior\" not \"Extension\" or \"External\" to avoid confusing it with various LLVM/MLIR concepts of extensions.","title":"Beaver.Exterior","ref":"Beaver.Exterior.html"},{"type":"callback","doc":"Register a register to a MLIR context","title":"Beaver.Exterior.register_dialect/1","ref":"Beaver.Exterior.html#c:register_dialect/1"},{"type":"module","doc":"This module defines the Exterior for Elixir dialect. This is at the moment a placeholder for future development.","title":"Beaver.Exterior.Elixir","ref":"Beaver.Exterior.Elixir.html"},{"type":"function","doc":"","title":"Beaver.Exterior.Elixir.register_dialect/1","ref":"Beaver.Exterior.Elixir.html#register_dialect/1"},{"type":"module","doc":"Beaver pattern DSL for MLIR, a PDL frontend in Elixir.","title":"Beaver.Pattern","ref":"Beaver.Pattern.html"},{"type":"macro","doc":"","title":"Beaver.Pattern.attribute/0","ref":"Beaver.Pattern.html#attribute/0"},{"type":"macro","doc":"","title":"Beaver.Pattern.attribute/1","ref":"Beaver.Pattern.html#attribute/1"},{"type":"function","doc":"The difference between a pdl.operation creation in a match body and a rewrite body:\n- in a match body, `pdl.attribute`/`pdl.operand`/`pdl.result` will be generated for unbound variables\n- in a rewrite body, all variables are considered bound before creation pdl ops","title":"Beaver.Pattern.create_operation/5","ref":"Beaver.Pattern.html#create_operation/5"},{"type":"macro","doc":"","title":"Beaver.Pattern.defpat/2","ref":"Beaver.Pattern.html#defpat/2"},{"type":"function","doc":"Evaluate SSA as ops in a rewrite block. Note that function is only public so that it could be used in a AST.","title":"Beaver.Pattern.eval_rewrite/1","ref":"Beaver.Pattern.html#eval_rewrite/1"},{"type":"macro","doc":"","title":"Beaver.Pattern.replace/2","ref":"Beaver.Pattern.html#replace/2"},{"type":"macro","doc":"","title":"Beaver.Pattern.rewrite/2","ref":"Beaver.Pattern.html#rewrite/2"},{"type":"macro","doc":"","title":"Beaver.Pattern.type/0","ref":"Beaver.Pattern.html#type/0"},{"type":"macro","doc":"","title":"Beaver.Pattern.type/1","ref":"Beaver.Pattern.html#type/1"},{"type":"macro","doc":"","title":"Beaver.Pattern.value/0","ref":"Beaver.Pattern.html#value/0"},{"type":"module","doc":"Storing MLIR IR structure with a Elixir struct. Macros like `Beaver.mlir/1` will generate SSA structs defined by this module.","title":"Beaver.SSA","ref":"Beaver.SSA.html"},{"type":"function","doc":"","title":"Beaver.SSA.eval/1","ref":"Beaver.SSA.html#eval/1"},{"type":"function","doc":"","title":"Beaver.SSA.postwalk/2","ref":"Beaver.SSA.html#postwalk/2"},{"type":"function","doc":"","title":"Beaver.SSA.prewalk/2","ref":"Beaver.SSA.html#prewalk/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_arguments/2","ref":"Beaver.SSA.html#put_arguments/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_block/2","ref":"Beaver.SSA.html#put_block/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_ctx/2","ref":"Beaver.SSA.html#put_ctx/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_filler/2","ref":"Beaver.SSA.html#put_filler/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_location/2","ref":"Beaver.SSA.html#put_location/2"},{"type":"function","doc":"","title":"Beaver.SSA.put_results/2","ref":"Beaver.SSA.html#put_results/2"},{"type":"type","doc":"","title":"Beaver.SSA.t/0","ref":"Beaver.SSA.html#t:t/0"},{"type":"behaviour","doc":"Provides macros and utilities for defining MLIR dialects in Elixir.\n\nThis module allows you to define MLIR dialects using Elixir macros, which are internally compiled to\n[IRDL](https://mlir.llvm.org/docs/Dialects/IRDL/). It provides:\n\n- Macro-based dialect definition\n- Operation creation and manipulation\n- Type and attribute handling\n- Constraint definition support","title":"Beaver.Slang","ref":"Beaver.Slang.html"},{"type":"macro","doc":"This macro is invoked when the module is used. It sets up the module by registering attributes and importing macros from `Beaver.Slang`.","title":"Beaver.Slang.__using__/1","ref":"Beaver.Slang.html#__using__/1"},{"type":"macro","doc":"This macro generates the AST for the `irdl.any` op.","title":"Beaver.Slang.any/0","ref":"Beaver.Slang.html#any/0"},{"type":"macro","doc":"This macro generates the AST for the any_of attribute in the dialect.","title":"Beaver.Slang.any_of/1","ref":"Beaver.Slang.html#any_of/1"},{"type":"macro","doc":"This macro defines an alias for a lengthy type. It generates the AST for the alias function.","title":"Beaver.Slang.defalias/2","ref":"Beaver.Slang.html#defalias/2"},{"type":"macro","doc":"This macro defines a attribute in the dialect.","title":"Beaver.Slang.defattr/1","ref":"Beaver.Slang.html#defattr/1"},{"type":"macro","doc":"This macro defines an operation in the dialect. It generates the AST for the creator function for the operation.","title":"Beaver.Slang.defop/2","ref":"Beaver.Slang.html#defop/2"},{"type":"macro","doc":"This macro defines a type in the dialect.","title":"Beaver.Slang.deftype/1","ref":"Beaver.Slang.html#deftype/1"},{"type":"macro","doc":"This macro generates the AST for `irdl.is` op, usually used to create a constraint on type","title":"Beaver.Slang.is/1","ref":"Beaver.Slang.html#is/1"},{"type":"function","doc":"This function loads the MLIR dialect into the MLIR context. It invokes the internal function of the provided module to create the dialect's IRDL module and performs additional MLIR transformations and verification.","title":"Beaver.Slang.load/2","ref":"Beaver.Slang.html#load/2"},{"type":"module","doc":"This module provide functions to compose and run passes.","title":"Beaver.Composer","ref":"Beaver.Composer.html"},{"type":"function","doc":"","title":"Beaver.Composer.append/2","ref":"Beaver.Composer.html#append/2"},{"type":"type","doc":"","title":"Beaver.Composer.composer/0","ref":"Beaver.Composer.html#t:composer/0"},{"type":"function","doc":"","title":"Beaver.Composer.init/2","ref":"Beaver.Composer.html#init/2"},{"type":"function","doc":"","title":"Beaver.Composer.nested/3","ref":"Beaver.Composer.html#nested/3"},{"type":"function","doc":"","title":"Beaver.Composer.new/1","ref":"Beaver.Composer.html#new/1"},{"type":"type","doc":"","title":"Beaver.Composer.operation/0","ref":"Beaver.Composer.html#t:operation/0"},{"type":"function","doc":"Run the passes on the operation.\n\n> #### Must be a multi-threaded context if an Elixir pass is in the pipeline {: .info}\n>\n> MLIR context's thread pool is used to run the CAPI. If an Elixir pass is in the pipeline, the context must be multi-threaded otherwise there can be a deadlock. Also note that it can be more expensive than a C/C++ implementation due to the overhead of the thread pool.","title":"Beaver.Composer.run/2","ref":"Beaver.Composer.html#run/2"},{"type":"function","doc":"","title":"Beaver.Composer.run!/2","ref":"Beaver.Composer.html#run!/2"},{"type":"type","doc":"","title":"Beaver.Composer.run_option/0","ref":"Beaver.Composer.html#t:run_option/0"},{"type":"type","doc":"","title":"Beaver.Composer.run_result/0","ref":"Beaver.Composer.html#t:run_result/0"},{"type":"type","doc":"","title":"Beaver.Composer.t/0","ref":"Beaver.Composer.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.Composer.to_pipeline/1","ref":"Beaver.Composer.html#to_pipeline/1"},{"type":"module","doc":"Functions to work with IR entities not eagerly created. Usually it is an attribute/type doesn't get created until there is a MLIR context from block/op state.","title":"Beaver.Deferred","ref":"Beaver.Deferred.html"},{"type":"type","doc":"","title":"Beaver.Deferred.attribute/0","ref":"Beaver.Deferred.html#t:attribute/0"},{"type":"function","doc":"","title":"Beaver.Deferred.create/2","ref":"Beaver.Deferred.html#create/2"},{"type":"function","doc":"","title":"Beaver.Deferred.fetch_block/1","ref":"Beaver.Deferred.html#fetch_block/1"},{"type":"function","doc":"","title":"Beaver.Deferred.fetch_context/1","ref":"Beaver.Deferred.html#fetch_context/1"},{"type":"function","doc":"","title":"Beaver.Deferred.from_opts/2","ref":"Beaver.Deferred.html#from_opts/2"},{"type":"type","doc":"","title":"Beaver.Deferred.operation/0","ref":"Beaver.Deferred.html#t:operation/0"},{"type":"type","doc":"","title":"Beaver.Deferred.opts/0","ref":"Beaver.Deferred.html#t:opts/0"},{"type":"type","doc":"","title":"Beaver.Deferred.type/0","ref":"Beaver.Deferred.html#t:type/0"},{"type":"module","doc":"This module provides a way to run MLIR CAPI with a string callback and user data.","title":"Beaver.Printer","ref":"Beaver.Printer.html"},{"type":"function","doc":"","title":"Beaver.Printer.make/1","ref":"Beaver.Printer.html#make/1"},{"type":"function","doc":"Run the given function with a string callback and user data.","title":"Beaver.Printer.run/1","ref":"Beaver.Printer.html#run/1"},{"type":"type","doc":"","title":"Beaver.Printer.t/0","ref":"Beaver.Printer.html#t:t/0"},{"type":"module","doc":"Sigils return a function to create MLIR elements by parsing the content.","title":"Beaver.Sigils","ref":"Beaver.Sigils.html"},{"type":"function","doc":"Create an attribute creator.\n\nAdd a modifier to it as a shortcut to annotate the type","title":"Beaver.Sigils.sigil_a/2","ref":"Beaver.Sigils.html#sigil_a/2"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.equal?(Attribute.float(Type.f(32), 0.0).(ctx), ~a{0.0}f32.(ctx))\n    true\n    iex> ~a{1 : i32}.(ctx) |> MLIR.to_string()\n    \"1 : i32\"\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.Sigils.sigil_a/2","ref":"Beaver.Sigils.html#sigil_a/2-examples"},{"type":"function","doc":"Create a module creator.","title":"Beaver.Sigils.sigil_m/2","ref":"Beaver.Sigils.html#sigil_m/2"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> %MLIR.Module{} = ~m\"\"\"\n    ...> module {\n    ...>   func.func @add(%arg0 : i32, %arg1 : i32) -> i32 attributes { llvm.emit_c_interface } {\n    ...>     %res = arith.addi %arg0, %arg1 : i32\n    ...>     return %res : i32\n    ...>   }\n    ...> }\n    ...> \"\"\".(ctx) |> MLIR.verify!()\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.Sigils.sigil_m/2","ref":"Beaver.Sigils.html#sigil_m/2-examples"},{"type":"function","doc":"Create a type creator.\n\nAdd a modifier to it as a shortcut to make it a higher order type.","title":"Beaver.Sigils.sigil_t/2","ref":"Beaver.Sigils.html#sigil_t/2"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.equal?(Type.unranked_tensor!(Type.f32(ctx: ctx)), ~t{tensor<*xf32>}.(ctx))\n    true\n    iex> MLIR.equal?(Type.unranked_tensor!(Type.f32(ctx: ctx)), ~t{tensor<*xf32>})\n    true\n    iex> MLIR.equal?(Type.complex(Type.f32()).(ctx), ~t complex.(ctx))\n    true\n    iex> MLIR.equal?(Type.complex(Type.f32()), ~t complex.(ctx))\n    true\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.Sigils.sigil_t/2","ref":"Beaver.Sigils.html#sigil_t/2-examples"},{"type":"module","doc":"Provides traversal capabilities for MLIR structures.\n\nThis module implements traversal functionality for MLIR structures including:\n- `operations/1`\n- `results/1`\n- `successors/1`\n- `attributes/1`\n- `regions/1`\n\nIt implements both the `Enumerable` protocol and the `Access` behavior to provide\na familiar interface for working with MLIR structures.","title":"Beaver.Walker","ref":"Beaver.Walker.html"},{"type":"module","doc":"Allows traversing MLIR structures in depth-first order, visiting each node and its\nchildren before moving to siblings. Supports both pre-order (visit node before children) and post-order (visit children\nbefore node).","title":"Depth-first, pre-order and post-order walking - Beaver.Walker","ref":"Beaver.Walker.html#module-depth-first-pre-order-and-post-order-walking"},{"type":"module","doc":"It is possible to modifying the MLIR structure during traversal with CAPIs. It is recommended to use `replace/2` to replace an operation to keep the traversal going.","title":"Mutation Support - Beaver.Walker","ref":"Beaver.Walker.html#module-mutation-support"},{"type":"module","doc":"You can apply transformation patterns defined using `Beaver.Pattern.defpat/2` to MLIR structures during traversal.","title":"Pattern-based Transformations - Beaver.Walker","ref":"Beaver.Walker.html#module-pattern-based-transformations"},{"type":"module","doc":"- Access behavior to provide convenient attribute access:\n```elixir\nop[:attr_name]\nop[\"attr_name\"]\n```\n- convenient access to get operands, results, regions\n```\noperands(op)[0]\n```","title":"Access Syntax - Beaver.Walker","ref":"Beaver.Walker.html#module-access-syntax"},{"type":"function","doc":"Returns an enumerable of the arguments of an `Block.t()`","title":"Beaver.Walker.arguments/1","ref":"Beaver.Walker.html#arguments/1"},{"type":"function","doc":"Returns an enumerable of the attributes of an `operation()`.","title":"Beaver.Walker.attributes/1","ref":"Beaver.Walker.html#attributes/1"},{"type":"function","doc":"Returns an enumerable of the blocks of an `Region.t()`","title":"Beaver.Walker.blocks/1","ref":"Beaver.Walker.html#blocks/1"},{"type":"type","doc":"","title":"Beaver.Walker.container/0","ref":"Beaver.Walker.html#t:container/0"},{"type":"type","doc":"","title":"Beaver.Walker.element/0","ref":"Beaver.Walker.html#t:element/0"},{"type":"type","doc":"","title":"Beaver.Walker.element_module/0","ref":"Beaver.Walker.html#t:element_module/0"},{"type":"type","doc":"","title":"Beaver.Walker.mlir/0","ref":"Beaver.Walker.html#t:mlir/0"},{"type":"function","doc":"Returns an enumerable of the operands of an `operation()`.","title":"Beaver.Walker.operands/1","ref":"Beaver.Walker.html#operands/1"},{"type":"type","doc":"","title":"Beaver.Walker.operation/0","ref":"Beaver.Walker.html#t:operation/0"},{"type":"function","doc":"Returns an enumerable of the operations of an `Block.t()`","title":"Beaver.Walker.operations/1","ref":"Beaver.Walker.html#operations/1"},{"type":"function","doc":"Performs a depth-first, post-order traversal of a MLIR structure.","title":"Beaver.Walker.postwalk/2","ref":"Beaver.Walker.html#postwalk/2"},{"type":"function","doc":"Performs a depth-first, post-order traversal of a MLIR structure using an accumulator.","title":"Beaver.Walker.postwalk/3","ref":"Beaver.Walker.html#postwalk/3"},{"type":"function","doc":"Performs a depth-first, pre-order traversal of a MLIR structure.","title":"Beaver.Walker.prewalk/2","ref":"Beaver.Walker.html#prewalk/2"},{"type":"function","doc":"Performs a depth-first, pre-order traversal of a MLIR structure using an accumulator.","title":"Beaver.Walker.prewalk/3","ref":"Beaver.Walker.html#prewalk/3"},{"type":"function","doc":"Returns an enumerable of the regions of an `operation()`.","title":"Beaver.Walker.regions/1","ref":"Beaver.Walker.html#regions/1"},{"type":"function","doc":"Replace a operation with a value","title":"Beaver.Walker.replace/3","ref":"Beaver.Walker.html#replace/3"},{"type":"function","doc":"Returns an enumerable of the results of an `operation()`.","title":"Beaver.Walker.results/1","ref":"Beaver.Walker.html#results/1"},{"type":"function","doc":"Returns an enumerable of the successor blocks of an `operation()`.","title":"Beaver.Walker.successors/1","ref":"Beaver.Walker.html#successors/1"},{"type":"type","doc":"","title":"Beaver.Walker.t/0","ref":"Beaver.Walker.html#t:t/0"},{"type":"function","doc":"Traverse and transform a container in MLIR, it could be a operation, region, block.\nYou might expect this function works like `Macro.traverse/4`.","title":"Beaver.Walker.traverse/4","ref":"Beaver.Walker.html#traverse/4"},{"type":"function","doc":"During the traversal, there are generally two choices to manipulate the IR:\n- Use a pattern defined by macro `Beaver.Pattern.defpat/2` to have the PDL interpreter transform the IR for you.\nYou can use both if it is proper to do so.\n- Use `Beaver.Walker.replace/2` to replace the operation and return a walker as placeholder if is replaced by value.\nIt could be mind-boggling to think the IR is mutable but not an issue if your approach is very functional. Inappropriate mutation might cause crash or bugs if somewhere else is keeping a reference of the replace op.","title":"More on manipulating the IR - Beaver.Walker.traverse/4","ref":"Beaver.Walker.html#traverse/4-more-on-manipulating-the-ir"},{"type":"function","doc":"- If your matching is very complicated, using `with/1` in Elixir should cover it.\n- Use `defpat` if you want MLIR's greedy pattern application based on benefits instead of implementing something alike yourself.\n- You can run traversals in a MLIR pass by calling them in `run/1` so that it joins the general MLIR pass manager's orchestration and will be run in parallel when possible.","title":"Some tips - Beaver.Walker.traverse/4","ref":"Beaver.Walker.html#traverse/4-some-tips"},{"type":"function","doc":"Returns an enumerable of the uses of an `Value.t()`","title":"Beaver.Walker.uses/1","ref":"Beaver.Walker.html#uses/1"},{"type":"module","doc":"A placeholder when an operation is replaced by value.","title":"Beaver.Walker.OpReplacement","ref":"Beaver.Walker.OpReplacement.html"},{"type":"type","doc":"","title":"Beaver.Walker.OpReplacement.t/0","ref":"Beaver.Walker.OpReplacement.html#t:t/0"},{"type":"module","doc":"This module provides functions to work with Erlang's [erl_nif](https://www.erlang.org/doc/man/erl_nif.html) APIs in MLIR.","title":"Beaver.ENIF","ref":"Beaver.ENIF.html"},{"type":"module","doc":"- call `declare_external_functions/2` to insert external function declarations into a `Beaver.MLIR.Block`\n- call `register_symbols/1` to register symbols of ENIF functions in a `Beaver.MLIR.ExecutionEngine`","title":"Main usages - Beaver.ENIF","ref":"Beaver.ENIF.html#module-main-usages"},{"type":"function","doc":"function call to [enif_alloc](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc)","title":"Beaver.ENIF.alloc/1","ref":"Beaver.ENIF.html#alloc/1"},{"type":"function","doc":"function call to [enif_alloc_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_binary)","title":"Beaver.ENIF.alloc_binary/1","ref":"Beaver.ENIF.html#alloc_binary/1"},{"type":"function","doc":"function call to [enif_alloc_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_env)","title":"Beaver.ENIF.alloc_env/1","ref":"Beaver.ENIF.html#alloc_env/1"},{"type":"function","doc":"function call to [enif_alloc_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_alloc_resource)","title":"Beaver.ENIF.alloc_resource/1","ref":"Beaver.ENIF.html#alloc_resource/1"},{"type":"function","doc":"function call to [enif_binary_to_term](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_binary_to_term)","title":"Beaver.ENIF.binary_to_term/1","ref":"Beaver.ENIF.html#binary_to_term/1"},{"type":"function","doc":"function call to [enif_clear_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_clear_env)","title":"Beaver.ENIF.clear_env/1","ref":"Beaver.ENIF.html#clear_env/1"},{"type":"function","doc":"function call to [enif_compare](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare)","title":"Beaver.ENIF.compare/1","ref":"Beaver.ENIF.html#compare/1"},{"type":"function","doc":"function call to [enif_compare_monitors](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare_monitors)","title":"Beaver.ENIF.compare_monitors/1","ref":"Beaver.ENIF.html#compare_monitors/1"},{"type":"function","doc":"function call to [enif_compare_pids](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_compare_pids)","title":"Beaver.ENIF.compare_pids/1","ref":"Beaver.ENIF.html#compare_pids/1"},{"type":"function","doc":"function call to [enif_cond_broadcast](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_broadcast)","title":"Beaver.ENIF.cond_broadcast/1","ref":"Beaver.ENIF.html#cond_broadcast/1"},{"type":"function","doc":"function call to [enif_cond_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_create)","title":"Beaver.ENIF.cond_create/1","ref":"Beaver.ENIF.html#cond_create/1"},{"type":"function","doc":"function call to [enif_cond_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_destroy)","title":"Beaver.ENIF.cond_destroy/1","ref":"Beaver.ENIF.html#cond_destroy/1"},{"type":"function","doc":"function call to [enif_cond_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_name)","title":"Beaver.ENIF.cond_name/1","ref":"Beaver.ENIF.html#cond_name/1"},{"type":"function","doc":"function call to [enif_cond_signal](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_signal)","title":"Beaver.ENIF.cond_signal/1","ref":"Beaver.ENIF.html#cond_signal/1"},{"type":"function","doc":"function call to [enif_cond_wait](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cond_wait)","title":"Beaver.ENIF.cond_wait/1","ref":"Beaver.ENIF.html#cond_wait/1"},{"type":"function","doc":"function call to [enif_consume_timeslice](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_consume_timeslice)","title":"Beaver.ENIF.consume_timeslice/1","ref":"Beaver.ENIF.html#consume_timeslice/1"},{"type":"function","doc":"function call to [enif_convert_time_unit](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_convert_time_unit)","title":"Beaver.ENIF.convert_time_unit/1","ref":"Beaver.ENIF.html#convert_time_unit/1"},{"type":"function","doc":"function call to [enif_cpu_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_cpu_time)","title":"Beaver.ENIF.cpu_time/1","ref":"Beaver.ENIF.html#cpu_time/1"},{"type":"function","doc":"Insert external functions of ENIF into given MLIR block","title":"Beaver.ENIF.declare_external_functions/2","ref":"Beaver.ENIF.html#declare_external_functions/2"},{"type":"function","doc":"function call to [enif_demonitor_process](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_demonitor_process)","title":"Beaver.ENIF.demonitor_process/1","ref":"Beaver.ENIF.html#demonitor_process/1"},{"type":"function","doc":"function call to [enif_dynamic_resource_call](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_dynamic_resource_call)","title":"Beaver.ENIF.dynamic_resource_call/1","ref":"Beaver.ENIF.html#dynamic_resource_call/1"},{"type":"function","doc":"function call to [enif_equal_tids](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_equal_tids)","title":"Beaver.ENIF.equal_tids/1","ref":"Beaver.ENIF.html#equal_tids/1"},{"type":"function","doc":"function call to [enif_fprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_fprintf)","title":"Beaver.ENIF.fprintf/1","ref":"Beaver.ENIF.html#fprintf/1"},{"type":"function","doc":"function call to [enif_free](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free)","title":"Beaver.ENIF.free/1","ref":"Beaver.ENIF.html#free/1"},{"type":"function","doc":"function call to [enif_free_env](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free_env)","title":"Beaver.ENIF.free_env/1","ref":"Beaver.ENIF.html#free_env/1"},{"type":"function","doc":"function call to [enif_free_iovec](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_free_iovec)","title":"Beaver.ENIF.free_iovec/1","ref":"Beaver.ENIF.html#free_iovec/1"},{"type":"function","doc":"","title":"Beaver.ENIF.functions/0","ref":"Beaver.ENIF.html#functions/0"},{"type":"function","doc":"function call to [enif_get_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_atom)","title":"Beaver.ENIF.get_atom/1","ref":"Beaver.ENIF.html#get_atom/1"},{"type":"function","doc":"function call to [enif_get_atom_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_atom_length)","title":"Beaver.ENIF.get_atom_length/1","ref":"Beaver.ENIF.html#get_atom_length/1"},{"type":"function","doc":"function call to [enif_get_double](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_double)","title":"Beaver.ENIF.get_double/1","ref":"Beaver.ENIF.html#get_double/1"},{"type":"function","doc":"function call to [enif_get_int64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_int64)","title":"Beaver.ENIF.get_int64/1","ref":"Beaver.ENIF.html#get_int64/1"},{"type":"function","doc":"function call to [enif_get_int](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_int)","title":"Beaver.ENIF.get_int/1","ref":"Beaver.ENIF.html#get_int/1"},{"type":"function","doc":"function call to [enif_get_list_cell](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_list_cell)","title":"Beaver.ENIF.get_list_cell/1","ref":"Beaver.ENIF.html#get_list_cell/1"},{"type":"function","doc":"function call to [enif_get_list_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_list_length)","title":"Beaver.ENIF.get_list_length/1","ref":"Beaver.ENIF.html#get_list_length/1"},{"type":"function","doc":"function call to [enif_get_local_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_local_pid)","title":"Beaver.ENIF.get_local_pid/1","ref":"Beaver.ENIF.html#get_local_pid/1"},{"type":"function","doc":"function call to [enif_get_local_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_local_port)","title":"Beaver.ENIF.get_local_port/1","ref":"Beaver.ENIF.html#get_local_port/1"},{"type":"function","doc":"function call to [enif_get_long](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_long)","title":"Beaver.ENIF.get_long/1","ref":"Beaver.ENIF.html#get_long/1"},{"type":"function","doc":"function call to [enif_get_map_size](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_map_size)","title":"Beaver.ENIF.get_map_size/1","ref":"Beaver.ENIF.html#get_map_size/1"},{"type":"function","doc":"function call to [enif_get_map_value](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_map_value)","title":"Beaver.ENIF.get_map_value/1","ref":"Beaver.ENIF.html#get_map_value/1"},{"type":"function","doc":"function call to [enif_get_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_resource)","title":"Beaver.ENIF.get_resource/1","ref":"Beaver.ENIF.html#get_resource/1"},{"type":"function","doc":"function call to [enif_get_string](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_string)","title":"Beaver.ENIF.get_string/1","ref":"Beaver.ENIF.html#get_string/1"},{"type":"function","doc":"function call to [enif_get_string_length](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_string_length)","title":"Beaver.ENIF.get_string_length/1","ref":"Beaver.ENIF.html#get_string_length/1"},{"type":"function","doc":"function call to [enif_get_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_tuple)","title":"Beaver.ENIF.get_tuple/1","ref":"Beaver.ENIF.html#get_tuple/1"},{"type":"function","doc":"function call to [enif_get_uint64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_uint64)","title":"Beaver.ENIF.get_uint64/1","ref":"Beaver.ENIF.html#get_uint64/1"},{"type":"function","doc":"function call to [enif_get_uint](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_uint)","title":"Beaver.ENIF.get_uint/1","ref":"Beaver.ENIF.html#get_uint/1"},{"type":"function","doc":"function call to [enif_get_ulong](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_get_ulong)","title":"Beaver.ENIF.get_ulong/1","ref":"Beaver.ENIF.html#get_ulong/1"},{"type":"function","doc":"function call to [enif_getenv](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_getenv)","title":"Beaver.ENIF.getenv/1","ref":"Beaver.ENIF.html#getenv/1"},{"type":"function","doc":"function call to [enif_has_pending_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_has_pending_exception)","title":"Beaver.ENIF.has_pending_exception/1","ref":"Beaver.ENIF.html#has_pending_exception/1"},{"type":"function","doc":"function call to [enif_hash](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_hash)","title":"Beaver.ENIF.hash/1","ref":"Beaver.ENIF.html#hash/1"},{"type":"function","doc":"function call to [enif_init_resource_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_init_resource_type)","title":"Beaver.ENIF.init_resource_type/1","ref":"Beaver.ENIF.html#init_resource_type/1"},{"type":"function","doc":"function call to [enif_inspect_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_binary)","title":"Beaver.ENIF.inspect_binary/1","ref":"Beaver.ENIF.html#inspect_binary/1"},{"type":"function","doc":"function call to [enif_inspect_iolist_as_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_iolist_as_binary)","title":"Beaver.ENIF.inspect_iolist_as_binary/1","ref":"Beaver.ENIF.html#inspect_iolist_as_binary/1"},{"type":"function","doc":"function call to [enif_inspect_iovec](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_inspect_iovec)","title":"Beaver.ENIF.inspect_iovec/1","ref":"Beaver.ENIF.html#inspect_iovec/1"},{"type":"function","doc":"","title":"Beaver.ENIF.invoke/4","ref":"Beaver.ENIF.html#invoke/4"},{"type":"function","doc":"function call to [enif_ioq_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_create)","title":"Beaver.ENIF.ioq_create/1","ref":"Beaver.ENIF.html#ioq_create/1"},{"type":"function","doc":"function call to [enif_ioq_deq](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_deq)","title":"Beaver.ENIF.ioq_deq/1","ref":"Beaver.ENIF.html#ioq_deq/1"},{"type":"function","doc":"function call to [enif_ioq_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_destroy)","title":"Beaver.ENIF.ioq_destroy/1","ref":"Beaver.ENIF.html#ioq_destroy/1"},{"type":"function","doc":"function call to [enif_ioq_enq_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_enq_binary)","title":"Beaver.ENIF.ioq_enq_binary/1","ref":"Beaver.ENIF.html#ioq_enq_binary/1"},{"type":"function","doc":"function call to [enif_ioq_enqv](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_enqv)","title":"Beaver.ENIF.ioq_enqv/1","ref":"Beaver.ENIF.html#ioq_enqv/1"},{"type":"function","doc":"function call to [enif_ioq_peek](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_peek)","title":"Beaver.ENIF.ioq_peek/1","ref":"Beaver.ENIF.html#ioq_peek/1"},{"type":"function","doc":"function call to [enif_ioq_peek_head](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_peek_head)","title":"Beaver.ENIF.ioq_peek_head/1","ref":"Beaver.ENIF.html#ioq_peek_head/1"},{"type":"function","doc":"function call to [enif_ioq_size](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_ioq_size)","title":"Beaver.ENIF.ioq_size/1","ref":"Beaver.ENIF.html#ioq_size/1"},{"type":"function","doc":"function call to [enif_is_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_atom)","title":"Beaver.ENIF.is_atom/1","ref":"Beaver.ENIF.html#is_atom/1"},{"type":"function","doc":"function call to [enif_is_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_binary)","title":"Beaver.ENIF.is_binary/1","ref":"Beaver.ENIF.html#is_binary/1"},{"type":"function","doc":"function call to [enif_is_current_process_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_current_process_alive)","title":"Beaver.ENIF.is_current_process_alive/1","ref":"Beaver.ENIF.html#is_current_process_alive/1"},{"type":"function","doc":"function call to [enif_is_empty_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_empty_list)","title":"Beaver.ENIF.is_empty_list/1","ref":"Beaver.ENIF.html#is_empty_list/1"},{"type":"function","doc":"function call to [enif_is_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_exception)","title":"Beaver.ENIF.is_exception/1","ref":"Beaver.ENIF.html#is_exception/1"},{"type":"function","doc":"function call to [enif_is_fun](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_fun)","title":"Beaver.ENIF.is_fun/1","ref":"Beaver.ENIF.html#is_fun/1"},{"type":"function","doc":"function call to [enif_is_identical](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_identical)","title":"Beaver.ENIF.is_identical/1","ref":"Beaver.ENIF.html#is_identical/1"},{"type":"function","doc":"function call to [enif_is_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_list)","title":"Beaver.ENIF.is_list/1","ref":"Beaver.ENIF.html#is_list/1"},{"type":"function","doc":"function call to [enif_is_map](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_map)","title":"Beaver.ENIF.is_map/1","ref":"Beaver.ENIF.html#is_map/1"},{"type":"function","doc":"function call to [enif_is_number](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_number)","title":"Beaver.ENIF.is_number/1","ref":"Beaver.ENIF.html#is_number/1"},{"type":"function","doc":"function call to [enif_is_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_pid)","title":"Beaver.ENIF.is_pid/1","ref":"Beaver.ENIF.html#is_pid/1"},{"type":"function","doc":"function call to [enif_is_pid_undefined](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_pid_undefined)","title":"Beaver.ENIF.is_pid_undefined/1","ref":"Beaver.ENIF.html#is_pid_undefined/1"},{"type":"function","doc":"function call to [enif_is_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_port)","title":"Beaver.ENIF.is_port/1","ref":"Beaver.ENIF.html#is_port/1"},{"type":"function","doc":"function call to [enif_is_port_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_port_alive)","title":"Beaver.ENIF.is_port_alive/1","ref":"Beaver.ENIF.html#is_port_alive/1"},{"type":"function","doc":"function call to [enif_is_process_alive](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_process_alive)","title":"Beaver.ENIF.is_process_alive/1","ref":"Beaver.ENIF.html#is_process_alive/1"},{"type":"function","doc":"function call to [enif_is_ref](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_ref)","title":"Beaver.ENIF.is_ref/1","ref":"Beaver.ENIF.html#is_ref/1"},{"type":"function","doc":"function call to [enif_is_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_is_tuple)","title":"Beaver.ENIF.is_tuple/1","ref":"Beaver.ENIF.html#is_tuple/1"},{"type":"function","doc":"function call to [enif_keep_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_keep_resource)","title":"Beaver.ENIF.keep_resource/1","ref":"Beaver.ENIF.html#keep_resource/1"},{"type":"function","doc":"function call to [enif_make_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_atom)","title":"Beaver.ENIF.make_atom/1","ref":"Beaver.ENIF.html#make_atom/1"},{"type":"function","doc":"function call to [enif_make_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_atom_len)","title":"Beaver.ENIF.make_atom_len/1","ref":"Beaver.ENIF.html#make_atom_len/1"},{"type":"function","doc":"function call to [enif_make_badarg](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_badarg)","title":"Beaver.ENIF.make_badarg/1","ref":"Beaver.ENIF.html#make_badarg/1"},{"type":"function","doc":"function call to [enif_make_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_binary)","title":"Beaver.ENIF.make_binary/1","ref":"Beaver.ENIF.html#make_binary/1"},{"type":"function","doc":"function call to [enif_make_copy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_copy)","title":"Beaver.ENIF.make_copy/1","ref":"Beaver.ENIF.html#make_copy/1"},{"type":"function","doc":"function call to [enif_make_double](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_double)","title":"Beaver.ENIF.make_double/1","ref":"Beaver.ENIF.html#make_double/1"},{"type":"function","doc":"function call to [enif_make_existing_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_existing_atom)","title":"Beaver.ENIF.make_existing_atom/1","ref":"Beaver.ENIF.html#make_existing_atom/1"},{"type":"function","doc":"function call to [enif_make_existing_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_existing_atom_len)","title":"Beaver.ENIF.make_existing_atom_len/1","ref":"Beaver.ENIF.html#make_existing_atom_len/1"},{"type":"function","doc":"function call to [enif_make_int64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_int64)","title":"Beaver.ENIF.make_int64/1","ref":"Beaver.ENIF.html#make_int64/1"},{"type":"function","doc":"function call to [enif_make_int](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_int)","title":"Beaver.ENIF.make_int/1","ref":"Beaver.ENIF.html#make_int/1"},{"type":"function","doc":"function call to [enif_make_list1](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list1)","title":"Beaver.ENIF.make_list1/1","ref":"Beaver.ENIF.html#make_list1/1"},{"type":"function","doc":"function call to [enif_make_list2](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list2)","title":"Beaver.ENIF.make_list2/1","ref":"Beaver.ENIF.html#make_list2/1"},{"type":"function","doc":"function call to [enif_make_list3](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list3)","title":"Beaver.ENIF.make_list3/1","ref":"Beaver.ENIF.html#make_list3/1"},{"type":"function","doc":"function call to [enif_make_list4](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list4)","title":"Beaver.ENIF.make_list4/1","ref":"Beaver.ENIF.html#make_list4/1"},{"type":"function","doc":"function call to [enif_make_list5](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list5)","title":"Beaver.ENIF.make_list5/1","ref":"Beaver.ENIF.html#make_list5/1"},{"type":"function","doc":"function call to [enif_make_list6](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list6)","title":"Beaver.ENIF.make_list6/1","ref":"Beaver.ENIF.html#make_list6/1"},{"type":"function","doc":"function call to [enif_make_list7](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list7)","title":"Beaver.ENIF.make_list7/1","ref":"Beaver.ENIF.html#make_list7/1"},{"type":"function","doc":"function call to [enif_make_list8](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list8)","title":"Beaver.ENIF.make_list8/1","ref":"Beaver.ENIF.html#make_list8/1"},{"type":"function","doc":"function call to [enif_make_list9](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list9)","title":"Beaver.ENIF.make_list9/1","ref":"Beaver.ENIF.html#make_list9/1"},{"type":"function","doc":"function call to [enif_make_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list)","title":"Beaver.ENIF.make_list/1","ref":"Beaver.ENIF.html#make_list/1"},{"type":"function","doc":"function call to [enif_make_list_cell](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list_cell)","title":"Beaver.ENIF.make_list_cell/1","ref":"Beaver.ENIF.html#make_list_cell/1"},{"type":"function","doc":"function call to [enif_make_list_from_array](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_list_from_array)","title":"Beaver.ENIF.make_list_from_array/1","ref":"Beaver.ENIF.html#make_list_from_array/1"},{"type":"function","doc":"function call to [enif_make_long](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_long)","title":"Beaver.ENIF.make_long/1","ref":"Beaver.ENIF.html#make_long/1"},{"type":"function","doc":"function call to [enif_make_map_from_arrays](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_from_arrays)","title":"Beaver.ENIF.make_map_from_arrays/1","ref":"Beaver.ENIF.html#make_map_from_arrays/1"},{"type":"function","doc":"function call to [enif_make_map_put](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_put)","title":"Beaver.ENIF.make_map_put/1","ref":"Beaver.ENIF.html#make_map_put/1"},{"type":"function","doc":"function call to [enif_make_map_remove](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_remove)","title":"Beaver.ENIF.make_map_remove/1","ref":"Beaver.ENIF.html#make_map_remove/1"},{"type":"function","doc":"function call to [enif_make_map_update](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_map_update)","title":"Beaver.ENIF.make_map_update/1","ref":"Beaver.ENIF.html#make_map_update/1"},{"type":"function","doc":"function call to [enif_make_monitor_term](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_monitor_term)","title":"Beaver.ENIF.make_monitor_term/1","ref":"Beaver.ENIF.html#make_monitor_term/1"},{"type":"function","doc":"function call to [enif_make_new_atom](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_atom)","title":"Beaver.ENIF.make_new_atom/1","ref":"Beaver.ENIF.html#make_new_atom/1"},{"type":"function","doc":"function call to [enif_make_new_atom_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_atom_len)","title":"Beaver.ENIF.make_new_atom_len/1","ref":"Beaver.ENIF.html#make_new_atom_len/1"},{"type":"function","doc":"function call to [enif_make_new_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_binary)","title":"Beaver.ENIF.make_new_binary/1","ref":"Beaver.ENIF.html#make_new_binary/1"},{"type":"function","doc":"function call to [enif_make_new_map](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_new_map)","title":"Beaver.ENIF.make_new_map/1","ref":"Beaver.ENIF.html#make_new_map/1"},{"type":"function","doc":"function call to [enif_make_ref](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_ref)","title":"Beaver.ENIF.make_ref/1","ref":"Beaver.ENIF.html#make_ref/1"},{"type":"function","doc":"function call to [enif_make_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_resource)","title":"Beaver.ENIF.make_resource/1","ref":"Beaver.ENIF.html#make_resource/1"},{"type":"function","doc":"function call to [enif_make_resource_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_resource_binary)","title":"Beaver.ENIF.make_resource_binary/1","ref":"Beaver.ENIF.html#make_resource_binary/1"},{"type":"function","doc":"function call to [enif_make_reverse_list](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_reverse_list)","title":"Beaver.ENIF.make_reverse_list/1","ref":"Beaver.ENIF.html#make_reverse_list/1"},{"type":"function","doc":"function call to [enif_make_string](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_string)","title":"Beaver.ENIF.make_string/1","ref":"Beaver.ENIF.html#make_string/1"},{"type":"function","doc":"function call to [enif_make_string_len](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_string_len)","title":"Beaver.ENIF.make_string_len/1","ref":"Beaver.ENIF.html#make_string_len/1"},{"type":"function","doc":"function call to [enif_make_sub_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_sub_binary)","title":"Beaver.ENIF.make_sub_binary/1","ref":"Beaver.ENIF.html#make_sub_binary/1"},{"type":"function","doc":"function call to [enif_make_tuple1](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple1)","title":"Beaver.ENIF.make_tuple1/1","ref":"Beaver.ENIF.html#make_tuple1/1"},{"type":"function","doc":"function call to [enif_make_tuple2](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple2)","title":"Beaver.ENIF.make_tuple2/1","ref":"Beaver.ENIF.html#make_tuple2/1"},{"type":"function","doc":"function call to [enif_make_tuple3](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple3)","title":"Beaver.ENIF.make_tuple3/1","ref":"Beaver.ENIF.html#make_tuple3/1"},{"type":"function","doc":"function call to [enif_make_tuple4](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple4)","title":"Beaver.ENIF.make_tuple4/1","ref":"Beaver.ENIF.html#make_tuple4/1"},{"type":"function","doc":"function call to [enif_make_tuple5](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple5)","title":"Beaver.ENIF.make_tuple5/1","ref":"Beaver.ENIF.html#make_tuple5/1"},{"type":"function","doc":"function call to [enif_make_tuple6](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple6)","title":"Beaver.ENIF.make_tuple6/1","ref":"Beaver.ENIF.html#make_tuple6/1"},{"type":"function","doc":"function call to [enif_make_tuple7](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple7)","title":"Beaver.ENIF.make_tuple7/1","ref":"Beaver.ENIF.html#make_tuple7/1"},{"type":"function","doc":"function call to [enif_make_tuple8](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple8)","title":"Beaver.ENIF.make_tuple8/1","ref":"Beaver.ENIF.html#make_tuple8/1"},{"type":"function","doc":"function call to [enif_make_tuple9](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple9)","title":"Beaver.ENIF.make_tuple9/1","ref":"Beaver.ENIF.html#make_tuple9/1"},{"type":"function","doc":"function call to [enif_make_tuple](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple)","title":"Beaver.ENIF.make_tuple/1","ref":"Beaver.ENIF.html#make_tuple/1"},{"type":"function","doc":"function call to [enif_make_tuple_from_array](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_tuple_from_array)","title":"Beaver.ENIF.make_tuple_from_array/1","ref":"Beaver.ENIF.html#make_tuple_from_array/1"},{"type":"function","doc":"function call to [enif_make_uint64](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_uint64)","title":"Beaver.ENIF.make_uint64/1","ref":"Beaver.ENIF.html#make_uint64/1"},{"type":"function","doc":"function call to [enif_make_uint](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_uint)","title":"Beaver.ENIF.make_uint/1","ref":"Beaver.ENIF.html#make_uint/1"},{"type":"function","doc":"function call to [enif_make_ulong](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_ulong)","title":"Beaver.ENIF.make_ulong/1","ref":"Beaver.ENIF.html#make_ulong/1"},{"type":"function","doc":"function call to [enif_make_unique_integer](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_make_unique_integer)","title":"Beaver.ENIF.make_unique_integer/1","ref":"Beaver.ENIF.html#make_unique_integer/1"},{"type":"function","doc":"function call to [enif_map_iterator_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_create)","title":"Beaver.ENIF.map_iterator_create/1","ref":"Beaver.ENIF.html#map_iterator_create/1"},{"type":"function","doc":"function call to [enif_map_iterator_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_destroy)","title":"Beaver.ENIF.map_iterator_destroy/1","ref":"Beaver.ENIF.html#map_iterator_destroy/1"},{"type":"function","doc":"function call to [enif_map_iterator_get_pair](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_get_pair)","title":"Beaver.ENIF.map_iterator_get_pair/1","ref":"Beaver.ENIF.html#map_iterator_get_pair/1"},{"type":"function","doc":"function call to [enif_map_iterator_is_head](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_is_head)","title":"Beaver.ENIF.map_iterator_is_head/1","ref":"Beaver.ENIF.html#map_iterator_is_head/1"},{"type":"function","doc":"function call to [enif_map_iterator_is_tail](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_is_tail)","title":"Beaver.ENIF.map_iterator_is_tail/1","ref":"Beaver.ENIF.html#map_iterator_is_tail/1"},{"type":"function","doc":"function call to [enif_map_iterator_next](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_next)","title":"Beaver.ENIF.map_iterator_next/1","ref":"Beaver.ENIF.html#map_iterator_next/1"},{"type":"function","doc":"function call to [enif_map_iterator_prev](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_map_iterator_prev)","title":"Beaver.ENIF.map_iterator_prev/1","ref":"Beaver.ENIF.html#map_iterator_prev/1"},{"type":"function","doc":"function call to [enif_monitor_process](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_monitor_process)","title":"Beaver.ENIF.monitor_process/1","ref":"Beaver.ENIF.html#monitor_process/1"},{"type":"function","doc":"function call to [enif_monotonic_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_monotonic_time)","title":"Beaver.ENIF.monotonic_time/1","ref":"Beaver.ENIF.html#monotonic_time/1"},{"type":"function","doc":"function call to [enif_mutex_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_create)","title":"Beaver.ENIF.mutex_create/1","ref":"Beaver.ENIF.html#mutex_create/1"},{"type":"function","doc":"function call to [enif_mutex_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_destroy)","title":"Beaver.ENIF.mutex_destroy/1","ref":"Beaver.ENIF.html#mutex_destroy/1"},{"type":"function","doc":"function call to [enif_mutex_lock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_lock)","title":"Beaver.ENIF.mutex_lock/1","ref":"Beaver.ENIF.html#mutex_lock/1"},{"type":"function","doc":"function call to [enif_mutex_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_name)","title":"Beaver.ENIF.mutex_name/1","ref":"Beaver.ENIF.html#mutex_name/1"},{"type":"function","doc":"function call to [enif_mutex_trylock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_trylock)","title":"Beaver.ENIF.mutex_trylock/1","ref":"Beaver.ENIF.html#mutex_trylock/1"},{"type":"function","doc":"function call to [enif_mutex_unlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_mutex_unlock)","title":"Beaver.ENIF.mutex_unlock/1","ref":"Beaver.ENIF.html#mutex_unlock/1"},{"type":"function","doc":"function call to [enif_now_time](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_now_time)","title":"Beaver.ENIF.now_time/1","ref":"Beaver.ENIF.html#now_time/1"},{"type":"function","doc":"function call to [enif_open_resource_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_open_resource_type)","title":"Beaver.ENIF.open_resource_type/1","ref":"Beaver.ENIF.html#open_resource_type/1"},{"type":"function","doc":"function call to [enif_open_resource_type_x](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_open_resource_type_x)","title":"Beaver.ENIF.open_resource_type_x/1","ref":"Beaver.ENIF.html#open_resource_type_x/1"},{"type":"function","doc":"function call to [enif_port_command](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_port_command)","title":"Beaver.ENIF.port_command/1","ref":"Beaver.ENIF.html#port_command/1"},{"type":"function","doc":"function call to print_close","title":"Beaver.ENIF.print_close/1","ref":"Beaver.ENIF.html#print_close/1"},{"type":"function","doc":"function call to print_comma","title":"Beaver.ENIF.print_comma/1","ref":"Beaver.ENIF.html#print_comma/1"},{"type":"function","doc":"function call to print_f32","title":"Beaver.ENIF.print_f32/1","ref":"Beaver.ENIF.html#print_f32/1"},{"type":"function","doc":"function call to print_f64","title":"Beaver.ENIF.print_f64/1","ref":"Beaver.ENIF.html#print_f64/1"},{"type":"function","doc":"function call to print_i32","title":"Beaver.ENIF.print_i32/1","ref":"Beaver.ENIF.html#print_i32/1"},{"type":"function","doc":"function call to print_i64","title":"Beaver.ENIF.print_i64/1","ref":"Beaver.ENIF.html#print_i64/1"},{"type":"function","doc":"function call to print_newline","title":"Beaver.ENIF.print_newline/1","ref":"Beaver.ENIF.html#print_newline/1"},{"type":"function","doc":"function call to print_open","title":"Beaver.ENIF.print_open/1","ref":"Beaver.ENIF.html#print_open/1"},{"type":"function","doc":"function call to print_u32","title":"Beaver.ENIF.print_u32/1","ref":"Beaver.ENIF.html#print_u32/1"},{"type":"function","doc":"function call to print_u64","title":"Beaver.ENIF.print_u64/1","ref":"Beaver.ENIF.html#print_u64/1"},{"type":"function","doc":"function call to [enif_priv_data](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_priv_data)","title":"Beaver.ENIF.priv_data/1","ref":"Beaver.ENIF.html#priv_data/1"},{"type":"function","doc":"Convert a pointer to a memref\n\n`ptr_to_memref(ptr(), size()) :: memref<?xi8>`","title":"Beaver.ENIF.ptr_to_memref/1","ref":"Beaver.ENIF.html#ptr_to_memref/1"},{"type":"function","doc":"function call to [enif_raise_exception](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_raise_exception)","title":"Beaver.ENIF.raise_exception/1","ref":"Beaver.ENIF.html#raise_exception/1"},{"type":"function","doc":"function call to [enif_realloc](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_realloc)","title":"Beaver.ENIF.realloc/1","ref":"Beaver.ENIF.html#realloc/1"},{"type":"function","doc":"function call to [enif_realloc_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_realloc_binary)","title":"Beaver.ENIF.realloc_binary/1","ref":"Beaver.ENIF.html#realloc_binary/1"},{"type":"function","doc":"","title":"Beaver.ENIF.register_symbols/1","ref":"Beaver.ENIF.html#register_symbols/1"},{"type":"function","doc":"function call to [enif_release_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_release_binary)","title":"Beaver.ENIF.release_binary/1","ref":"Beaver.ENIF.html#release_binary/1"},{"type":"function","doc":"function call to [enif_release_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_release_resource)","title":"Beaver.ENIF.release_resource/1","ref":"Beaver.ENIF.html#release_resource/1"},{"type":"function","doc":"function call to [enif_rwlock_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_create)","title":"Beaver.ENIF.rwlock_create/1","ref":"Beaver.ENIF.html#rwlock_create/1"},{"type":"function","doc":"function call to [enif_rwlock_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_destroy)","title":"Beaver.ENIF.rwlock_destroy/1","ref":"Beaver.ENIF.html#rwlock_destroy/1"},{"type":"function","doc":"function call to [enif_rwlock_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_name)","title":"Beaver.ENIF.rwlock_name/1","ref":"Beaver.ENIF.html#rwlock_name/1"},{"type":"function","doc":"function call to [enif_rwlock_rlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rlock)","title":"Beaver.ENIF.rwlock_rlock/1","ref":"Beaver.ENIF.html#rwlock_rlock/1"},{"type":"function","doc":"function call to [enif_rwlock_runlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_runlock)","title":"Beaver.ENIF.rwlock_runlock/1","ref":"Beaver.ENIF.html#rwlock_runlock/1"},{"type":"function","doc":"function call to [enif_rwlock_rwlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rwlock)","title":"Beaver.ENIF.rwlock_rwlock/1","ref":"Beaver.ENIF.html#rwlock_rwlock/1"},{"type":"function","doc":"function call to [enif_rwlock_rwunlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_rwunlock)","title":"Beaver.ENIF.rwlock_rwunlock/1","ref":"Beaver.ENIF.html#rwlock_rwunlock/1"},{"type":"function","doc":"function call to [enif_rwlock_tryrlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_tryrlock)","title":"Beaver.ENIF.rwlock_tryrlock/1","ref":"Beaver.ENIF.html#rwlock_tryrlock/1"},{"type":"function","doc":"function call to [enif_rwlock_tryrwlock](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_rwlock_tryrwlock)","title":"Beaver.ENIF.rwlock_tryrwlock/1","ref":"Beaver.ENIF.html#rwlock_tryrwlock/1"},{"type":"function","doc":"function call to [enif_schedule_nif](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_schedule_nif)","title":"Beaver.ENIF.schedule_nif/1","ref":"Beaver.ENIF.html#schedule_nif/1"},{"type":"function","doc":"function call to [enif_select](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_select)","title":"Beaver.ENIF.select/1","ref":"Beaver.ENIF.html#select/1"},{"type":"function","doc":"function call to [enif_self](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_self)","title":"Beaver.ENIF.self/1","ref":"Beaver.ENIF.html#self/1"},{"type":"function","doc":"function call to [enif_send](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_send)","title":"Beaver.ENIF.send/1","ref":"Beaver.ENIF.html#send/1"},{"type":"function","doc":"function call to [enif_set_option](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_set_option)","title":"Beaver.ENIF.set_option/1","ref":"Beaver.ENIF.html#set_option/1"},{"type":"function","doc":"function call to [enif_set_pid_undefined](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_set_pid_undefined)","title":"Beaver.ENIF.set_pid_undefined/1","ref":"Beaver.ENIF.html#set_pid_undefined/1"},{"type":"function","doc":"Query the signature of an ENIF function.","title":"Beaver.ENIF.signature/2","ref":"Beaver.ENIF.html#signature/2"},{"type":"function","doc":"Retrieve the signatures of all available ENIF functions.","title":"Beaver.ENIF.signatures/1","ref":"Beaver.ENIF.html#signatures/1"},{"type":"function","doc":"function call to [enif_sizeof_resource](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_sizeof_resource)","title":"Beaver.ENIF.sizeof_resource/1","ref":"Beaver.ENIF.html#sizeof_resource/1"},{"type":"function","doc":"function call to [enif_snprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_snprintf)","title":"Beaver.ENIF.snprintf/1","ref":"Beaver.ENIF.html#snprintf/1"},{"type":"function","doc":"function call to [enif_system_info](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_system_info)","title":"Beaver.ENIF.system_info/1","ref":"Beaver.ENIF.html#system_info/1"},{"type":"function","doc":"function call to [enif_term_to_binary](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_term_to_binary)","title":"Beaver.ENIF.term_to_binary/1","ref":"Beaver.ENIF.html#term_to_binary/1"},{"type":"function","doc":"function call to [enif_term_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_term_type)","title":"Beaver.ENIF.term_type/1","ref":"Beaver.ENIF.html#term_type/1"},{"type":"function","doc":"function call to [enif_thread_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_create)","title":"Beaver.ENIF.thread_create/1","ref":"Beaver.ENIF.html#thread_create/1"},{"type":"function","doc":"function call to [enif_thread_exit](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_exit)","title":"Beaver.ENIF.thread_exit/1","ref":"Beaver.ENIF.html#thread_exit/1"},{"type":"function","doc":"function call to [enif_thread_join](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_join)","title":"Beaver.ENIF.thread_join/1","ref":"Beaver.ENIF.html#thread_join/1"},{"type":"function","doc":"function call to [enif_thread_name](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_name)","title":"Beaver.ENIF.thread_name/1","ref":"Beaver.ENIF.html#thread_name/1"},{"type":"function","doc":"function call to [enif_thread_opts_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_opts_create)","title":"Beaver.ENIF.thread_opts_create/1","ref":"Beaver.ENIF.html#thread_opts_create/1"},{"type":"function","doc":"function call to [enif_thread_opts_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_opts_destroy)","title":"Beaver.ENIF.thread_opts_destroy/1","ref":"Beaver.ENIF.html#thread_opts_destroy/1"},{"type":"function","doc":"function call to [enif_thread_self](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_self)","title":"Beaver.ENIF.thread_self/1","ref":"Beaver.ENIF.html#thread_self/1"},{"type":"function","doc":"function call to [enif_thread_type](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_thread_type)","title":"Beaver.ENIF.thread_type/1","ref":"Beaver.ENIF.html#thread_type/1"},{"type":"function","doc":"function call to [enif_time_offset](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_time_offset)","title":"Beaver.ENIF.time_offset/1","ref":"Beaver.ENIF.html#time_offset/1"},{"type":"function","doc":"function call to [enif_tsd_get](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_get)","title":"Beaver.ENIF.tsd_get/1","ref":"Beaver.ENIF.html#tsd_get/1"},{"type":"function","doc":"function call to [enif_tsd_key_create](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_key_create)","title":"Beaver.ENIF.tsd_key_create/1","ref":"Beaver.ENIF.html#tsd_key_create/1"},{"type":"function","doc":"function call to [enif_tsd_key_destroy](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_key_destroy)","title":"Beaver.ENIF.tsd_key_destroy/1","ref":"Beaver.ENIF.html#tsd_key_destroy/1"},{"type":"function","doc":"function call to [enif_tsd_set](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_tsd_set)","title":"Beaver.ENIF.tsd_set/1","ref":"Beaver.ENIF.html#tsd_set/1"},{"type":"function","doc":"function call to [enif_vfprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_vfprintf)","title":"Beaver.ENIF.vfprintf/1","ref":"Beaver.ENIF.html#vfprintf/1"},{"type":"function","doc":"function call to [enif_vsnprintf](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_vsnprintf)","title":"Beaver.ENIF.vsnprintf/1","ref":"Beaver.ENIF.html#vsnprintf/1"},{"type":"function","doc":"function call to [enif_whereis_pid](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_whereis_pid)","title":"Beaver.ENIF.whereis_pid/1","ref":"Beaver.ENIF.html#whereis_pid/1"},{"type":"function","doc":"function call to [enif_whereis_port](https://www.erlang.org/doc/apps/erts/erl_nif.html#enif_whereis_port)","title":"Beaver.ENIF.whereis_port/1","ref":"Beaver.ENIF.html#whereis_port/1"},{"type":"module","doc":"Query the MLIR type of an Erlang term or environment.","title":"Beaver.ENIF.Type","ref":"Beaver.ENIF.Type.html"},{"type":"function","doc":"","title":"Beaver.ENIF.Type.binary/1","ref":"Beaver.ENIF.Type.html#binary/1"},{"type":"function","doc":"","title":"Beaver.ENIF.Type.env/1","ref":"Beaver.ENIF.Type.html#env/1"},{"type":"type","doc":"A tuple representing the signature of an enif function.\nEach tuple contains:\n- The name of the function, which is an atom.\n- A list of argument MLIR types.\n- A list of return MLIR types.","title":"Beaver.ENIF.Type.signature/0","ref":"Beaver.ENIF.Type.html#t:signature/0"},{"type":"function","doc":"","title":"Beaver.ENIF.Type.term/1","ref":"Beaver.ENIF.Type.html#term/1"},{"type":"module","doc":"Core functionality for working with MLIR.\n\nThis module serves as the primary interface for MLIR operations and entities in Beaver. It provides:\n\n- String conversion utilities for debugging and serialization\n- Null checking for safe operation handling\n- Context and location retrieval for MLIR entities","title":"Beaver.MLIR","ref":"Beaver.MLIR.html"},{"type":"module","doc":"When converting operations to strings, you can specify the output format:\n- `generic: true` - Uses MLIR's generic format\n- `generic: false` - Uses MLIR's specialized format\n- `bytecode: true` - Uses MLIR's bytecode format\n\nThe default format may vary between MLIR versions, so explicitly specify the format\nwhen consistent output is required.","title":"Printing Operations - Beaver.MLIR","ref":"Beaver.MLIR.html#module-printing-operations"},{"type":"module","doc":"Beaver doesn't implement `Inspect` protocol for MLIR entities because the output might be too verbose and can crash the BEAM if invalid entities are passed. Use `Beaver.MLIR.to_string/2` to convert entities to inspect it.","title":"Inspecting MLIR Entities - Beaver.MLIR","ref":"Beaver.MLIR.html#module-inspecting-mlir-entities"},{"type":"module","doc":"Many MLIR operations can return null values. Use `null?/1` to safely check entities\nbefore performing operations that require non-null values.","title":"Null Safety - Beaver.MLIR","ref":"Beaver.MLIR.html#module-null-safety"},{"type":"module","doc":"- `Beaver.MLIR.***`: APIs related to lifecycle, including creating and destroying MLIR entities.\n- `Beaver.MLIR`: APIs like `Beaver.MLIR.dump!/1` or `Beaver.MLIR.null?/1`. These are standard features generally expected in any MLIR tools.","title":"Name spaces to include different kinds of CAPI delegates - Beaver.MLIR","ref":"Beaver.MLIR.html#module-name-spaces-to-include-different-kinds-of-capi-delegates"},{"type":"type","doc":"","title":"Beaver.MLIR.applicable/0","ref":"Beaver.MLIR.html#t:applicable/0"},{"type":"function","doc":"Apply patterns on a container (region, operation, module).\nIt returns the container if it succeeds otherwise it raises.","title":"Beaver.MLIR.apply!/3","ref":"Beaver.MLIR.html#apply!/3"},{"type":"function","doc":"Apply patterns on a container (operation, module).\nIt is named `apply_` with a underscore to avoid name collision with `Kernel.apply/2`","title":"Beaver.MLIR.apply_/3","ref":"Beaver.MLIR.html#apply_/3"},{"type":"type","doc":"","title":"Beaver.MLIR.apply_opt/0","ref":"Beaver.MLIR.html#t:apply_opt/0"},{"type":"function","doc":"Get the MLIR context of an MLIR entity.","title":"Beaver.MLIR.context/1","ref":"Beaver.MLIR.html#context/1"},{"type":"function","doc":"Dump MLIR element to stdio.\n\nThis will call the printer registered in C/C++. Note that the outputs wouldn't go through Erlang's IO system, so it's not possible to capture the output in Elixir. If you need to capture the output, use `to_string/1` instead.","title":"Beaver.MLIR.dump/2","ref":"Beaver.MLIR.html#dump/2"},{"type":"function","doc":"Dump MLIR element to stdio and raise an error if it fails.","title":"Beaver.MLIR.dump!/2","ref":"Beaver.MLIR.html#dump!/2"},{"type":"type","doc":"","title":"Beaver.MLIR.dump_opts/0","ref":"Beaver.MLIR.html#t:dump_opts/0"},{"type":"function","doc":"Compare two MLIR entities.","title":"Beaver.MLIR.equal?/2","ref":"Beaver.MLIR.html#equal?/2"},{"type":"function","doc":"Get the MLIR location of an MLIR entity.","title":"Beaver.MLIR.location/1","ref":"Beaver.MLIR.html#location/1"},{"type":"function","doc":"Check if an MLIR entity is null.\n\nTo prevent crashing the BEAM, it is encouraged to use this function to check if an entity is null before calling functions that require a non-null entity.","title":"Beaver.MLIR.null?/1","ref":"Beaver.MLIR.html#null?/1"},{"type":"type","doc":"","title":"Beaver.MLIR.nullable/0","ref":"Beaver.MLIR.html#t:nullable/0"},{"type":"type","doc":"","title":"Beaver.MLIR.printable/0","ref":"Beaver.MLIR.html#t:printable/0"},{"type":"function","doc":"Print MLIR element or StringRef as Elixir binary string.\n\nWhen printing an operation, it is recommended to use `generic: false` or `generic: true` to explicitly specify the format if your usage requires consistent output. If not specified, the default behavior is subject to change according to the MLIR version.","title":"Beaver.MLIR.to_string/2","ref":"Beaver.MLIR.html#to_string/2"},{"type":"type","doc":"","title":"Beaver.MLIR.verifiable/0","ref":"Beaver.MLIR.html#t:verifiable/0"},{"type":"function","doc":"","title":"Beaver.MLIR.verify/1","ref":"Beaver.MLIR.html#verify/1"},{"type":"function","doc":"","title":"Beaver.MLIR.verify!/1","ref":"Beaver.MLIR.html#verify!/1"},{"type":"module","doc":"","title":"Beaver.MLIR.AffineExpr","ref":"Beaver.MLIR.AffineExpr.html"},{"type":"function","doc":"","title":"Beaver.MLIR.AffineExpr.make/1","ref":"Beaver.MLIR.AffineExpr.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.AffineExpr.t/0","ref":"Beaver.MLIR.AffineExpr.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR AffineMap.","title":"Beaver.MLIR.AffineMap","ref":"Beaver.MLIR.AffineMap.html"},{"type":"function","doc":"","title":"Beaver.MLIR.AffineMap.create/4","ref":"Beaver.MLIR.AffineMap.html#create/4"},{"type":"function","doc":"","title":"Beaver.MLIR.AffineMap.dim/2","ref":"Beaver.MLIR.AffineMap.html#dim/2"},{"type":"function","doc":"","title":"Beaver.MLIR.AffineMap.make/1","ref":"Beaver.MLIR.AffineMap.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.AffineMap.symbol/2","ref":"Beaver.MLIR.AffineMap.html#symbol/2"},{"type":"type","doc":"","title":"Beaver.MLIR.AffineMap.t/0","ref":"Beaver.MLIR.AffineMap.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.AsmState","ref":"Beaver.MLIR.AsmState.html"},{"type":"function","doc":"","title":"Beaver.MLIR.AsmState.make/1","ref":"Beaver.MLIR.AsmState.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.AsmState.t/0","ref":"Beaver.MLIR.AsmState.html#t:t/0"},{"type":"module","doc":"This module defines functions parsing and creating attributes in MLIR.","title":"Beaver.MLIR.Attribute","ref":"Beaver.MLIR.Attribute.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.affine_map/1","ref":"Beaver.MLIR.Attribute.html#affine_map/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.array/2","ref":"Beaver.MLIR.Attribute.html#array/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.bool/2","ref":"Beaver.MLIR.Attribute.html#bool/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.dense_array/3","ref":"Beaver.MLIR.Attribute.html#dense_array/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.dense_elements/3","ref":"Beaver.MLIR.Attribute.html#dense_elements/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.flat_symbol_ref/2","ref":"Beaver.MLIR.Attribute.html#flat_symbol_ref/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.float/2","ref":"Beaver.MLIR.Attribute.html#float/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.get/2","ref":"Beaver.MLIR.Attribute.html#get/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.index/2","ref":"Beaver.MLIR.Attribute.html#index/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.integer/2","ref":"Beaver.MLIR.Attribute.html#integer/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.make/1","ref":"Beaver.MLIR.Attribute.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.null/0","ref":"Beaver.MLIR.Attribute.html#null/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.string/2","ref":"Beaver.MLIR.Attribute.html#string/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.symbol_ref/3","ref":"Beaver.MLIR.Attribute.html#symbol_ref/3"},{"type":"type","doc":"","title":"Beaver.MLIR.Attribute.t/0","ref":"Beaver.MLIR.Attribute.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.type/1","ref":"Beaver.MLIR.Attribute.html#type/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.unit/1","ref":"Beaver.MLIR.Attribute.html#unit/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.unwrap/1","ref":"Beaver.MLIR.Attribute.html#unwrap/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.unwrap_string/1","ref":"Beaver.MLIR.Attribute.html#unwrap_string/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Attribute.unwrap_type/1","ref":"Beaver.MLIR.Attribute.html#unwrap_type/1"},{"type":"module","doc":"This module defines functions working with MLIR Block.","title":"Beaver.MLIR.Block","ref":"Beaver.MLIR.Block.html"},{"type":"function","doc":"add arguments to a block","title":"Beaver.MLIR.Block.add_args!/3","ref":"Beaver.MLIR.Block.html#add_args!/3"},{"type":"type","doc":"","title":"Beaver.MLIR.Block.arg/0","ref":"Beaver.MLIR.Block.html#t:arg/0"},{"type":"type","doc":"","title":"Beaver.MLIR.Block.arg_type/0","ref":"Beaver.MLIR.Block.html#t:arg_type/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Block.create/1","ref":"Beaver.MLIR.Block.html#create/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Block.create/2","ref":"Beaver.MLIR.Block.html#create/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Block.destroy/1","ref":"Beaver.MLIR.Block.html#destroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Block.get_arg!/2","ref":"Beaver.MLIR.Block.html#get_arg!/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Block.make/1","ref":"Beaver.MLIR.Block.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Block.t/0","ref":"Beaver.MLIR.Block.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.BytecodeWriterConfig","ref":"Beaver.MLIR.BytecodeWriterConfig.html"},{"type":"function","doc":"","title":"Beaver.MLIR.BytecodeWriterConfig.make/1","ref":"Beaver.MLIR.BytecodeWriterConfig.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.BytecodeWriterConfig.t/0","ref":"Beaver.MLIR.BytecodeWriterConfig.html#t:t/0"},{"type":"module","doc":"This module ships MLIR's C API. These NIFs are generated from headers in LLVM repo and this repo's headers providing supplemental functions.","title":"Beaver.MLIR.CAPI","ref":"Beaver.MLIR.CAPI.html"},{"type":"module","doc":"Some MLIR CAPIs might trigger the execution of Elixir code by sending messages.\nTheir respective NIFs will be created with dirty flag to prevent dead-locking the BEAM VM if the Elixir callback is scheduled to run on the same scheduler. That's why the Elixir callback shouldn't contain any code run on dirty scheduler. Also be aware of the performance of the Elixir callback, because when it is running, the dirty schedulers will be blocked to wait for a mutex.\n\nHere are the list of these MLIR CAPIs and the Elixir code to execute they might trigger:\n- `mlirPassManagerRunOnOp`: the MLIR pass implemented in Elixir.\n- `mlirOperationVerify`, `mlirAttributeParseGet`, `mlirTypeParseGet`, `mlirModuleCreateParse`: the diagnostic handler implemented in Elixir.","title":"MLIR CAPIs might trigger Elixir code execution - Beaver.MLIR.CAPI","ref":"Beaver.MLIR.CAPI.html#module-mlir-capis-might-trigger-elixir-code-execution"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_context_attach_diagnostic_handler/2","ref":"Beaver.MLIR.CAPI.html#beaver_raw_context_attach_diagnostic_handler/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_create_mlir_pass/8","ref":"Beaver.MLIR.CAPI.html#beaver_raw_create_mlir_pass/8"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_deallocate_opaque_ptr/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_deallocate_opaque_ptr/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_destroy_pm_async/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_destroy_pm_async/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_enif_functions/0","ref":"Beaver.MLIR.CAPI.html#beaver_raw_enif_functions/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_enif_signatures/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_enif_signatures/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_get_null_ptr/0","ref":"Beaver.MLIR.CAPI.html#beaver_raw_get_null_ptr/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_get_string_ref/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_get_string_ref/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms/3","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms_cpu_bound/3","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms_cpu_bound/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_jit_invoke_with_terms_io_bound/3","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_invoke_with_terms_io_bound/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_jit_register_enif/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_jit_register_enif/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_logical_mutex_token_signal_success/2","ref":"Beaver.MLIR.CAPI.html#beaver_raw_logical_mutex_token_signal_success/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_mlir_type_of_enif_obj/2","ref":"Beaver.MLIR.CAPI.html#beaver_raw_mlir_type_of_enif_obj/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_read_opaque_ptr/2","ref":"Beaver.MLIR.CAPI.html#beaver_raw_read_opaque_ptr/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_registered_dialects/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_registered_dialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_registered_ops/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_registered_ops/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_run_pm_on_op_async/2","ref":"Beaver.MLIR.CAPI.html#beaver_raw_run_pm_on_op_async/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_string_printer_callback/0","ref":"Beaver.MLIR.CAPI.html#beaver_raw_string_printer_callback/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_string_printer_flush/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_string_printer_flush/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_AffineMap/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_AffineMap/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Attribute/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Attribute/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Diagnostic/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Diagnostic/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Identifier/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Identifier/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Location/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Location/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Operation/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Operation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_OperationBytecode/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_OperationBytecode/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_OperationGeneric/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_OperationGeneric/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_OperationSpecialized/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_OperationSpecialized/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_OpPassManager/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_OpPassManager/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_StringRef/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_StringRef/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Type/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Type/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaver_raw_to_string_Value/1","ref":"Beaver.MLIR.CAPI.html#beaver_raw_to_string_Value/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverContextAddWork/3","ref":"Beaver.MLIR.CAPI.html#beaverContextAddWork/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverContextGetDialects/3","ref":"Beaver.MLIR.CAPI.html#beaverContextGetDialects/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverContextGetOps/3","ref":"Beaver.MLIR.CAPI.html#beaverContextGetOps/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverGetReassociationIndicesForReshape/2","ref":"Beaver.MLIR.CAPI.html#beaverGetReassociationIndicesForReshape/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIRDLGetDefinedAttr/3","ref":"Beaver.MLIR.CAPI.html#beaverIRDLGetDefinedAttr/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIRDLGetDefinedType/3","ref":"Beaver.MLIR.CAPI.html#beaverIRDLGetDefinedType/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullAttribute/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullAttribute/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullBlock/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullContext/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullDialect/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullDialect/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullDialectRegistry/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullDialectRegistry/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullExecutionEngine/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullExecutionEngine/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullLocation/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullLocation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullModule/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullModule/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullOperation/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullRegion/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullRegion/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullSymbolTable/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullSymbolTable/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullType/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsNullValue/1","ref":"Beaver.MLIR.CAPI.html#beaverIsNullValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverIsOpNameTerminator/2","ref":"Beaver.MLIR.CAPI.html#beaverIsOpNameTerminator/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverLocationPrint/3","ref":"Beaver.MLIR.CAPI.html#beaverLocationPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverLogicalResultFailure/0","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultFailure/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverLogicalResultIsFailure/1","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultIsFailure/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverLogicalResultIsSuccess/1","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultIsSuccess/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverLogicalResultSuccess/0","ref":"Beaver.MLIR.CAPI.html#beaverLogicalResultSuccess/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverModuleApplyPatternsAndFoldGreedily/2","ref":"Beaver.MLIR.CAPI.html#beaverModuleApplyPatternsAndFoldGreedily/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverModuleApplyPatternsAndFoldGreedilyWithDiagnostics/3","ref":"Beaver.MLIR.CAPI.html#beaverModuleApplyPatternsAndFoldGreedilyWithDiagnostics/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverNamedAttributeGetAttribute/1","ref":"Beaver.MLIR.CAPI.html#beaverNamedAttributeGetAttribute/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverNamedAttributeGetName/1","ref":"Beaver.MLIR.CAPI.html#beaverNamedAttributeGetName/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationDumpGeneric/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationDumpGeneric/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationGetAttribute/2","ref":"Beaver.MLIR.CAPI.html#beaverOperationGetAttribute/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationGetName/2","ref":"Beaver.MLIR.CAPI.html#beaverOperationGetName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationPrintGenericOpForm/3","ref":"Beaver.MLIR.CAPI.html#beaverOperationPrintGenericOpForm/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationPrintSpecializedFrom/3","ref":"Beaver.MLIR.CAPI.html#beaverOperationPrintSpecializedFrom/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetContext/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetLocation/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetLocation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetName/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetName/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumAttributes/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumAttributes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumOperands/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumOperands/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumRegions/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumRegions/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverOperationStateGetNumResults/1","ref":"Beaver.MLIR.CAPI.html#beaverOperationStateGetNumResults/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassCreate/13","ref":"Beaver.MLIR.CAPI.html#beaverPassCreate/13"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassGetArgument/1","ref":"Beaver.MLIR.CAPI.html#beaverPassGetArgument/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassGetDescription/1","ref":"Beaver.MLIR.CAPI.html#beaverPassGetDescription/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassGetName/1","ref":"Beaver.MLIR.CAPI.html#beaverPassGetName/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassManagerEnableTiming/1","ref":"Beaver.MLIR.CAPI.html#beaverPassManagerEnableTiming/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverPassManagerGetContext/1","ref":"Beaver.MLIR.CAPI.html#beaverPassManagerGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverStringRefGetData/1","ref":"Beaver.MLIR.CAPI.html#beaverStringRefGetData/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.beaverStringRefGetLength/1","ref":"Beaver.MLIR.CAPI.html#beaverStringRefGetLength/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.load_nif/0","ref":"Beaver.MLIR.CAPI.html#load_nif/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineAddExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineAddExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineBinaryOpExprGetLHS/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineBinaryOpExprGetLHS/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineBinaryOpExprGetRHS/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineBinaryOpExprGetRHS/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineCeilDivExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineCeilDivExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineConstantExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineConstantExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineConstantExprGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineConstantExprGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineDimExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineDimExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineDimExprGetPosition/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineDimExprGetPosition/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprCompose/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprCompose/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprDump/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprGetLargestKnownDivisor/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprGetLargestKnownDivisor/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAAdd/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAAdd/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsABinary/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsABinary/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsACeilDiv/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsACeilDiv/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAConstant/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAConstant/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsADim/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsADim/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAFloorDiv/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAFloorDiv/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAMod/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAMod/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsAMul/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsAMul/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsASymbol/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsASymbol/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsFunctionOfDim/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsFunctionOfDim/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsMultipleOf/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsMultipleOf/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsPureAffine/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsPureAffine/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprIsSymbolicOrConstant/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprIsSymbolicOrConstant/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineExprPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineExprPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineFloorDivExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineFloorDivExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGet/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapCompressUnusedSymbols/4","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapCompressUnusedSymbols/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapConstantGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapConstantGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapDump/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapEmptyGet/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapEmptyGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGet/5","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetMajorSubMap/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetMajorSubMap/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetMinorSubMap/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetMinorSubMap/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumDims/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumDims/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumInputs/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumInputs/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumResults/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumResults/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetNumSymbols/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetNumSymbols/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetResult/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetResult/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetSingleConstantResult/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetSingleConstantResult/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapGetSubMap/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapGetSubMap/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsEmpty/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsEmpty/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsIdentity/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsIdentity/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsMinorIdentity/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsMinorIdentity/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsPermutation/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsPermutation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsProjectedPermutation/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsProjectedPermutation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapIsSingleConstant/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapIsSingleConstant/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapMinorIdentityGet/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapMinorIdentityGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapMultiDimIdentityGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapMultiDimIdentityGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapPermutationGet/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapPermutationGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapReplace/5","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapReplace/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMapZeroResultGet/3","ref":"Beaver.MLIR.CAPI.html#mlirAffineMapZeroResultGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineModExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineModExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineMulExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineMulExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineSymbolExprGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAffineSymbolExprGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAffineSymbolExprGetPosition/1","ref":"Beaver.MLIR.CAPI.html#mlirAffineSymbolExprGetPosition/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAnyQuantizedTypeGet/5","ref":"Beaver.MLIR.CAPI.html#mlirAnyQuantizedTypeGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirApplyPatternsAndFoldGreedily/3","ref":"Beaver.MLIR.CAPI.html#mlirApplyPatternsAndFoldGreedily/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirArrayAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetNumElements/1","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetNumElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirArrayAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirArrayAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAsmStateCreateForOperation/2","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateCreateForOperation/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAsmStateCreateForValue/2","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateCreateForValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAsmStateDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirAsmStateDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeDump/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirAttributeEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeGetDialect/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetDialect/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeGetNull/0","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetNull/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeGetType/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeGetTypeID/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeGetTypeID/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAAffineMap/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAAffineMap/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAArray/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAArray/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsABool/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsABool/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseBoolArray/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseBoolArray/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseF32Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseF32Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseF64Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseF64Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseFPElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseFPElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI8Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI8Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI16Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI16Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI32Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI32Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseI64Array/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseI64Array/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseIntElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseIntElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADenseResourceElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADenseResourceElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsADictionary/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsADictionary/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAEmitCCmpPredicate/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAEmitCCmpPredicate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAEmitCOpaque/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAEmitCOpaque/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAFlatSymbolRef/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAFlatSymbolRef/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAFloat/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAFloat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAGPUObjectAttr/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAGPUObjectAttr/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAInteger/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAInteger/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAIntegerSet/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAIntegerSet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsALocation/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsALocation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAOpaque/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAOpaque/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsASparseElements/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASparseElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsASparseTensorEncodingAttr/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASparseTensorEncodingAttr/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAStridedLayout/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAStridedLayout/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAString/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAString/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsASymbolRef/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsASymbolRef/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAType/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeIsAUnit/1","ref":"Beaver.MLIR.CAPI.html#mlirAttributeIsAUnit/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeParseGet/2","ref":"Beaver.MLIR.CAPI.html#mlirAttributeParseGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributeParseGetWithDiagnostics/3","ref":"Beaver.MLIR.CAPI.html#mlirAttributeParseGetWithDiagnostics/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirAttributePrint/3","ref":"Beaver.MLIR.CAPI.html#mlirAttributePrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBF16TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirBF16TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBFloat16TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirBFloat16TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockAddArgument/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockAddArgument/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockAppendOwnedOperation/2","ref":"Beaver.MLIR.CAPI.html#mlirBlockAppendOwnedOperation/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockArgumentGetArgNumber/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentGetArgNumber/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockArgumentGetOwner/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentGetOwner/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockArgumentSetType/2","ref":"Beaver.MLIR.CAPI.html#mlirBlockArgumentSetType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockCreate/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockCreate/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockDetach/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockDetach/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirBlockEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockEraseArgument/2","ref":"Beaver.MLIR.CAPI.html#mlirBlockEraseArgument/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetArgument/2","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetArgument/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetFirstOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetFirstOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetNextInRegion/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetNextInRegion/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetNumArguments/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetNumArguments/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetParentOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetParentOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetParentRegion/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetParentRegion/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockGetTerminator/1","ref":"Beaver.MLIR.CAPI.html#mlirBlockGetTerminator/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockInsertArgument/4","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertArgument/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperation/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperation/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperationAfter/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperationAfter/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockInsertOwnedOperationBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockInsertOwnedOperationBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBlockPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirBlockPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBoolAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirBoolAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBoolAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirBoolAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigDesiredEmitVersion/2","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigDesiredEmitVersion/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirBytecodeWriterConfigDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirBytecodeWriterConfigDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGet/3","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGetMax/1","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGetMax/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCalibratedQuantizedTypeGetMin/1","ref":"Beaver.MLIR.CAPI.html#mlirCalibratedQuantizedTypeGetMin/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirComplexTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirComplexTypeGetElementType/1","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGetElementType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirComplexTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirComplexTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextAppendDialectRegistry/2","ref":"Beaver.MLIR.CAPI.html#mlirContextAppendDialectRegistry/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextAttachDiagnosticHandler/4","ref":"Beaver.MLIR.CAPI.html#mlirContextAttachDiagnosticHandler/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirContextCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextCreateWithRegistry/2","ref":"Beaver.MLIR.CAPI.html#mlirContextCreateWithRegistry/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextCreateWithThreading/1","ref":"Beaver.MLIR.CAPI.html#mlirContextCreateWithThreading/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirContextDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextDetachDiagnosticHandler/2","ref":"Beaver.MLIR.CAPI.html#mlirContextDetachDiagnosticHandler/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextEnableMultithreading/2","ref":"Beaver.MLIR.CAPI.html#mlirContextEnableMultithreading/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirContextEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextGetAllowUnregisteredDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirContextGetAllowUnregisteredDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextGetNumLoadedDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirContextGetNumLoadedDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextGetNumRegisteredDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirContextGetNumRegisteredDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextGetOrLoadDialect/2","ref":"Beaver.MLIR.CAPI.html#mlirContextGetOrLoadDialect/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextIsRegisteredOperation/2","ref":"Beaver.MLIR.CAPI.html#mlirContextIsRegisteredOperation/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextLoadAllAvailableDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirContextLoadAllAvailableDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextSetAllowUnregisteredDialects/2","ref":"Beaver.MLIR.CAPI.html#mlirContextSetAllowUnregisteredDialects/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirContextSetThreadPool/2","ref":"Beaver.MLIR.CAPI.html#mlirContextSetThreadPool/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncFuncToAsyncRuntime/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncFuncToAsyncRuntime/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncParallelFor/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncParallelFor/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimePolicyBasedRefCounting/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimePolicyBasedRefCounting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimeRefCounting/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimeRefCounting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncRuntimeRefCountingOpt/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncRuntimeRefCountingOpt/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateAsyncAsyncToAsyncRuntime/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateAsyncAsyncToAsyncRuntime/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToAMDGPUConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToAMDGPUConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToArmSMEConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToArmSMEConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionArithToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionArithToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAffineForToGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAffineForToGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAffineToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAffineToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAMDGPUToROCDL/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAMDGPUToROCDL/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArithToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArithToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArithToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArithToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmNeon2dToIntr/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmNeon2dToIntr/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmSMEToLLVM/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmSMEToLLVM/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertArmSMEToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertArmSMEToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertAsyncToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertAsyncToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertBufferizationToMemRef/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertBufferizationToMemRef/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToLibm/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToLibm/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertComplexToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertComplexToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertControlFlowToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertControlFlowToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertControlFlowToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertControlFlowToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertFuncToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertFuncToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGPUToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGPUToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToLLVMSPVOps/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToLLVMSPVOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToNVVMOps/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToNVVMOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertGpuOpsToROCDLOps/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertGpuOpsToROCDLOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertIndexToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertIndexToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertIndexToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertIndexToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertLinalgToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertLinalgToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToFuncs/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToFuncs/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToLibm/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToLibm/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToROCDL/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToROCDL/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMathToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMathToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMemRefToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMemRefToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMemRefToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMemRefToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertMeshToMPIPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertMeshToMPIPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertNVGPUToNVVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertNVGPUToNVVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertNVVMToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertNVVMToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertOpenACCToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertOpenACCToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertOpenMPToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertOpenMPToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertParallelLoopToGpu/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertParallelLoopToGpu/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertPDLToPDLInterp/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertPDLToPDLInterp/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertSCFToOpenMPPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertSCFToOpenMPPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertShapeConstraints/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertShapeConstraints/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertShapeToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertShapeToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertSPIRVToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertSPIRVToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertTensorToLinalg/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertTensorToLinalg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertTensorToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertTensorToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToArmSME/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToArmSME/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionConvertVectorToXeGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionConvertVectorToXeGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionFinalizeMemRefToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionFinalizeMemRefToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionGpuToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionGpuToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionLiftControlFlowToSCFPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionLiftControlFlowToSCFPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionLowerHostCodeToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionLowerHostCodeToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionMapMemRefStorageClass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionMapMemRefStorageClass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionReconcileUnrealizedCasts/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionReconcileUnrealizedCasts/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToControlFlow/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToControlFlow/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionSCFToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSCFToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionSetLLVMModuleDataLayoutPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionSetLLVMModuleDataLayoutPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToArith/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToArith/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToLinalg/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToLinalg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToLinalgNamed/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToLinalgNamed/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToMLProgram/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToMLProgram/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionTosaToTensor/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionTosaToTensor/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionUBToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionUBToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateConversionUBToSPIRVConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateConversionUBToSPIRVConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateExternalPass/9","ref":"Beaver.MLIR.CAPI.html#mlirCreateExternalPass/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuAsyncRegionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuAsyncRegionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuDecomposeMemrefsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuDecomposeMemrefsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuEliminateBarriers/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuEliminateBarriers/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuKernelOutlining/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuKernelOutlining/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuLaunchSinkIndexComputations/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuLaunchSinkIndexComputations/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuMapParallelLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuMapParallelLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuModuleToBinaryPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuModuleToBinaryPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuNVVMAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuNVVMAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuROCDLAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuROCDLAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateGPUGpuSPIRVAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateGPUGpuSPIRVAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertElementwiseToLinalgPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertElementwiseToLinalgPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToAffineLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToAffineLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgConvertLinalgToParallelLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgConvertLinalgToParallelLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgBlockPackMatmul/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgBlockPackMatmul/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgDetensorizePass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgDetensorizePass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgElementwiseOpFusionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgElementwiseOpFusionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgFoldUnitExtentDimsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgFoldUnitExtentDimsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgGeneralizeNamedOpsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgGeneralizeNamedOpsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgInlineScalarOperandsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgInlineScalarOperandsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgNamedOpConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgNamedOpConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateLinalgLinalgSpecializeGenericOpsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateLinalgLinalgSpecializeGenericOpsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerForeachToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerForeachToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerSparseIterationToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerSparseIterationToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorLowerSparseOpsToForeach/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorLowerSparseOpsToForeach/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorPreSparsificationRewrite/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorPreSparsificationRewrite/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseAssembler/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseAssembler/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseBufferRewrite/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseBufferRewrite/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseGPUCodegen/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseGPUCodegen/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseReinterpretMap/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseReinterpretMap/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseSpaceCollapse/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseSpaceCollapse/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseTensorCodegen/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseTensorCodegen/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseTensorConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseTensorConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparseVectorization/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparseVectorization/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparsificationAndBufferization/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparsificationAndBufferization/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorSparsificationPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorSparsificationPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorStageSparseOperations/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorStageSparseOperations/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateSparseTensorStorageSpecifierToLLVM/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateSparseTensorStorageSpecifierToLLVM/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCanonicalizer/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCanonicalizer/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCompositeFixedPointPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCompositeFixedPointPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsControlFlowSink/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsControlFlowSink/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsCSE/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsCSE/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsGenerateRuntimeVerification/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsGenerateRuntimeVerification/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsInliner/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsInliner/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLocationSnapshot/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLocationSnapshot/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLoopInvariantCodeMotion/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLoopInvariantCodeMotion/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsLoopInvariantSubsetHoisting/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsLoopInvariantSubsetHoisting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsMem2Reg/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsMem2Reg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsPrintIRPass/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsPrintIRPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsPrintOpStats/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsPrintOpStats/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsRemoveDeadValues/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsRemoveDeadValues/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSCCP/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSCCP/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSROA/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSROA/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsStripDebugInfo/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsStripDebugInfo/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSymbolDCE/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSymbolDCE/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsSymbolPrivatize/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsSymbolPrivatize/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsTopologicalSort/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsTopologicalSort/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirCreateTransformsViewOpGraph/0","ref":"Beaver.MLIR.CAPI.html#mlirCreateTransformsViewOpGraph/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseArrayAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirDenseArrayAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseArrayGetNumElements/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseArrayGetNumElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseBoolArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseBoolArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseBoolResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseBoolResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseDoubleResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseDoubleResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBFloat16Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBFloat16Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBoolGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBoolGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrBoolSplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrBoolSplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrDoubleGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrDoubleGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrDoubleSplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrDoubleSplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloat16Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloat16Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloatGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloatGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrFloatSplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrFloatSplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetBoolSplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetBoolSplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetBoolValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetBoolValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetDoubleSplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetDoubleSplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetDoubleValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetDoubleValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetFloatSplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetFloatSplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetFloatValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetFloatValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt8SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt8SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt8Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt8Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt16Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt16Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt32SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt32SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt32Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt32Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt64SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt64SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetInt64Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetInt64Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetRawData/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetRawData/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetSplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetSplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetStringSplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetStringSplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetStringValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetStringValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt8SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt8SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt8Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt8Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt16Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt16Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt32SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt32SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt32Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt32Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt64SplatValue/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt64SplatValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrGetUInt64Value/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrGetUInt64Value/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt8Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt8Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt8SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt8SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt16Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt16Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt32Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt32Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt32SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt32SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt64Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt64Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrInt64SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrInt64SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrIsSplat/1","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrIsSplat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrRawBufferGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrRawBufferGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrReshapeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrReshapeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrSplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrSplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrStringGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrStringGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt8Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt8Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt8SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt8SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt16Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt16Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt32Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt32Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt32SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt32SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt64Get/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt64Get/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseElementsAttrUInt64SplatGet/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseElementsAttrUInt64SplatGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseF32ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseF32ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseF32ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseF32ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseF64ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseF64ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseF64ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseF64ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseFloatResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseFloatResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI8ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseI8ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI8ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseI8ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI16ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseI16ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI16ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseI16ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI32ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseI32ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI32ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseI32ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI64ArrayGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDenseI64ArrayGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseI64ArrayGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseI64ArrayGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseInt8ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt8ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseInt16ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt16ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseInt32ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt32ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseInt64ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseInt64ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseIntOrFPElementsAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirDenseIntOrFPElementsAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseUInt8ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt8ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseUInt16ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt16ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseUInt32ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt32ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDenseUInt64ResourceElementsAttrGetValue/2","ref":"Beaver.MLIR.CAPI.html#mlirDenseUInt64ResourceElementsAttrGetValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetLocation/1","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetLocation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetNote/2","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetNote/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetNumNotes/1","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetNumNotes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDiagnosticGetSeverity/1","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticGetSeverity/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDiagnosticPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirDiagnosticPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirDialectEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirDialectGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectGetNamespace/1","ref":"Beaver.MLIR.CAPI.html#mlirDialectGetNamespace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectHandleGetNamespace/1","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleGetNamespace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectHandleInsertDialect/2","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleInsertDialect/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectHandleLoadDialect/2","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleLoadDialect/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectHandleRegisterDialect/2","ref":"Beaver.MLIR.CAPI.html#mlirDialectHandleRegisterDialect/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectRegistryCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirDialectRegistryCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDialectRegistryDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirDialectRegistryDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetElement/2","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetElement/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetElementByName/2","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetElementByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetNumElements/1","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetNumElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDictionaryAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirDictionaryAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirDisctinctAttrCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirDisctinctAttrCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirElementsAttrGetNumElements/1","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrGetNumElements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirElementsAttrGetValue/3","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrGetValue/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirElementsAttrIsValidIndex/3","ref":"Beaver.MLIR.CAPI.html#mlirElementsAttrIsValidIndex/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCArrayTypeGet/3","ref":"Beaver.MLIR.CAPI.html#mlirEmitCArrayTypeGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCArrayTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCArrayTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCCmpPredicateAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirEmitCCmpPredicateAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCCmpPredicateAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCCmpPredicateAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCCmpPredicateAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCCmpPredicateAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCLValueTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCLValueTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCLValueTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCLValueTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCOpaqueAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirEmitCOpaqueAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCOpaqueAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCOpaqueAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCOpaqueAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCOpaqueAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCOpaqueTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirEmitCOpaqueTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCOpaqueTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCOpaqueTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCPointerTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCPointerTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCPointerTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCPointerTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCPtrDiffTTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCPtrDiffTTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCPtrDiffTTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCPtrDiffTTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCSignedSizeTTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCSignedSizeTTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCSignedSizeTTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCSignedSizeTTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCSizeTTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirEmitCSizeTTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitCSizeTTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirEmitCSizeTTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEmitError/2","ref":"Beaver.MLIR.CAPI.html#mlirEmitError/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirEnableGlobalDebug/1","ref":"Beaver.MLIR.CAPI.html#mlirEnableGlobalDebug/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineCreate/5","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineCreate/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineCreateWithDiagnostics/6","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineCreateWithDiagnostics/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineDumpToObjectFile/2","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineDumpToObjectFile/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked/3","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked_dirty_cpu/3","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked_dirty_cpu/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineInvokePacked_dirty_io/3","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineInvokePacked_dirty_io/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineLookup/2","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineLookup/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineLookupPacked/2","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineLookupPacked/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExecutionEngineRegisterSymbol/3","ref":"Beaver.MLIR.CAPI.html#mlirExecutionEngineRegisterSymbol/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirExternalPassSignalFailure/1","ref":"Beaver.MLIR.CAPI.html#mlirExternalPassSignalFailure/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirF16TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirF16TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirF32TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirF32TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirF64TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirF64TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFlatSymbolRefAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirFlatSymbolRefAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFlatSymbolRefAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirFlatSymbolRefAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat4E2M1FNTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat4E2M1FNTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat4E2M1FNTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat4E2M1FNTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat6E2M3FNTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat6E2M3FNTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat6E2M3FNTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat6E2M3FNTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat6E3M2FNTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat6E3M2FNTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat6E3M2FNTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat6E3M2FNTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E3M4TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E3M4TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E3M4TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E3M4TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3B11FNUZTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3B11FNUZTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3B11FNUZTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3B11FNUZTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNUZTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNUZTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3FNUZTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3FNUZTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E4M3TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E4M3TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2FNUZTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2FNUZTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2FNUZTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2FNUZTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E5M2TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E5M2TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E8M0FNUTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E8M0FNUTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat8E8M0FNUTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat8E8M0FNUTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat16TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat16TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat32TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat32TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloat64TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloat64TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatAttrDoubleGet/3","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrDoubleGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatAttrDoubleGetChecked/3","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrDoubleGetChecked/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatAttrDoubleGetCheckedWithDiagnostics/4","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrDoubleGetCheckedWithDiagnostics/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatAttrGetValueDouble/1","ref":"Beaver.MLIR.CAPI.html#mlirFloatAttrGetValueDouble/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatTF32TypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFloatTF32TypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFloatTypeGetWidth/1","ref":"Beaver.MLIR.CAPI.html#mlirFloatTypeGetWidth/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFreezeRewritePattern/1","ref":"Beaver.MLIR.CAPI.html#mlirFreezeRewritePattern/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFrozenRewritePatternSetDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirFrozenRewritePatternSetDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFuncSetArgAttr/4","ref":"Beaver.MLIR.CAPI.html#mlirFuncSetArgAttr/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGet/5","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetInput/2","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetInput/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetNumInputs/1","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetNumInputs/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetNumResults/1","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetNumResults/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetResult/2","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetResult/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirFunctionTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirFunctionTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__amdgpu__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__amdgpu__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__arith__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__arith__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__async__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__async__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__cf__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__cf__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__elixir__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__elixir__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__emitc__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__emitc__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__func__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__func__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__gpu__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__gpu__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__irdl__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__irdl__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__linalg__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__linalg__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__llvm__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__llvm__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__math__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__math__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__memref__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__memref__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__ml_program__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__ml_program__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__nvgpu__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__nvgpu__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__nvvm__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__nvvm__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__omp__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__omp__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__pdl__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__pdl__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__quant__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__quant__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__rocdl__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__rocdl__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__scf__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__scf__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__shape__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__shape__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__sparse_tensor__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__sparse_tensor__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__spirv__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__spirv__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__tensor__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__tensor__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__transform__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__transform__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGetDialectHandle__vector__/0","ref":"Beaver.MLIR.CAPI.html#mlirGetDialectHandle__vector__/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUAsyncTokenTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUAsyncTokenTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGet/5","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetFormat/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetFormat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetKernels/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetKernels/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetObject/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetObject/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetProperties/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetProperties/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetTarget/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetTarget/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrGetWithKernels/6","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrGetWithKernels/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrHasKernels/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrHasKernels/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirGPUObjectAttrHasProperties/1","ref":"Beaver.MLIR.CAPI.html#mlirGPUObjectAttrHasProperties/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIdentifierEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIdentifierGet/2","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIdentifierGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIdentifierPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIdentifierStr/1","ref":"Beaver.MLIR.CAPI.html#mlirIdentifierStr/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIndexTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirIndexTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIndexTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirIndexTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirInferShapedTypeOpInterfaceInferReturnTypes/11","ref":"Beaver.MLIR.CAPI.html#mlirInferShapedTypeOpInterfaceInferReturnTypes/11"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirInferShapedTypeOpInterfaceTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirInferShapedTypeOpInterfaceTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirInferTypeOpInterfaceInferReturnTypes/11","ref":"Beaver.MLIR.CAPI.html#mlirInferTypeOpInterfaceInferReturnTypes/11"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirInferTypeOpInterfaceTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirInferTypeOpInterfaceTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueInt/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueInt/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueSInt/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueSInt/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerAttrGetValueUInt/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerAttrGetValueUInt/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetAttrGet/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetAttrGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetDump/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetEmptyGet/3","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetEmptyGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGet/6","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGet/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetConstraint/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetConstraint/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumConstraints/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumConstraints/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumDims/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumDims/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumEqualities/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumEqualities/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumInequalities/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumInequalities/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumInputs/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumInputs/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetGetNumSymbols/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetGetNumSymbols/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetIsCanonicalEmpty/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetIsCanonicalEmpty/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetIsConstraintEq/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetIsConstraintEq/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerSetReplaceGet/5","ref":"Beaver.MLIR.CAPI.html#mlirIntegerSetReplaceGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeGetWidth/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeGetWidth/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsSigned/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsSigned/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsSignless/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsSignless/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeIsUnsigned/1","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeIsUnsigned/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeSignedGet/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeSignedGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIntegerTypeUnsignedGet/2","ref":"Beaver.MLIR.CAPI.html#mlirIntegerTypeUnsignedGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIRRewriterCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIRRewriterCreateFromOp/1","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterCreateFromOp/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIRRewriterDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirIRRewriterDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIsCurrentDebugType/1","ref":"Beaver.MLIR.CAPI.html#mlirIsCurrentDebugType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirIsGlobalDebugEnabled/0","ref":"Beaver.MLIR.CAPI.html#mlirIsGlobalDebugEnabled/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLinalgFillBuiltinNamedOpRegion/1","ref":"Beaver.MLIR.CAPI.html#mlirLinalgFillBuiltinNamedOpRegion/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMArrayTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMArrayTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMArrayTypeGetElementType/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMArrayTypeGetElementType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMCConvAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMCConvAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMComdatAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMComdatAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIAnnotationAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIAnnotationAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIBasicTypeAttrGet/5","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIBasicTypeAttrGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDICompileUnitAttrGet/8","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompileUnitAttrGet/8"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDICompositeTypeAttrGet/18","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompositeTypeAttrGet/18"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDICompositeTypeAttrGetRecSelf/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDICompositeTypeAttrGetRecSelf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIDerivedTypeAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIDerivedTypeAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIDerivedTypeAttrGetBaseType/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIDerivedTypeAttrGetBaseType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIExpressionAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIExpressionAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIExpressionElemAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIExpressionElemAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIFileAttrGet/3","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIFileAttrGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIFlagsAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIFlagsAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIImportedEntityAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIImportedEntityAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDILexicalBlockAttrGet/5","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILexicalBlockAttrGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDILexicalBlockFileAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILexicalBlockFileAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDILocalVariableAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDILocalVariableAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIModuleAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIModuleAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIModuleAttrGetScope/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIModuleAttrGetScope/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDINullTypeAttrGet/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDINullTypeAttrGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDIStringTypeAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDIStringTypeAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGet/17","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGet/17"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetCompileUnit/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetCompileUnit/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetFile/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetFile/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetLine/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetLine/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetRecSelf/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetRecSelf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetScope/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetScope/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetScopeLine/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetScopeLine/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubprogramAttrGetType/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubprogramAttrGetType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMDISubroutineTypeAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMDISubroutineTypeAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMFunctionTypeGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMFunctionTypeGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMFunctionTypeGetInput/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMFunctionTypeGetInput/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMFunctionTypeGetNumInputs/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMFunctionTypeGetNumInputs/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMLinkageAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMLinkageAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMPointerTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMPointerTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMPointerTypeGetAddressSpace/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMPointerTypeGetAddressSpace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetElementType/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetElementType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetIdentifier/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetIdentifier/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeGetNumElementTypes/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeGetNumElementTypes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIdentifiedGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIdentifiedGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIdentifiedNewGet/5","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIdentifiedNewGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsLiteral/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsLiteral/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsOpaque/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsOpaque/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeIsPacked/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeIsPacked/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeLiteralGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeLiteralGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeLiteralGetChecked/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeLiteralGetChecked/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeLiteralGetCheckedWithDiagnostics/5","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeLiteralGetCheckedWithDiagnostics/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeOpaqueGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeOpaqueGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMStructTypeSetBody/4","ref":"Beaver.MLIR.CAPI.html#mlirLLVMStructTypeSetBody/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLLVMVoidTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirLLVMVoidTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLlvmThreadPoolCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirLlvmThreadPoolCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLlvmThreadPoolDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirLlvmThreadPoolDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLoadIRDLDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirLoadIRDLDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationCallSiteGet/2","ref":"Beaver.MLIR.CAPI.html#mlirLocationCallSiteGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirLocationEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationFileLineColGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLocationFileLineColGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationFileLineColRangeGet/6","ref":"Beaver.MLIR.CAPI.html#mlirLocationFileLineColRangeGet/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationFromAttribute/1","ref":"Beaver.MLIR.CAPI.html#mlirLocationFromAttribute/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationFusedGet/4","ref":"Beaver.MLIR.CAPI.html#mlirLocationFusedGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationGetAttribute/1","ref":"Beaver.MLIR.CAPI.html#mlirLocationGetAttribute/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirLocationGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationNameGet/3","ref":"Beaver.MLIR.CAPI.html#mlirLocationNameGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirLocationPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirLocationUnknownGet/1","ref":"Beaver.MLIR.CAPI.html#mlirLocationUnknownGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeContiguousGet/4","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeContiguousGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeContiguousGetChecked/5","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeContiguousGetChecked/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeContiguousGetCheckedWithDiagnostics/6","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeContiguousGetCheckedWithDiagnostics/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGet/5","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetAffineMap/1","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetAffineMap/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetChecked/6","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetChecked/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetCheckedWithDiagnostics/7","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetCheckedWithDiagnostics/7"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetLayout/1","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetLayout/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetMemorySpace/1","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetMemorySpace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetStridesAndOffset/3","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetStridesAndOffset/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMemRefTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirMemRefTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirMergeSymbolsIntoFromClone/2","ref":"Beaver.MLIR.CAPI.html#mlirMergeSymbolsIntoFromClone/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleCreateEmpty/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleCreateEmpty/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleCreateParse/2","ref":"Beaver.MLIR.CAPI.html#mlirModuleCreateParse/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleCreateParseWithDiagnostics/3","ref":"Beaver.MLIR.CAPI.html#mlirModuleCreateParseWithDiagnostics/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleFromOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleFromOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleGetBody/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetBody/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirModuleGetOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirModuleGetOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirNamedAttributeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirNamedAttributeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirNoneTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirNoneTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirNoneTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirNoneTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirNVGPUTensorMapDescriptorTypeGet/6","ref":"Beaver.MLIR.CAPI.html#mlirNVGPUTensorMapDescriptorTypeGet/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGet/5","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGet/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetData/1","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetData/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetDialectNamespace/1","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetDialectNamespace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGet/3","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetData/1","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetData/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetDialectNamespace/1","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetDialectNamespace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpaqueTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirOpaqueTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationClone/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationClone/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationCreateParse/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationCreateParse/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationDump/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetAttribute/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetAttribute/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetBlock/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetDiscardableAttribute/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetDiscardableAttribute/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetDiscardableAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetDiscardableAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetFirstRegion/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetFirstRegion/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetInherentAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetInherentAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetLocation/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetLocation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetName/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetName/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNextInBlock/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNextInBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumAttributes/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumAttributes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumDiscardableAttributes/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumDiscardableAttributes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumOperands/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumOperands/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumRegions/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumRegions/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumResults/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumResults/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetNumSuccessors/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetNumSuccessors/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetOperand/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetOperand/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetParentOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetParentOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetRegion/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetRegion/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetResult/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetResult/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetSuccessor/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetSuccessor/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationGetTypeID/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationGetTypeID/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationHasInherentAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationHasInherentAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationImplementsInterface/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationImplementsInterface/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationImplementsInterfaceStatic/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationImplementsInterfaceStatic/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationMoveAfter/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationMoveAfter/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationMoveBefore/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationMoveBefore/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationPrint/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationPrintWithFlags/4","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrintWithFlags/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationPrintWithState/4","ref":"Beaver.MLIR.CAPI.html#mlirOperationPrintWithState/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationRemoveAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationRemoveDiscardableAttributeByName/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveDiscardableAttributeByName/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationRemoveFromParent/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationRemoveFromParent/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetAttributeByName/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetAttributeByName/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetDiscardableAttributeByName/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetDiscardableAttributeByName/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetInherentAttributeByName/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetInherentAttributeByName/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetOperand/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetOperand/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetOperands/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetOperands/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationSetSuccessor/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationSetSuccessor/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateAddAttributes/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddAttributes/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateAddOperands/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddOperands/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateAddOwnedRegions/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddOwnedRegions/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateAddResults/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddResults/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateAddSuccessors/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateAddSuccessors/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateEnableResultTypeInference/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateEnableResultTypeInference/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationStateGet/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationStateGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationVerify/1","ref":"Beaver.MLIR.CAPI.html#mlirOperationVerify/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationVerifyWithDiagnostics/2","ref":"Beaver.MLIR.CAPI.html#mlirOperationVerifyWithDiagnostics/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationWalk/4","ref":"Beaver.MLIR.CAPI.html#mlirOperationWalk/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationWriteBytecode/3","ref":"Beaver.MLIR.CAPI.html#mlirOperationWriteBytecode/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOperationWriteBytecodeWithConfig/4","ref":"Beaver.MLIR.CAPI.html#mlirOperationWriteBytecodeWithConfig/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpOperandGetNextUse/1","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetNextUse/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpOperandGetOperandNumber/1","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetOperandNumber/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpOperandGetOwner/1","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetOwner/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpOperandGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpOperandIsNull/1","ref":"Beaver.MLIR.CAPI.html#mlirOpOperandIsNull/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPassManagerAddOwnedPass/2","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerAddOwnedPass/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPassManagerAddPipeline/4","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerAddPipeline/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPassManagerGetNestedUnder/2","ref":"Beaver.MLIR.CAPI.html#mlirOpPassManagerGetNestedUnder/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsAssumeVerified/1","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsAssumeVerified/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsElideLargeElementsAttrs/2","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsElideLargeElementsAttrs/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsElideLargeResourceString/2","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsElideLargeResourceString/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsEnableDebugInfo/3","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsEnableDebugInfo/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsPrintGenericOpForm/1","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsPrintGenericOpForm/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsSkipRegions/1","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsSkipRegions/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpPrintingFlagsUseLocalScope/1","ref":"Beaver.MLIR.CAPI.html#mlirOpPrintingFlagsUseLocalScope/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpResultGetOwner/1","ref":"Beaver.MLIR.CAPI.html#mlirOpResultGetOwner/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirOpResultGetResultNumber/1","ref":"Beaver.MLIR.CAPI.html#mlirOpResultGetResultNumber/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirParsePassPipeline/4","ref":"Beaver.MLIR.CAPI.html#mlirParsePassPipeline/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerAddOwnedPass/2","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerAddOwnedPass/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerCreateOnOperation/2","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerCreateOnOperation/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerEnableIRPrinting/8","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerEnableIRPrinting/8"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerEnableVerifier/2","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerEnableVerifier/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerGetAsOpPassManager/1","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerGetAsOpPassManager/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerGetNestedUnder/2","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerGetNestedUnder/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPassManagerRunOnOp/2","ref":"Beaver.MLIR.CAPI.html#mlirPassManagerRunOnOp/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLAttributeTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLAttributeTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLOperationTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLOperationTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLPatternModuleDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLPatternModuleDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLPatternModuleFromModule/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLPatternModuleFromModule/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLRangeTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLRangeTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLRangeTypeGetElementType/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLRangeTypeGetElementType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLTypeTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLTypeTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPDLValueTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirPDLValueTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirPrintPassPipeline/3","ref":"Beaver.MLIR.CAPI.html#mlirPrintPassPipeline/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastExpressedToStorageType/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastExpressedToStorageType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastFromExpressedType/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastFromExpressedType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastFromStorageType/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastFromStorageType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastToExpressedType/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastToExpressedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeCastToStorageType/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeCastToStorageType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetDefaultMaximumForInteger/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetDefaultMaximumForInteger/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetDefaultMinimumForInteger/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetDefaultMinimumForInteger/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetExpressedType/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetExpressedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetFlags/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetFlags/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetQuantizedElementType/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetQuantizedElementType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetSignedFlag/0","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetSignedFlag/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageType/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeIntegralWidth/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeIntegralWidth/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeMax/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeMax/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeGetStorageTypeMin/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeGetStorageTypeMin/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeIsCompatibleExpressedType/2","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeIsCompatibleExpressedType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirQuantizedTypeIsSigned/1","ref":"Beaver.MLIR.CAPI.html#mlirQuantizedTypeIsSigned/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGet/4","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetChecked/5","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetChecked/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetCheckedWithDiagnostics/6","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetCheckedWithDiagnostics/6"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetEncoding/1","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetEncoding/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRankedTensorTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirRankedTensorTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionAppendOwnedBlock/2","ref":"Beaver.MLIR.CAPI.html#mlirRegionAppendOwnedBlock/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirRegionCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirRegionDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirRegionEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionGetFirstBlock/1","ref":"Beaver.MLIR.CAPI.html#mlirRegionGetFirstBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionGetNextInOperation/1","ref":"Beaver.MLIR.CAPI.html#mlirRegionGetNextInOperation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlock/3","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlock/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlockAfter/3","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlockAfter/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionInsertOwnedBlockBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirRegionInsertOwnedBlockBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegionTakeBody/2","ref":"Beaver.MLIR.CAPI.html#mlirRegionTakeBody/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAllDialects/1","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllDialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAllLLVMTranslations/1","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllLLVMTranslations/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAllPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAllPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncFuncToAsyncRuntime/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncFuncToAsyncRuntime/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncParallelFor/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncParallelFor/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimePolicyBasedRefCounting/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimePolicyBasedRefCounting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimeRefCounting/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimeRefCounting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncRuntimeRefCountingOpt/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncRuntimeRefCountingOpt/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncAsyncToAsyncRuntime/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncAsyncToAsyncRuntime/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterAsyncPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterAsyncPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToAMDGPUConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToAMDGPUConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToArmSMEConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToArmSMEConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionArithToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionArithToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAffineForToGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAffineForToGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAffineToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAffineToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAMDGPUToROCDL/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAMDGPUToROCDL/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArithToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArithToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArithToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArithToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmNeon2dToIntr/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmNeon2dToIntr/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmSMEToLLVM/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmSMEToLLVM/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertArmSMEToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertArmSMEToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertAsyncToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertAsyncToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertBufferizationToMemRef/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertBufferizationToMemRef/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToLibm/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToLibm/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertComplexToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertComplexToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertControlFlowToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertControlFlowToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertControlFlowToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertControlFlowToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertFuncToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertFuncToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGPUToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGPUToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToLLVMSPVOps/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToLLVMSPVOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToNVVMOps/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToNVVMOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertGpuOpsToROCDLOps/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertGpuOpsToROCDLOps/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertIndexToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertIndexToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertIndexToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertIndexToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertLinalgToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertLinalgToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToFuncs/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToFuncs/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToLibm/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToLibm/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToROCDL/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToROCDL/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMathToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMathToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMemRefToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMemRefToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMemRefToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMemRefToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertMeshToMPIPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertMeshToMPIPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertNVGPUToNVVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertNVGPUToNVVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertNVVMToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertNVVMToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertOpenACCToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertOpenACCToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertOpenMPToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertOpenMPToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertParallelLoopToGpu/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertParallelLoopToGpu/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertPDLToPDLInterp/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertPDLToPDLInterp/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertSCFToOpenMPPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertSCFToOpenMPPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertShapeConstraints/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertShapeConstraints/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertShapeToStandard/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertShapeToStandard/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertSPIRVToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertSPIRVToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertTensorToLinalg/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertTensorToLinalg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertTensorToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertTensorToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertToSPIRVPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertToSPIRVPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToArmSME/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToArmSME/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionConvertVectorToXeGPU/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionConvertVectorToXeGPU/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionFinalizeMemRefToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionFinalizeMemRefToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionGpuToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionGpuToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionLiftControlFlowToSCFPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionLiftControlFlowToSCFPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionLowerHostCodeToLLVMPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionLowerHostCodeToLLVMPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionMapMemRefStorageClass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionMapMemRefStorageClass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionReconcileUnrealizedCasts/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionReconcileUnrealizedCasts/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToControlFlow/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToControlFlow/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToEmitC/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToEmitC/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSCFToSPIRV/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSCFToSPIRV/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionSetLLVMModuleDataLayoutPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionSetLLVMModuleDataLayoutPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToArith/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToArith/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToLinalg/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToLinalg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToLinalgNamed/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToLinalgNamed/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToMLProgram/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToMLProgram/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionTosaToTensor/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionTosaToTensor/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionUBToLLVMConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionUBToLLVMConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterConversionUBToSPIRVConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterConversionUBToSPIRVConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuAsyncRegionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuAsyncRegionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuDecomposeMemrefsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuDecomposeMemrefsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuEliminateBarriers/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuEliminateBarriers/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuKernelOutlining/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuKernelOutlining/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuLaunchSinkIndexComputations/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuLaunchSinkIndexComputations/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuMapParallelLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuMapParallelLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuModuleToBinaryPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuModuleToBinaryPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuNVVMAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuNVVMAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuROCDLAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuROCDLAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUGpuSPIRVAttachTarget/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUGpuSPIRVAttachTarget/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterGPUPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterGPUPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertElementwiseToLinalgPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertElementwiseToLinalgPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToAffineLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToAffineLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgConvertLinalgToParallelLoopsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgConvertLinalgToParallelLoopsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgBlockPackMatmul/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgBlockPackMatmul/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgDetensorizePass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgDetensorizePass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgElementwiseOpFusionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgElementwiseOpFusionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgFoldUnitExtentDimsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgFoldUnitExtentDimsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgGeneralizeNamedOpsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgGeneralizeNamedOpsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgInlineScalarOperandsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgInlineScalarOperandsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgNamedOpConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgNamedOpConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgLinalgSpecializeGenericOpsPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgLinalgSpecializeGenericOpsPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterLinalgPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterLinalgPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerForeachToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerForeachToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerSparseIterationToSCF/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerSparseIterationToSCF/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorLowerSparseOpsToForeach/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorLowerSparseOpsToForeach/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorPreSparsificationRewrite/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorPreSparsificationRewrite/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseAssembler/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseAssembler/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseBufferRewrite/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseBufferRewrite/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseGPUCodegen/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseGPUCodegen/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseReinterpretMap/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseReinterpretMap/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseSpaceCollapse/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseSpaceCollapse/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseTensorCodegen/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseTensorCodegen/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseTensorConversionPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseTensorConversionPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparseVectorization/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparseVectorization/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparsificationAndBufferization/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparsificationAndBufferization/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorSparsificationPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorSparsificationPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorStageSparseOperations/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorStageSparseOperations/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterSparseTensorStorageSpecifierToLLVM/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterSparseTensorStorageSpecifierToLLVM/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCanonicalizer/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCanonicalizer/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCompositeFixedPointPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCompositeFixedPointPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsControlFlowSink/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsControlFlowSink/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsCSE/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsCSE/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsGenerateRuntimeVerification/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsGenerateRuntimeVerification/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsInliner/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsInliner/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLocationSnapshot/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLocationSnapshot/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLoopInvariantCodeMotion/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLoopInvariantCodeMotion/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsLoopInvariantSubsetHoisting/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsLoopInvariantSubsetHoisting/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsMem2Reg/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsMem2Reg/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPasses/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPasses/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPrintIRPass/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPrintIRPass/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsPrintOpStats/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsPrintOpStats/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsRemoveDeadValues/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsRemoveDeadValues/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSCCP/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSCCP/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSROA/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSROA/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsStripDebugInfo/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsStripDebugInfo/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSymbolDCE/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSymbolDCE/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsSymbolPrivatize/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsSymbolPrivatize/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsTopologicalSort/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsTopologicalSort/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRegisterTransformsViewOpGraph/0","ref":"Beaver.MLIR.CAPI.html#mlirRegisterTransformsViewOpGraph/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewritePatternSetFromPDLPatternModule/1","ref":"Beaver.MLIR.CAPI.html#mlirRewritePatternSetFromPDLPatternModule/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCancelOpModification/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCancelOpModification/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseClearInsertionPoint/1","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseClearInsertionPoint/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseClone/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseClone/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCloneRegionBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCloneRegionBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCloneWithoutRegions/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCloneWithoutRegions/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseCreateBlockBefore/5","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseCreateBlockBefore/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseEraseBlock/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseEraseBlock/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseEraseOp/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseEraseOp/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseFinalizeOpModification/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseFinalizeOpModification/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetBlock/1","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseGetInsertionBlock/1","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseGetInsertionBlock/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInlineBlockBefore/5","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInlineBlockBefore/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInlineRegionBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInlineRegionBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseInsert/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseInsert/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMergeBlocks/5","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMergeBlocks/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveBlockBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveBlockBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveOpAfter/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveOpAfter/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseMoveOpBefore/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseMoveOpBefore/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllOpUsesWithOperation/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllOpUsesWithOperation/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllOpUsesWithValueRange/4","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllOpUsesWithValueRange/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllUsesExcept/4","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllUsesExcept/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllUsesWith/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllUsesWith/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceAllValueRangeUsesWith/4","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceAllValueRangeUsesWith/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpUsesWithinBlock/5","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpUsesWithinBlock/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpWithOperation/3","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpWithOperation/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseReplaceOpWithValues/4","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseReplaceOpWithValues/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointAfter/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointAfter/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointAfterValue/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointAfterValue/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointBefore/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointBefore/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointToEnd/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointToEnd/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseSetInsertionPointToStart/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseSetInsertionPointToStart/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirRewriterBaseStartOpModification/2","ref":"Beaver.MLIR.CAPI.html#mlirRewriterBaseStartOpModification/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSetGlobalDebugType/1","ref":"Beaver.MLIR.CAPI.html#mlirSetGlobalDebugType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSetGlobalDebugTypes/2","ref":"Beaver.MLIR.CAPI.html#mlirSetGlobalDebugTypes/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDimSize/2","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDimSize/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDynamicSize/0","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDynamicSize/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetDynamicStrideOrOffset/0","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetDynamicStrideOrOffset/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetElementType/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetElementType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeGetRank/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeGetRank/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeHasRank/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeHasRank/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeHasStaticShape/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeHasStaticShape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicDim/2","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicDim/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicSize/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicSize/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirShapedTypeIsDynamicStrideOrOffset/1","ref":"Beaver.MLIR.CAPI.html#mlirShapedTypeIsDynamicStrideOrOffset/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetIndices/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetIndices/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttrGetValues/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttrGetValues/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseElementsAttribute/3","ref":"Beaver.MLIR.CAPI.html#mlirSparseElementsAttribute/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrBuildLvlType/5","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrBuildLvlType/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGet/9","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetCrdWidth/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetCrdWidth/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetDimToLvl/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetDimToLvl/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetExplicitVal/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetExplicitVal/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetImplicitVal/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetImplicitVal/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlFmt/2","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlFmt/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlToDim/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlToDim/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetLvlType/2","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetLvlType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetPosWidth/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetPosWidth/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetStructuredM/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetStructuredM/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingAttrGetStructuredN/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingAttrGetStructuredN/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSparseTensorEncodingGetLvlRank/1","ref":"Beaver.MLIR.CAPI.html#mlirSparseTensorEncodingGetLvlRank/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetNumStrides/1","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetNumStrides/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetOffset/1","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetOffset/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetStride/2","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetStride/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStridedLayoutAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirStridedLayoutAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringAttrGet/2","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringAttrTypedGet/2","ref":"Beaver.MLIR.CAPI.html#mlirStringAttrTypedGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringRefCreateFromCString/1","ref":"Beaver.MLIR.CAPI.html#mlirStringRefCreateFromCString/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirStringRefEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirStringRefEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetLeafReference/1","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetLeafReference/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetNestedReference/2","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetNestedReference/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetNumNestedReferences/1","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetNumNestedReferences/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetRootReference/1","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetRootReference/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolRefAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirSymbolRefAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableErase/2","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableErase/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableGetSymbolAttributeName/0","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableGetSymbolAttributeName/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableGetVisibilityAttributeName/0","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableGetVisibilityAttributeName/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableInsert/2","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableInsert/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableLookup/2","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableLookup/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableReplaceAllSymbolUses/3","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableReplaceAllSymbolUses/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirSymbolTableWalkSymbolTables/4","ref":"Beaver.MLIR.CAPI.html#mlirSymbolTableWalkSymbolTables/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTF32TypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirTF32TypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyOpTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyOpTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyOpTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyOpTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyParamTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyParamTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyParamTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyParamTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyValueTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyValueTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformAnyValueTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformAnyValueTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformApplyNamedSequence/4","ref":"Beaver.MLIR.CAPI.html#mlirTransformApplyNamedSequence/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOperationTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirTransformOperationTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOperationTypeGetOperationName/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformOperationTypeGetOperationName/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOperationTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformOperationTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsEnableExpensiveChecks/2","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsEnableExpensiveChecks/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsEnforceSingleTopLevelTransformOp/2","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsEnforceSingleTopLevelTransformOp/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsGetEnforceSingleTopLevelTransformOp/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsGetEnforceSingleTopLevelTransformOp/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformOptionsGetExpensiveChecksEnabled/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformOptionsGetExpensiveChecksEnabled/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformParamTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirTransformParamTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformParamTypeGetType/1","ref":"Beaver.MLIR.CAPI.html#mlirTransformParamTypeGetType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTransformParamTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTransformParamTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTupleTypeGet/3","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetNumTypes/1","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetNumTypes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetType/2","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTupleTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTupleTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeAttrGet/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeAttrGetValue/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeAttrGetValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeDump/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirTypeEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeGetContext/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetContext/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeGetDialect/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetDialect/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeGetTypeID/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeGetTypeID/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorAllocateTypeID/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorAllocateTypeID/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorCreate/0","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorCreate/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDAllocatorDestroy/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDAllocatorDestroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDCreate/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDCreate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIDHashValue/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIDHashValue/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAAnyQuantizedType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAAnyQuantizedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsABF16/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsABF16/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsACalibratedQuantizedType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsACalibratedQuantizedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAComplex/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAComplex/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCArrayType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCArrayType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCLValueType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCLValueType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCOpaqueType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCOpaqueType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCPointerType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCPointerType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCPtrDiffTType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCPtrDiffTType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCSignedSizeTType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCSignedSizeTType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAEmitCSizeTType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAEmitCSizeTType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAF16/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF16/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAF32/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF32/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAF64/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAF64/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat4E2M1FN/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat4E2M1FN/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat6E2M3FN/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat6E2M3FN/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat6E3M2FN/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat6E3M2FN/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E3M4/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E3M4/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3B11FNUZ/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3B11FNUZ/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3FN/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3FN/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E4M3FNUZ/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E4M3FNUZ/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E5M2/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E5M2/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E5M2FNUZ/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E5M2FNUZ/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat8E8M0FNU/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat8E8M0FNU/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFloat/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFloat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAFunction/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAFunction/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAGPUAsyncTokenType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAGPUAsyncTokenType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAIndex/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAIndex/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAInteger/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAInteger/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsALLVMPointerType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsALLVMPointerType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsALLVMStructType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsALLVMStructType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAMemRef/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAMemRef/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsANone/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsANone/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsANVGPUTensorMapDescriptorType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsANVGPUTensorMapDescriptorType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAOpaque/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAOpaque/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLAttributeType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLAttributeType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLOperationType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLOperationType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLRangeType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLRangeType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLTypeType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLTypeType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAPDLValueType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAPDLValueType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAQuantizedType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAQuantizedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsARankedTensor/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsARankedTensor/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAShaped/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAShaped/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATensor/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATensor/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATF32/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATF32/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATransformAnyOpType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATransformAnyOpType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATransformAnyParamType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATransformAnyParamType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATransformAnyValueType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATransformAnyValueType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATransformOperationType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATransformOperationType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATransformParamType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATransformParamType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsATuple/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsATuple/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAUniformQuantizedPerAxisType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUniformQuantizedPerAxisType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAUniformQuantizedType/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUniformQuantizedType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAUnrankedMemRef/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUnrankedMemRef/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAUnrankedTensor/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAUnrankedTensor/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeIsAVector/1","ref":"Beaver.MLIR.CAPI.html#mlirTypeIsAVector/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeParseGet/2","ref":"Beaver.MLIR.CAPI.html#mlirTypeParseGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypeParseGetWithDiagnostics/3","ref":"Beaver.MLIR.CAPI.html#mlirTypeParseGetWithDiagnostics/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirTypePrint/3","ref":"Beaver.MLIR.CAPI.html#mlirTypePrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGet/9","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGet/9"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetNumDims/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetNumDims/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetQuantizedDimension/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetQuantizedDimension/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetScale/2","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetScale/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeGetZeroPoint/2","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeGetZeroPoint/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedPerAxisTypeIsFixedPoint/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedPerAxisTypeIsFixedPoint/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGet/7","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGet/7"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGetScale/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGetScale/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeGetZeroPoint/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeGetZeroPoint/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUniformQuantizedTypeIsFixedPoint/1","ref":"Beaver.MLIR.CAPI.html#mlirUniformQuantizedTypeIsFixedPoint/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnitAttrGet/1","ref":"Beaver.MLIR.CAPI.html#mlirUnitAttrGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnitAttrGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirUnitAttrGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseBoolResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseBoolResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseDoubleResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseDoubleResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseFloatResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseFloatResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt8ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt8ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt16ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt16ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt32ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt32ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseInt64ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseInt64ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseResourceElementsAttrGet/8","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseResourceElementsAttrGet/8"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt8ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt8ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt16ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt16ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt32ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt32ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnmanagedDenseUInt64ResourceElementsAttrGet/4","ref":"Beaver.MLIR.CAPI.html#mlirUnmanagedDenseUInt64ResourceElementsAttrGet/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGet/2","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGet/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGetChecked/3","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGetChecked/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGetCheckedWithDiagnostics/4","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGetCheckedWithDiagnostics/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedMemRefTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemRefTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedMemrefGetMemorySpace/1","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedMemrefGetMemorySpace/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGet/1","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGet/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGetChecked/2","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGetChecked/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGetCheckedWithDiagnostics/3","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGetCheckedWithDiagnostics/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirUnrankedTensorTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirUnrankedTensorTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueDump/1","ref":"Beaver.MLIR.CAPI.html#mlirValueDump/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueEqual/2","ref":"Beaver.MLIR.CAPI.html#mlirValueEqual/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueGetFirstUse/1","ref":"Beaver.MLIR.CAPI.html#mlirValueGetFirstUse/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueGetType/1","ref":"Beaver.MLIR.CAPI.html#mlirValueGetType/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueIsABlockArgument/1","ref":"Beaver.MLIR.CAPI.html#mlirValueIsABlockArgument/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueIsAOpResult/1","ref":"Beaver.MLIR.CAPI.html#mlirValueIsAOpResult/1"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValuePrint/3","ref":"Beaver.MLIR.CAPI.html#mlirValuePrint/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValuePrintAsOperand/4","ref":"Beaver.MLIR.CAPI.html#mlirValuePrintAsOperand/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueReplaceAllUsesExcept/4","ref":"Beaver.MLIR.CAPI.html#mlirValueReplaceAllUsesExcept/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueReplaceAllUsesOfWith/2","ref":"Beaver.MLIR.CAPI.html#mlirValueReplaceAllUsesOfWith/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirValueSetType/2","ref":"Beaver.MLIR.CAPI.html#mlirValueSetType/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGet/3","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGet/3"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetChecked/4","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetChecked/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetCheckedWithDiagnostics/5","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetCheckedWithDiagnostics/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetScalable/4","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetScalable/4"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetScalableChecked/5","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetScalableChecked/5"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeGetTypeID/0","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeGetTypeID/0"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeIsDimScalable/2","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeIsDimScalable/2"},{"type":"function","doc":"","title":"Beaver.MLIR.CAPI.mlirVectorTypeIsScalable/1","ref":"Beaver.MLIR.CAPI.html#mlirVectorTypeIsScalable/1"},{"type":"module","doc":"This module defines functions creating or destroying MLIR context.","title":"Beaver.MLIR.Context","ref":"Beaver.MLIR.Context.html"},{"type":"type","doc":"","title":"Beaver.MLIR.Context.context_option/0","ref":"Beaver.MLIR.Context.html#t:context_option/0"},{"type":"function","doc":"Create a MLIR context. By default it registers and loads all dialects.","title":"Beaver.MLIR.Context.create/1","ref":"Beaver.MLIR.Context.html#create/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Context.destroy/1","ref":"Beaver.MLIR.Context.html#destroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Context.make/1","ref":"Beaver.MLIR.Context.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Context.register_translations/1","ref":"Beaver.MLIR.Context.html#register_translations/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Context.t/0","ref":"Beaver.MLIR.Context.html#t:t/0"},{"type":"function","doc":"Run a function with a registry appended to the context.","title":"Beaver.MLIR.Context.with_registry/2","ref":"Beaver.MLIR.Context.html#with_registry/2"},{"type":"module","doc":"Conversions MLIR provides by default.","title":"Beaver.MLIR.Conversion","ref":"Beaver.MLIR.Conversion.html"},{"type":"function","doc":"Convert Arm NEON structured ops to intrinsics","title":"Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0"},{"type":"function","doc":"`arm-neon-2d-to-intr`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertArmNeon2dToIntr`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.arm_neon_2d_to_intr/0","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.arm_neon_2d_to_intr/1","ref":"Beaver.MLIR.Conversion.html#arm_neon_2d_to_intr/1"},{"type":"function","doc":"Convert top-level AffineFor Ops to GPU kernels","title":"Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0"},{"type":"function","doc":"`convert-affine-for-to-gpu`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertAffineForToGPU`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_affine_for_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_affine_for_to_gpu/1","ref":"Beaver.MLIR.Conversion.html#convert_affine_for_to_gpu/1"},{"type":"function","doc":"Convert AMDGPU dialect to ROCDL dialect","title":"Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0"},{"type":"function","doc":"`convert-amdgpu-to-rocdl`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertAMDGPUToROCDL`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_amdgpu_to_rocdl/1","ref":"Beaver.MLIR.Conversion.html#convert_amdgpu_to_rocdl/1"},{"type":"function","doc":"Convert Arith operations to AMDGPU-specific implementations","title":"Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0"},{"type":"function","doc":"`convert-arith-to-amdgpu`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ArithToAMDGPUConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_amdgpu/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arith_to_amdgpu/1","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_amdgpu/1"},{"type":"function","doc":"Convert Arith dialect to ArmSME dialect","title":"Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0"},{"type":"function","doc":"`convert-arith-to-arm-sme`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ArithToArmSMEConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arith_to_arm_sme/1","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_arm_sme/1"},{"type":"function","doc":"Convert Arith dialect to EmitC dialect","title":"Beaver.MLIR.Conversion.convert_arith_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0"},{"type":"function","doc":"`convert-arith-to-emitc`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertArithToEmitC`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arith_to_emitc/1","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_emitc/1"},{"type":"function","doc":"Convert Arith dialect to LLVM dialect","title":"Beaver.MLIR.Conversion.convert_arith_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0"},{"type":"function","doc":"`convert-arith-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ArithToLLVMConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arith_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_llvm/1"},{"type":"function","doc":"Convert Arith dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_arith_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0"},{"type":"function","doc":"`convert-arith-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arith_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertArithToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arith_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arith_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_arith_to_spirv/1"},{"type":"function","doc":"Lower the operations from the ArmSME dialect into the LLVM dialect","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0"},{"type":"function","doc":"`convert-arm-sme-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertArmSMEToLLVM`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_llvm/1"},{"type":"function","doc":"Lower the operations from the ArmSME dialect into the SCF dialect","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0"},{"type":"function","doc":"`convert-arm-sme-to-scf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertArmSMEToSCF`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_arm_sme_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_arm_sme_to_scf/1","ref":"Beaver.MLIR.Conversion.html#convert_arm_sme_to_scf/1"},{"type":"function","doc":"Convert the operations from the async dialect into the LLVM dialect","title":"Beaver.MLIR.Conversion.convert_async_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0"},{"type":"function","doc":"`convert-async-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_async_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertAsyncToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_async_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_async_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_async_to_llvm/1"},{"type":"function","doc":"Convert operations from the Bufferization dialect to the MemRef dialect","title":"Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0"},{"type":"function","doc":"`convert-bufferization-to-memref`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertBufferizationToMemRef`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_bufferization_to_memref/0","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_bufferization_to_memref/1","ref":"Beaver.MLIR.Conversion.html#convert_bufferization_to_memref/1"},{"type":"function","doc":"Convert ControlFlow operations to the LLVM dialect","title":"Beaver.MLIR.Conversion.convert_cf_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0"},{"type":"function","doc":"`convert-cf-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_cf_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertControlFlowToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_cf_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_cf_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_llvm/1"},{"type":"function","doc":"Convert ControlFlow dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_cf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0"},{"type":"function","doc":"`convert-cf-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_cf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertControlFlowToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_cf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_cf_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_cf_to_spirv/1"},{"type":"function","doc":"Convert Complex dialect to libm calls","title":"Beaver.MLIR.Conversion.convert_complex_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0"},{"type":"function","doc":"`convert-complex-to-libm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertComplexToLibm`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_complex_to_libm/1","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_libm/1"},{"type":"function","doc":"Convert Complex dialect to LLVM dialect","title":"Beaver.MLIR.Conversion.convert_complex_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0"},{"type":"function","doc":"`convert-complex-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertComplexToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_complex_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_llvm/1"},{"type":"function","doc":"Convert Complex dialect to SPIRV dialect","title":"Beaver.MLIR.Conversion.convert_complex_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0"},{"type":"function","doc":"`convert-complex-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertComplexToSPIRVPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_complex_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_spirv/1"},{"type":"function","doc":"Convert Complex dialect to standard dialect","title":"Beaver.MLIR.Conversion.convert_complex_to_standard/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0"},{"type":"function","doc":"`convert-complex-to-standard`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_complex_to_standard/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertComplexToStandard`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_complex_to_standard/0","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_complex_to_standard/1","ref":"Beaver.MLIR.Conversion.html#convert_complex_to_standard/1"},{"type":"function","doc":"Convert Func dialect to EmitC dialect","title":"Beaver.MLIR.Conversion.convert_func_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0"},{"type":"function","doc":"`convert-func-to-emitc`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertFuncToEmitC`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_func_to_emitc/1","ref":"Beaver.MLIR.Conversion.html#convert_func_to_emitc/1"},{"type":"function","doc":"Convert from the Func dialect to the LLVM dialect","title":"Beaver.MLIR.Conversion.convert_func_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0"},{"type":"function","doc":"`convert-func-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertFuncToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_func_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_func_to_llvm/1"},{"type":"function","doc":"Convert Func dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_func_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0"},{"type":"function","doc":"`convert-func-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_func_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertFuncToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_func_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_func_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_func_to_spirv/1"},{"type":"function","doc":"Generate LLVM operations to be ingested by a SPIR-V backend for gpu operations","title":"Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0"},{"type":"function","doc":"`convert-gpu-to-llvm-spv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertGpuOpsToLLVMSPVOps`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_gpu_to_llvm_spv/1","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_llvm_spv/1"},{"type":"function","doc":"Generate NVVM operations for gpu operations","title":"Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0"},{"type":"function","doc":"`convert-gpu-to-nvvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertGpuOpsToNVVMOps`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_gpu_to_nvvm/1","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_nvvm/1"},{"type":"function","doc":"Generate ROCDL operations for gpu operations","title":"Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0"},{"type":"function","doc":"`convert-gpu-to-rocdl`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertGpuOpsToROCDLOps`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_gpu_to_rocdl/1","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_rocdl/1"},{"type":"function","doc":"Convert GPU dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0"},{"type":"function","doc":"`convert-gpu-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertGPUToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_gpu_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_gpu_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_gpu_to_spirv/1"},{"type":"function","doc":"Lower the `index` dialect to the `llvm` dialect.","title":"Beaver.MLIR.Conversion.convert_index_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0"},{"type":"function","doc":"`convert-index-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_index_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertIndexToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_index_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_index_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_index_to_llvm/1"},{"type":"function","doc":"Lower the `index` dialect to the `spirv` dialect.","title":"Beaver.MLIR.Conversion.convert_index_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0"},{"type":"function","doc":"`convert-index-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_index_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertIndexToSPIRVPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_index_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_index_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_index_to_spirv/1"},{"type":"function","doc":"Convert the operations from the linalg dialect into the Standard dialect","title":"Beaver.MLIR.Conversion.convert_linalg_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0"},{"type":"function","doc":"`convert-linalg-to-std`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_linalg_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertLinalgToStandard`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_linalg_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_linalg_to_std/1","ref":"Beaver.MLIR.Conversion.html#convert_linalg_to_std/1"},{"type":"function","doc":"Convert some Math operations to EmitC call_opaque operations","title":"Beaver.MLIR.Conversion.convert_math_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_emitc/0"},{"type":"function","doc":"`convert-math-to-emitc`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToEmitC`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_emitc/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_emitc/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_emitc/1"},{"type":"function","doc":"Convert Math operations to calls of outlined implementations.","title":"Beaver.MLIR.Conversion.convert_math_to_funcs/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0"},{"type":"function","doc":"`convert-math-to-funcs`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_funcs/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToFuncs`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_funcs/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_funcs/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_funcs/1"},{"type":"function","doc":"Convert Math dialect to libm calls","title":"Beaver.MLIR.Conversion.convert_math_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0"},{"type":"function","doc":"`convert-math-to-libm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToLibm`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_libm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_libm/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_libm/1"},{"type":"function","doc":"Convert Math dialect to LLVM dialect","title":"Beaver.MLIR.Conversion.convert_math_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0"},{"type":"function","doc":"`convert-math-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_llvm/1"},{"type":"function","doc":"Convert Math dialect to ROCDL library calls","title":"Beaver.MLIR.Conversion.convert_math_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0"},{"type":"function","doc":"`convert-math-to-rocdl`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToROCDL`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_rocdl/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_rocdl/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_rocdl/1"},{"type":"function","doc":"Convert Math dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_math_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0"},{"type":"function","doc":"`convert-math-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_math_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMathToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_math_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_math_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_math_to_spirv/1"},{"type":"function","doc":"Convert MemRef dialect to EmitC dialect","title":"Beaver.MLIR.Conversion.convert_memref_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0"},{"type":"function","doc":"`convert-memref-to-emitc`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_memref_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMemRefToEmitC`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_memref_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_memref_to_emitc/1","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_emitc/1"},{"type":"function","doc":"Convert MemRef dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_memref_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0"},{"type":"function","doc":"`convert-memref-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_memref_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMemRefToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_memref_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_memref_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_memref_to_spirv/1"},{"type":"function","doc":"Convert Mesh dialect to MPI dialect.","title":"Beaver.MLIR.Conversion.convert_mesh_to_mpi/0","ref":"Beaver.MLIR.Conversion.html#convert_mesh_to_mpi/0"},{"type":"function","doc":"`convert-mesh-to-mpi`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_mesh_to_mpi/0","ref":"Beaver.MLIR.Conversion.html#convert_mesh_to_mpi/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertMeshToMPIPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_mesh_to_mpi/0","ref":"Beaver.MLIR.Conversion.html#convert_mesh_to_mpi/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_mesh_to_mpi/1","ref":"Beaver.MLIR.Conversion.html#convert_mesh_to_mpi/1"},{"type":"function","doc":"Convert NVGPU dialect to NVVM dialect","title":"Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0"},{"type":"function","doc":"`convert-nvgpu-to-nvvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertNVGPUToNVVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_nvgpu_to_nvvm/1","ref":"Beaver.MLIR.Conversion.html#convert_nvgpu_to_nvvm/1"},{"type":"function","doc":"Convert NVVM to PTX with Inline Assembly in LLVM dialect","title":"Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0"},{"type":"function","doc":"`convert-nvvm-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertNVVMToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_nvvm_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_nvvm_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_nvvm_to_llvm/1"},{"type":"function","doc":"Convert the OpenACC ops to OpenACC with SCF dialect","title":"Beaver.MLIR.Conversion.convert_openacc_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0"},{"type":"function","doc":"`convert-openacc-to-scf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_openacc_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertOpenACCToSCF`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_openacc_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_openacc_to_scf/1","ref":"Beaver.MLIR.Conversion.html#convert_openacc_to_scf/1"},{"type":"function","doc":"Convert the OpenMP ops to OpenMP ops with LLVM dialect","title":"Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0"},{"type":"function","doc":"`convert-openmp-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertOpenMPToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_openmp_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_openmp_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_openmp_to_llvm/1"},{"type":"function","doc":"Convert mapped scf.parallel ops to gpu launch operations","title":"Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0"},{"type":"function","doc":"`convert-parallel-loops-to-gpu`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertParallelLoopToGpu`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_parallel_loops_to_gpu/1","ref":"Beaver.MLIR.Conversion.html#convert_parallel_loops_to_gpu/1"},{"type":"function","doc":"Convert PDL ops to PDL interpreter ops","title":"Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0"},{"type":"function","doc":"`convert-pdl-to-pdl-interp`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertPDLToPDLInterp`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/0","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_pdl_to_pdl_interp/1","ref":"Beaver.MLIR.Conversion.html#convert_pdl_to_pdl_interp/1"},{"type":"function","doc":"Convert SCF dialect to ControlFlow dialect, replacing structured control flow with a CFG","title":"Beaver.MLIR.Conversion.convert_scf_to_cf/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0"},{"type":"function","doc":"`convert-scf-to-cf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_cf/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SCFToControlFlow`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_cf/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_scf_to_cf/1","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_cf/1"},{"type":"function","doc":"Convert SCF dialect to EmitC dialect, maintaining structured control flow","title":"Beaver.MLIR.Conversion.convert_scf_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0"},{"type":"function","doc":"`convert-scf-to-emitc`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SCFToEmitC`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_emitc/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_scf_to_emitc/1","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_emitc/1"},{"type":"function","doc":"Convert SCF parallel loop to OpenMP parallel + workshare constructs.","title":"Beaver.MLIR.Conversion.convert_scf_to_openmp/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0"},{"type":"function","doc":"`convert-scf-to-openmp`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_openmp/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertSCFToOpenMPPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_openmp/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_scf_to_openmp/1","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_openmp/1"},{"type":"function","doc":"Convert SCF dialect to SPIR-V dialect.","title":"Beaver.MLIR.Conversion.convert_scf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0"},{"type":"function","doc":"`convert-scf-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_scf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SCFToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_scf_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_scf_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_scf_to_spirv/1"},{"type":"function","doc":"Convert shape constraint operations to the standard dialect","title":"Beaver.MLIR.Conversion.convert_shape_constraints/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0"},{"type":"function","doc":"`convert-shape-constraints`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_shape_constraints/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertShapeConstraints`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_shape_constraints/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_shape_constraints/1","ref":"Beaver.MLIR.Conversion.html#convert_shape_constraints/1"},{"type":"function","doc":"Convert operations from the shape dialect into the standard dialect","title":"Beaver.MLIR.Conversion.convert_shape_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0"},{"type":"function","doc":"`convert-shape-to-std`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_shape_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertShapeToStandard`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_shape_to_std/0","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_shape_to_std/1","ref":"Beaver.MLIR.Conversion.html#convert_shape_to_std/1"},{"type":"function","doc":"Convert SPIR-V dialect to LLVM dialect","title":"Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0"},{"type":"function","doc":"`convert-spirv-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertSPIRVToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_spirv_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_spirv_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_spirv_to_llvm/1"},{"type":"function","doc":"Convert some Tensor dialect ops to Linalg dialect","title":"Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0"},{"type":"function","doc":"`convert-tensor-to-linalg`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertTensorToLinalg`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_tensor_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_tensor_to_linalg/1","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_linalg/1"},{"type":"function","doc":"Convert Tensor dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0"},{"type":"function","doc":"`convert-tensor-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertTensorToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_tensor_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_tensor_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_tensor_to_spirv/1"},{"type":"function","doc":"Convert to LLVM via dialect interfaces found in the input IR","title":"Beaver.MLIR.Conversion.convert_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0"},{"type":"function","doc":"`convert-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_to_llvm/1"},{"type":"function","doc":"Convert to SPIR-V","title":"Beaver.MLIR.Conversion.convert_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0"},{"type":"function","doc":"`convert-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertToSPIRVPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_to_spirv/1"},{"type":"function","doc":"Convert UB dialect to LLVM dialect","title":"Beaver.MLIR.Conversion.convert_ub_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0"},{"type":"function","doc":"`convert-ub-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_ub_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`UBToLLVMConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_ub_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_ub_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_llvm/1"},{"type":"function","doc":"Convert UB dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_ub_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0"},{"type":"function","doc":"`convert-ub-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_ub_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`UBToSPIRVConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_ub_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_ub_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_ub_to_spirv/1"},{"type":"function","doc":"Lower the operations from the vector dialect into the ArmSME dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0"},{"type":"function","doc":"`convert-vector-to-arm-sme`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToArmSME`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_arm_sme/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_arm_sme/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_arm_sme/1"},{"type":"function","doc":"Lower the operations from the vector dialect into the GPU dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0"},{"type":"function","doc":"`convert-vector-to-gpu`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToGPU`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_gpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_gpu/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_gpu/1"},{"type":"function","doc":"Lower the operations from the vector dialect into the LLVM dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0"},{"type":"function","doc":"`convert-vector-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_llvm/1"},{"type":"function","doc":"Lower the operations from the vector dialect into the SCF dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0"},{"type":"function","doc":"`convert-vector-to-scf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToSCF`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_scf/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_scf/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_scf/1"},{"type":"function","doc":"Convert Vector dialect to SPIR-V dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0"},{"type":"function","doc":"`convert-vector-to-spirv`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToSPIRV`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_spirv/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_spirv/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_spirv/1"},{"type":"function","doc":"Lower the operations from the vector dialect into the XeGPU dialect","title":"Beaver.MLIR.Conversion.convert_vector_to_xegpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_xegpu/0"},{"type":"function","doc":"`convert-vector-to-xegpu`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.convert_vector_to_xegpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_xegpu/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertVectorToXeGPU`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.convert_vector_to_xegpu/0","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_xegpu/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.convert_vector_to_xegpu/1","ref":"Beaver.MLIR.Conversion.html#convert_vector_to_xegpu/1"},{"type":"function","doc":"Finalize MemRef dialect to LLVM dialect conversion","title":"Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0"},{"type":"function","doc":"`finalize-memref-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`FinalizeMemRefToLLVMConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.finalize_memref_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.finalize_memref_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#finalize_memref_to_llvm/1"},{"type":"function","doc":"Convert GPU dialect to LLVM dialect with GPU runtime calls","title":"Beaver.MLIR.Conversion.gpu_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0"},{"type":"function","doc":"`gpu-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.gpu_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuToLLVMConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.gpu_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.gpu_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#gpu_to_llvm/1"},{"type":"function","doc":"Lift ControlFlow dialect to SCF dialect","title":"Beaver.MLIR.Conversion.lift_cf_to_scf/0","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0"},{"type":"function","doc":"`lift-cf-to-scf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lift_cf_to_scf/0","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LiftControlFlowToSCFPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lift_cf_to_scf/0","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.lift_cf_to_scf/1","ref":"Beaver.MLIR.Conversion.html#lift_cf_to_scf/1"},{"type":"function","doc":"Lower Affine operations to a combination of Standard and SCF operations","title":"Beaver.MLIR.Conversion.lower_affine/0","ref":"Beaver.MLIR.Conversion.html#lower_affine/0"},{"type":"function","doc":"`lower-affine`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lower_affine/0","ref":"Beaver.MLIR.Conversion.html#lower_affine/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertAffineToStandard`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lower_affine/0","ref":"Beaver.MLIR.Conversion.html#lower_affine/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.lower_affine/1","ref":"Beaver.MLIR.Conversion.html#lower_affine/1"},{"type":"function","doc":"Lowers the host module code and `gpu.launch_func` to LLVM","title":"Beaver.MLIR.Conversion.lower_host_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0"},{"type":"function","doc":"`lower-host-to-llvm`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.lower_host_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LowerHostCodeToLLVMPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.lower_host_to_llvm/0","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.lower_host_to_llvm/1","ref":"Beaver.MLIR.Conversion.html#lower_host_to_llvm/1"},{"type":"function","doc":"Map numeric MemRef memory spaces to SPIR-V storage classes","title":"Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0"},{"type":"function","doc":"`map-memref-spirv-storage-class`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`MapMemRefStorageClass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.map_memref_spirv_storage_class/0","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.map_memref_spirv_storage_class/1","ref":"Beaver.MLIR.Conversion.html#map_memref_spirv_storage_class/1"},{"type":"function","doc":"Simplify and eliminate unrealized conversion casts","title":"Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0"},{"type":"function","doc":"`reconcile-unrealized-casts`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ReconcileUnrealizedCasts`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.reconcile_unrealized_casts/0","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.reconcile_unrealized_casts/1","ref":"Beaver.MLIR.Conversion.html#reconcile_unrealized_casts/1"},{"type":"function","doc":"Attach a datalayout string as a module attribute","title":"Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0"},{"type":"function","doc":"`set-llvm-module-datalayout`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SetLLVMModuleDataLayoutPass`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.set_llvm_module_datalayout/0","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.set_llvm_module_datalayout/1","ref":"Beaver.MLIR.Conversion.html#set_llvm_module_datalayout/1"},{"type":"function","doc":"Lower TOSA to the Arith dialect","title":"Beaver.MLIR.Conversion.tosa_to_arith/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0"},{"type":"function","doc":"`tosa-to-arith`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_arith/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToArith`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_arith/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_arith/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_arith/1"},{"type":"function","doc":"Lower TOSA to LinAlg on tensors","title":"Beaver.MLIR.Conversion.tosa_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0"},{"type":"function","doc":"`tosa-to-linalg`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToLinalg`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_linalg/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_linalg/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg/1"},{"type":"function","doc":"Lower TOSA to LinAlg named operations","title":"Beaver.MLIR.Conversion.tosa_to_linalg_named/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0"},{"type":"function","doc":"`tosa-to-linalg-named`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_linalg_named/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToLinalgNamed`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_linalg_named/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_linalg_named/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_linalg_named/1"},{"type":"function","doc":"Lower TOSA to the MLProgram dialect","title":"Beaver.MLIR.Conversion.tosa_to_mlprogram/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0"},{"type":"function","doc":"`tosa-to-mlprogram`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_mlprogram/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToMLProgram`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_mlprogram/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_mlprogram/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_mlprogram/1"},{"type":"function","doc":"Lower TOSA to the SCF dialect","title":"Beaver.MLIR.Conversion.tosa_to_scf/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0"},{"type":"function","doc":"`tosa-to-scf`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_scf/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToSCF`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_scf/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_scf/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_scf/1"},{"type":"function","doc":"Lower TOSA to the Tensor dialect","title":"Beaver.MLIR.Conversion.tosa_to_tensor/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0"},{"type":"function","doc":"`tosa-to-tensor`","title":"Argument name in MLIR CLI - Beaver.MLIR.Conversion.tosa_to_tensor/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TosaToTensor`","title":"Pass name in TableGen - Beaver.MLIR.Conversion.tosa_to_tensor/0","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Conversion.tosa_to_tensor/1","ref":"Beaver.MLIR.Conversion.html#tosa_to_tensor/1"},{"type":"module","doc":"This module provides functions to work with MLIR diagnostics.","title":"Beaver.MLIR.Diagnostic","ref":"Beaver.MLIR.Diagnostic.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Diagnostic.detach/2","ref":"Beaver.MLIR.Diagnostic.html#detach/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Diagnostic.emit/2","ref":"Beaver.MLIR.Diagnostic.html#emit/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Diagnostic.format/2","ref":"Beaver.MLIR.Diagnostic.html#format/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Diagnostic.make/1","ref":"Beaver.MLIR.Diagnostic.html#make/1"},{"type":"function","doc":"Returns the severity level of a diagnostic.\n\nIf the MLIR severity level is not recognized, it returns `:unknown`.","title":"Beaver.MLIR.Diagnostic.severity/1","ref":"Beaver.MLIR.Diagnostic.html#severity/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Diagnostic.t/0","ref":"Beaver.MLIR.Diagnostic.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Diagnostic.walk/3","ref":"Beaver.MLIR.Diagnostic.html#walk/3"},{"type":"module","doc":"","title":"Beaver.MLIR.DiagnosticHandler","ref":"Beaver.MLIR.DiagnosticHandler.html"},{"type":"function","doc":"","title":"Beaver.MLIR.DiagnosticHandler.make/1","ref":"Beaver.MLIR.DiagnosticHandler.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.DiagnosticHandler.t/0","ref":"Beaver.MLIR.DiagnosticHandler.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.DiagnosticHandlerID","ref":"Beaver.MLIR.DiagnosticHandlerID.html"},{"type":"function","doc":"","title":"Beaver.MLIR.DiagnosticHandlerID.make/1","ref":"Beaver.MLIR.DiagnosticHandlerID.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.DiagnosticHandlerID.t/0","ref":"Beaver.MLIR.DiagnosticHandlerID.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.DiagnosticSeverity","ref":"Beaver.MLIR.DiagnosticSeverity.html"},{"type":"function","doc":"","title":"Beaver.MLIR.DiagnosticSeverity.make/1","ref":"Beaver.MLIR.DiagnosticSeverity.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.DiagnosticSeverity.t/0","ref":"Beaver.MLIR.DiagnosticSeverity.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR ExecutionEngine.","title":"Beaver.MLIR.ExecutionEngine","ref":"Beaver.MLIR.ExecutionEngine.html"},{"type":"function","doc":"Create a MLIR JIT engine for a module and check if successful. Usually this module should be of LLVM dialect.","title":"Beaver.MLIR.ExecutionEngine.create!/1","ref":"Beaver.MLIR.ExecutionEngine.html#create!/1"},{"type":"function","doc":"","title":"Beaver.MLIR.ExecutionEngine.create!/2","ref":"Beaver.MLIR.ExecutionEngine.html#create!/2"},{"type":"function","doc":"","title":"Beaver.MLIR.ExecutionEngine.destroy/1","ref":"Beaver.MLIR.ExecutionEngine.html#destroy/1"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.dirty/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:dirty/0"},{"type":"function","doc":"invoke a function by symbol name.","title":"Beaver.MLIR.ExecutionEngine.invoke!/5","ref":"Beaver.MLIR.ExecutionEngine.html#invoke!/5"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.invoke_opts/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:invoke_opts/0"},{"type":"function","doc":"","title":"Beaver.MLIR.ExecutionEngine.make/1","ref":"Beaver.MLIR.ExecutionEngine.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.object_dump/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:object_dump/0"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.opt_level/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:opt_level/0"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.opts/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:opts/0"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.shared_lib_path/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:shared_lib_path/0"},{"type":"type","doc":"","title":"Beaver.MLIR.ExecutionEngine.t/0","ref":"Beaver.MLIR.ExecutionEngine.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.ExternalPassCallbacks","ref":"Beaver.MLIR.ExternalPassCallbacks.html"},{"type":"function","doc":"","title":"Beaver.MLIR.ExternalPassCallbacks.make/1","ref":"Beaver.MLIR.ExternalPassCallbacks.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.ExternalPassCallbacks.t/0","ref":"Beaver.MLIR.ExternalPassCallbacks.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR Identifier.","title":"Beaver.MLIR.Identifier","ref":"Beaver.MLIR.Identifier.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Identifier.get/2","ref":"Beaver.MLIR.Identifier.html#get/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Identifier.make/1","ref":"Beaver.MLIR.Identifier.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Identifier.t/0","ref":"Beaver.MLIR.Identifier.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.IntegerSet","ref":"Beaver.MLIR.IntegerSet.html"},{"type":"function","doc":"","title":"Beaver.MLIR.IntegerSet.make/1","ref":"Beaver.MLIR.IntegerSet.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.IntegerSet.t/0","ref":"Beaver.MLIR.IntegerSet.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.LLVMThreadPool","ref":"Beaver.MLIR.LLVMThreadPool.html"},{"type":"function","doc":"","title":"Beaver.MLIR.LLVMThreadPool.make/1","ref":"Beaver.MLIR.LLVMThreadPool.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.LLVMThreadPool.t/0","ref":"Beaver.MLIR.LLVMThreadPool.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR Location.","title":"Beaver.MLIR.Location","ref":"Beaver.MLIR.Location.html"},{"type":"function","doc":"Get a location of file line. Column is zero by default because in Elixir it is usually omitted.","title":"Beaver.MLIR.Location.file/1","ref":"Beaver.MLIR.Location.html#file/1"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Location.file(name: \"filename\", line: 1, column: 1, ctx: ctx) |> MLIR.to_string()\n    ~s{filename:1:1}\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.MLIR.Location.file/1","ref":"Beaver.MLIR.Location.html#file/1-examples"},{"type":"type","doc":"","title":"Beaver.MLIR.Location.file_opts/0","ref":"Beaver.MLIR.Location.html#t:file_opts/0"},{"type":"function","doc":"Create an MLIR location from `Macro.Env`","title":"Beaver.MLIR.Location.from_env/2","ref":"Beaver.MLIR.Location.html#from_env/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Location.make/1","ref":"Beaver.MLIR.Location.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Location.t/0","ref":"Beaver.MLIR.Location.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Location.unknown/1","ref":"Beaver.MLIR.Location.html#unknown/1"},{"type":"module","doc":"This module defines functions working with MLIR LogicalResult.","title":"Beaver.MLIR.LogicalResult","ref":"Beaver.MLIR.LogicalResult.html"},{"type":"function","doc":"","title":"Beaver.MLIR.LogicalResult.make/1","ref":"Beaver.MLIR.LogicalResult.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.LogicalResult.success?/1","ref":"Beaver.MLIR.LogicalResult.html#success?/1"},{"type":"type","doc":"","title":"Beaver.MLIR.LogicalResult.t/0","ref":"Beaver.MLIR.LogicalResult.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR Module.","title":"Beaver.MLIR.Module","ref":"Beaver.MLIR.Module.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.body/1","ref":"Beaver.MLIR.Module.html#body/1"},{"type":"function","doc":"Create a MLIR module by parsing string.","title":"Beaver.MLIR.Module.create/2","ref":"Beaver.MLIR.Module.html#create/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.create!/2","ref":"Beaver.MLIR.Module.html#create!/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.destroy/1","ref":"Beaver.MLIR.Module.html#destroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.empty/1","ref":"Beaver.MLIR.Module.html#empty/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.from_operation/1","ref":"Beaver.MLIR.Module.html#from_operation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Module.make/1","ref":"Beaver.MLIR.Module.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Module.t/0","ref":"Beaver.MLIR.Module.html#t:t/0"},{"type":"module","doc":"This module defines a wrapper struct of NamedAttribute in MLIR","title":"Beaver.MLIR.NamedAttribute","ref":"Beaver.MLIR.NamedAttribute.html"},{"type":"function","doc":"","title":"Beaver.MLIR.NamedAttribute.make/1","ref":"Beaver.MLIR.NamedAttribute.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.NamedAttribute.t/0","ref":"Beaver.MLIR.NamedAttribute.html#t:t/0"},{"type":"module","doc":"ODS helper functions to work with special concepts in ODS.","title":"Beaver.MLIR.ODS","ref":"Beaver.MLIR.ODS.html"},{"type":"function","doc":"Generate attribute for operand_segment_sizes","title":"Beaver.MLIR.ODS.operand_segment_sizes/1","ref":"Beaver.MLIR.ODS.html#operand_segment_sizes/1"},{"type":"function","doc":"","title":"Beaver.MLIR.ODS.result_segment_sizes/1","ref":"Beaver.MLIR.ODS.html#result_segment_sizes/1"},{"type":"module","doc":"This module defines functions working with MLIR OpOperand.","title":"Beaver.MLIR.OpOperand","ref":"Beaver.MLIR.OpOperand.html"},{"type":"function","doc":"","title":"Beaver.MLIR.OpOperand.make/1","ref":"Beaver.MLIR.OpOperand.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.OpOperand.t/0","ref":"Beaver.MLIR.OpOperand.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.OpPassManager","ref":"Beaver.MLIR.OpPassManager.html"},{"type":"function","doc":"","title":"Beaver.MLIR.OpPassManager.make/1","ref":"Beaver.MLIR.OpPassManager.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.OpPassManager.t/0","ref":"Beaver.MLIR.OpPassManager.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.OpPrintingFlags","ref":"Beaver.MLIR.OpPrintingFlags.html"},{"type":"function","doc":"","title":"Beaver.MLIR.OpPrintingFlags.make/1","ref":"Beaver.MLIR.OpPrintingFlags.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.OpPrintingFlags.t/0","ref":"Beaver.MLIR.OpPrintingFlags.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR Operation.","title":"Beaver.MLIR.Operation","ref":"Beaver.MLIR.Operation.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.create/1","ref":"Beaver.MLIR.Operation.html#create/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.from_module/1","ref":"Beaver.MLIR.Operation.html#from_module/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.location/1","ref":"Beaver.MLIR.Operation.html#location/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.make/1","ref":"Beaver.MLIR.Operation.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.name/1","ref":"Beaver.MLIR.Operation.html#name/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.parent/1","ref":"Beaver.MLIR.Operation.html#parent/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.results/1","ref":"Beaver.MLIR.Operation.html#results/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Operation.t/0","ref":"Beaver.MLIR.Operation.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Operation.with_symbol_table/2","ref":"Beaver.MLIR.Operation.html#with_symbol_table/2"},{"type":"module","doc":"","title":"Beaver.MLIR.OperationWalkCallback","ref":"Beaver.MLIR.OperationWalkCallback.html"},{"type":"function","doc":"","title":"Beaver.MLIR.OperationWalkCallback.make/1","ref":"Beaver.MLIR.OperationWalkCallback.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.OperationWalkCallback.t/0","ref":"Beaver.MLIR.OperationWalkCallback.html#t:t/0"},{"type":"behaviour","doc":"This module defines functions working with MLIR Pass.","title":"Beaver.MLIR.Pass","ref":"Beaver.MLIR.Pass.html"},{"type":"callback","doc":"","title":"Beaver.MLIR.Pass.clone/1","ref":"Beaver.MLIR.Pass.html#c:clone/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Pass.create/4","ref":"Beaver.MLIR.Pass.html#create/4"},{"type":"callback","doc":"","title":"Beaver.MLIR.Pass.destruct/1","ref":"Beaver.MLIR.Pass.html#c:destruct/1"},{"type":"callback","doc":"","title":"Beaver.MLIR.Pass.initialize/2","ref":"Beaver.MLIR.Pass.html#c:initialize/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Pass.make/1","ref":"Beaver.MLIR.Pass.html#make/1"},{"type":"callback","doc":"","title":"Beaver.MLIR.Pass.run/2","ref":"Beaver.MLIR.Pass.html#c:run/2"},{"type":"type","doc":"","title":"Beaver.MLIR.Pass.state/0","ref":"Beaver.MLIR.Pass.html#t:state/0"},{"type":"type","doc":"","title":"Beaver.MLIR.Pass.t/0","ref":"Beaver.MLIR.Pass.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR PassManager.","title":"Beaver.MLIR.PassManager","ref":"Beaver.MLIR.PassManager.html"},{"type":"function","doc":"","title":"Beaver.MLIR.PassManager.destroy/1","ref":"Beaver.MLIR.PassManager.html#destroy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.PassManager.enable_ir_printing/2","ref":"Beaver.MLIR.PassManager.html#enable_ir_printing/2"},{"type":"function","doc":"","title":"Beaver.MLIR.PassManager.enable_verifier/2","ref":"Beaver.MLIR.PassManager.html#enable_verifier/2"},{"type":"function","doc":"","title":"Beaver.MLIR.PassManager.make/1","ref":"Beaver.MLIR.PassManager.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.PassManager.print_opt/0","ref":"Beaver.MLIR.PassManager.html#t:print_opt/0"},{"type":"type","doc":"","title":"Beaver.MLIR.PassManager.print_opts/0","ref":"Beaver.MLIR.PassManager.html#t:print_opts/0"},{"type":"function","doc":"","title":"Beaver.MLIR.PassManager.run/2","ref":"Beaver.MLIR.PassManager.html#run/2"},{"type":"type","doc":"","title":"Beaver.MLIR.PassManager.t/0","ref":"Beaver.MLIR.PassManager.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR Region.","title":"Beaver.MLIR.Region","ref":"Beaver.MLIR.Region.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Region.append/2","ref":"Beaver.MLIR.Region.html#append/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Region.insert/3","ref":"Beaver.MLIR.Region.html#insert/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Region.make/1","ref":"Beaver.MLIR.Region.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Region.t/0","ref":"Beaver.MLIR.Region.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Region.under/2","ref":"Beaver.MLIR.Region.html#under/2"},{"type":"module","doc":"","title":"Beaver.MLIR.RewritePatternSet","ref":"Beaver.MLIR.RewritePatternSet.html"},{"type":"function","doc":"","title":"Beaver.MLIR.RewritePatternSet.make/1","ref":"Beaver.MLIR.RewritePatternSet.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.RewritePatternSet.t/0","ref":"Beaver.MLIR.RewritePatternSet.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.ShapedTypeComponentsCallback","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html"},{"type":"function","doc":"","title":"Beaver.MLIR.ShapedTypeComponentsCallback.make/1","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.ShapedTypeComponentsCallback.t/0","ref":"Beaver.MLIR.ShapedTypeComponentsCallback.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.SparseTensorLevelType","ref":"Beaver.MLIR.SparseTensorLevelType.html"},{"type":"function","doc":"","title":"Beaver.MLIR.SparseTensorLevelType.make/1","ref":"Beaver.MLIR.SparseTensorLevelType.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.SparseTensorLevelType.t/0","ref":"Beaver.MLIR.SparseTensorLevelType.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.StringCallback","ref":"Beaver.MLIR.StringCallback.html"},{"type":"function","doc":"","title":"Beaver.MLIR.StringCallback.make/1","ref":"Beaver.MLIR.StringCallback.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.StringCallback.t/0","ref":"Beaver.MLIR.StringCallback.html#t:t/0"},{"type":"module","doc":"This module defines functions working with MLIR StringRef.","title":"Beaver.MLIR.StringRef","ref":"Beaver.MLIR.StringRef.html"},{"type":"function","doc":"Create a Elixir owned null-terminated C string from a Elixir bitstring and create a `StringRef` from it.\n\n> #### Not really a reference {: .info}\n>\n> A `StringRef` created in Elixir is not a reference to the BEAM binary as argument. Instead, a copy is made. In other words, excessively creating `StringRef` using this function can lead to memory leak.","title":"Beaver.MLIR.StringRef.create/1","ref":"Beaver.MLIR.StringRef.html#create/1"},{"type":"function","doc":"Get the data of the StringRef as an array pointer of unsigned 8-bit integers.","title":"Beaver.MLIR.StringRef.data/1","ref":"Beaver.MLIR.StringRef.html#data/1"},{"type":"function","doc":"Get the length of the StringRef as Erlang integer.","title":"Beaver.MLIR.StringRef.length/1","ref":"Beaver.MLIR.StringRef.html#length/1"},{"type":"function","doc":"","title":"Beaver.MLIR.StringRef.make/1","ref":"Beaver.MLIR.StringRef.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.StringRef.t/0","ref":"Beaver.MLIR.StringRef.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.SymbolTable","ref":"Beaver.MLIR.SymbolTable.html"},{"type":"function","doc":"","title":"Beaver.MLIR.SymbolTable.make/1","ref":"Beaver.MLIR.SymbolTable.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.SymbolTable.t/0","ref":"Beaver.MLIR.SymbolTable.html#t:t/0"},{"type":"module","doc":"Transformations MLIR provides by default.","title":"Beaver.MLIR.Transform","ref":"Beaver.MLIR.Transform.html"},{"type":"function","doc":"Canonicalize operations","title":"Beaver.MLIR.Transform.canonicalize/0","ref":"Beaver.MLIR.Transform.html#canonicalize/0"},{"type":"function","doc":"`canonicalize`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.canonicalize/0","ref":"Beaver.MLIR.Transform.html#canonicalize/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`Canonicalizer`","title":"Pass name in TableGen - Beaver.MLIR.Transform.canonicalize/0","ref":"Beaver.MLIR.Transform.html#canonicalize/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.canonicalize/1","ref":"Beaver.MLIR.Transform.html#canonicalize/1"},{"type":"function","doc":"Composite fixed point pass","title":"Beaver.MLIR.Transform.composite_fixed_point_pass/0","ref":"Beaver.MLIR.Transform.html#composite_fixed_point_pass/0"},{"type":"function","doc":"`composite-fixed-point-pass`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.composite_fixed_point_pass/0","ref":"Beaver.MLIR.Transform.html#composite_fixed_point_pass/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`CompositeFixedPointPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.composite_fixed_point_pass/0","ref":"Beaver.MLIR.Transform.html#composite_fixed_point_pass/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.composite_fixed_point_pass/1","ref":"Beaver.MLIR.Transform.html#composite_fixed_point_pass/1"},{"type":"function","doc":"Sink operations into conditional blocks","title":"Beaver.MLIR.Transform.control_flow_sink/0","ref":"Beaver.MLIR.Transform.html#control_flow_sink/0"},{"type":"function","doc":"`control-flow-sink`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.control_flow_sink/0","ref":"Beaver.MLIR.Transform.html#control_flow_sink/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ControlFlowSink`","title":"Pass name in TableGen - Beaver.MLIR.Transform.control_flow_sink/0","ref":"Beaver.MLIR.Transform.html#control_flow_sink/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.control_flow_sink/1","ref":"Beaver.MLIR.Transform.html#control_flow_sink/1"},{"type":"function","doc":"Convert ElementwiseMappable ops to linalg","title":"Beaver.MLIR.Transform.convert_elementwise_to_linalg/0","ref":"Beaver.MLIR.Transform.html#convert_elementwise_to_linalg/0"},{"type":"function","doc":"`convert-elementwise-to-linalg`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.convert_elementwise_to_linalg/0","ref":"Beaver.MLIR.Transform.html#convert_elementwise_to_linalg/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertElementwiseToLinalgPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.convert_elementwise_to_linalg/0","ref":"Beaver.MLIR.Transform.html#convert_elementwise_to_linalg/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.convert_elementwise_to_linalg/1","ref":"Beaver.MLIR.Transform.html#convert_elementwise_to_linalg/1"},{"type":"function","doc":"Lower the operations from the linalg dialect into affine loops","title":"Beaver.MLIR.Transform.convert_linalg_to_affine_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_affine_loops/0"},{"type":"function","doc":"`convert-linalg-to-affine-loops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.convert_linalg_to_affine_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_affine_loops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertLinalgToAffineLoopsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.convert_linalg_to_affine_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_affine_loops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.convert_linalg_to_affine_loops/1","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_affine_loops/1"},{"type":"function","doc":"Lower the operations from the linalg dialect into loops","title":"Beaver.MLIR.Transform.convert_linalg_to_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_loops/0"},{"type":"function","doc":"`convert-linalg-to-loops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.convert_linalg_to_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_loops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertLinalgToLoopsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.convert_linalg_to_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_loops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.convert_linalg_to_loops/1","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_loops/1"},{"type":"function","doc":"Lower the operations from the linalg dialect into parallel loops","title":"Beaver.MLIR.Transform.convert_linalg_to_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_parallel_loops/0"},{"type":"function","doc":"`convert-linalg-to-parallel-loops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.convert_linalg_to_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_parallel_loops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ConvertLinalgToParallelLoopsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.convert_linalg_to_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_parallel_loops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.convert_linalg_to_parallel_loops/1","ref":"Beaver.MLIR.Transform.html#convert_linalg_to_parallel_loops/1"},{"type":"function","doc":"Eliminate common sub-expressions","title":"Beaver.MLIR.Transform.cse/0","ref":"Beaver.MLIR.Transform.html#cse/0"},{"type":"function","doc":"`cse`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.cse/0","ref":"Beaver.MLIR.Transform.html#cse/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`CSE`","title":"Pass name in TableGen - Beaver.MLIR.Transform.cse/0","ref":"Beaver.MLIR.Transform.html#cse/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.cse/1","ref":"Beaver.MLIR.Transform.html#cse/1"},{"type":"function","doc":"Generate additional runtime op verification checks","title":"Beaver.MLIR.Transform.generate_runtime_verification/0","ref":"Beaver.MLIR.Transform.html#generate_runtime_verification/0"},{"type":"function","doc":"`generate-runtime-verification`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.generate_runtime_verification/0","ref":"Beaver.MLIR.Transform.html#generate_runtime_verification/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GenerateRuntimeVerification`","title":"Pass name in TableGen - Beaver.MLIR.Transform.generate_runtime_verification/0","ref":"Beaver.MLIR.Transform.html#generate_runtime_verification/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.generate_runtime_verification/1","ref":"Beaver.MLIR.Transform.html#generate_runtime_verification/1"},{"type":"function","doc":"Make GPU ops async","title":"Beaver.MLIR.Transform.gpu_async_region/0","ref":"Beaver.MLIR.Transform.html#gpu_async_region/0"},{"type":"function","doc":"`gpu-async-region`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_async_region/0","ref":"Beaver.MLIR.Transform.html#gpu_async_region/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuAsyncRegionPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_async_region/0","ref":"Beaver.MLIR.Transform.html#gpu_async_region/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_async_region/1","ref":"Beaver.MLIR.Transform.html#gpu_async_region/1"},{"type":"function","doc":"Decomposes memref index computation into explicit ops.","title":"Beaver.MLIR.Transform.gpu_decompose_memrefs/0","ref":"Beaver.MLIR.Transform.html#gpu_decompose_memrefs/0"},{"type":"function","doc":"`gpu-decompose-memrefs`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_decompose_memrefs/0","ref":"Beaver.MLIR.Transform.html#gpu_decompose_memrefs/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuDecomposeMemrefsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_decompose_memrefs/0","ref":"Beaver.MLIR.Transform.html#gpu_decompose_memrefs/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_decompose_memrefs/1","ref":"Beaver.MLIR.Transform.html#gpu_decompose_memrefs/1"},{"type":"function","doc":"Erase unnecessary barriers","title":"Beaver.MLIR.Transform.gpu_eliminate_barriers/0","ref":"Beaver.MLIR.Transform.html#gpu_eliminate_barriers/0"},{"type":"function","doc":"`gpu-eliminate-barriers`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_eliminate_barriers/0","ref":"Beaver.MLIR.Transform.html#gpu_eliminate_barriers/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuEliminateBarriers`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_eliminate_barriers/0","ref":"Beaver.MLIR.Transform.html#gpu_eliminate_barriers/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_eliminate_barriers/1","ref":"Beaver.MLIR.Transform.html#gpu_eliminate_barriers/1"},{"type":"function","doc":"Outline gpu.launch bodies to kernel functions","title":"Beaver.MLIR.Transform.gpu_kernel_outlining/0","ref":"Beaver.MLIR.Transform.html#gpu_kernel_outlining/0"},{"type":"function","doc":"`gpu-kernel-outlining`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_kernel_outlining/0","ref":"Beaver.MLIR.Transform.html#gpu_kernel_outlining/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuKernelOutlining`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_kernel_outlining/0","ref":"Beaver.MLIR.Transform.html#gpu_kernel_outlining/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_kernel_outlining/1","ref":"Beaver.MLIR.Transform.html#gpu_kernel_outlining/1"},{"type":"function","doc":"Sink index computations into gpu.launch body","title":"Beaver.MLIR.Transform.gpu_launch_sink_index_computations/0","ref":"Beaver.MLIR.Transform.html#gpu_launch_sink_index_computations/0"},{"type":"function","doc":"`gpu-launch-sink-index-computations`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_launch_sink_index_computations/0","ref":"Beaver.MLIR.Transform.html#gpu_launch_sink_index_computations/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuLaunchSinkIndexComputations`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_launch_sink_index_computations/0","ref":"Beaver.MLIR.Transform.html#gpu_launch_sink_index_computations/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_launch_sink_index_computations/1","ref":"Beaver.MLIR.Transform.html#gpu_launch_sink_index_computations/1"},{"type":"function","doc":"Greedily maps loops to GPU hardware dimensions.","title":"Beaver.MLIR.Transform.gpu_map_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#gpu_map_parallel_loops/0"},{"type":"function","doc":"`gpu-map-parallel-loops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_map_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#gpu_map_parallel_loops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuMapParallelLoopsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_map_parallel_loops/0","ref":"Beaver.MLIR.Transform.html#gpu_map_parallel_loops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_map_parallel_loops/1","ref":"Beaver.MLIR.Transform.html#gpu_map_parallel_loops/1"},{"type":"function","doc":"Transforms a GPU module into a GPU binary.","title":"Beaver.MLIR.Transform.gpu_module_to_binary/0","ref":"Beaver.MLIR.Transform.html#gpu_module_to_binary/0"},{"type":"function","doc":"`gpu-module-to-binary`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.gpu_module_to_binary/0","ref":"Beaver.MLIR.Transform.html#gpu_module_to_binary/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuModuleToBinaryPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.gpu_module_to_binary/0","ref":"Beaver.MLIR.Transform.html#gpu_module_to_binary/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.gpu_module_to_binary/1","ref":"Beaver.MLIR.Transform.html#gpu_module_to_binary/1"},{"type":"function","doc":"Inline function calls","title":"Beaver.MLIR.Transform.inline/0","ref":"Beaver.MLIR.Transform.html#inline/0"},{"type":"function","doc":"`inline`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.inline/0","ref":"Beaver.MLIR.Transform.html#inline/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`Inliner`","title":"Pass name in TableGen - Beaver.MLIR.Transform.inline/0","ref":"Beaver.MLIR.Transform.html#inline/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.inline/1","ref":"Beaver.MLIR.Transform.html#inline/1"},{"type":"function","doc":"Convert linalg matmul ops to block layout and back","title":"Beaver.MLIR.Transform.linalg_block_pack_matmul/0","ref":"Beaver.MLIR.Transform.html#linalg_block_pack_matmul/0"},{"type":"function","doc":"`linalg-block-pack-matmul`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_block_pack_matmul/0","ref":"Beaver.MLIR.Transform.html#linalg_block_pack_matmul/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgBlockPackMatmul`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_block_pack_matmul/0","ref":"Beaver.MLIR.Transform.html#linalg_block_pack_matmul/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_block_pack_matmul/1","ref":"Beaver.MLIR.Transform.html#linalg_block_pack_matmul/1"},{"type":"function","doc":"Detensorize linalg ops","title":"Beaver.MLIR.Transform.linalg_detensorize/0","ref":"Beaver.MLIR.Transform.html#linalg_detensorize/0"},{"type":"function","doc":"`linalg-detensorize`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_detensorize/0","ref":"Beaver.MLIR.Transform.html#linalg_detensorize/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgDetensorizePass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_detensorize/0","ref":"Beaver.MLIR.Transform.html#linalg_detensorize/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_detensorize/1","ref":"Beaver.MLIR.Transform.html#linalg_detensorize/1"},{"type":"function","doc":"Remove unit-extent dimension in Linalg ops on tensors","title":"Beaver.MLIR.Transform.linalg_fold_unit_extent_dims/0","ref":"Beaver.MLIR.Transform.html#linalg_fold_unit_extent_dims/0"},{"type":"function","doc":"`linalg-fold-unit-extent-dims`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_fold_unit_extent_dims/0","ref":"Beaver.MLIR.Transform.html#linalg_fold_unit_extent_dims/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgFoldUnitExtentDimsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_fold_unit_extent_dims/0","ref":"Beaver.MLIR.Transform.html#linalg_fold_unit_extent_dims/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_fold_unit_extent_dims/1","ref":"Beaver.MLIR.Transform.html#linalg_fold_unit_extent_dims/1"},{"type":"function","doc":"Fuse elementwise operations on tensors","title":"Beaver.MLIR.Transform.linalg_fuse_elementwise_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_fuse_elementwise_ops/0"},{"type":"function","doc":"`linalg-fuse-elementwise-ops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_fuse_elementwise_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_fuse_elementwise_ops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgElementwiseOpFusionPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_fuse_elementwise_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_fuse_elementwise_ops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_fuse_elementwise_ops/1","ref":"Beaver.MLIR.Transform.html#linalg_fuse_elementwise_ops/1"},{"type":"function","doc":"Convert named ops into generic ops","title":"Beaver.MLIR.Transform.linalg_generalize_named_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_generalize_named_ops/0"},{"type":"function","doc":"`linalg-generalize-named-ops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_generalize_named_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_generalize_named_ops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgGeneralizeNamedOpsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_generalize_named_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_generalize_named_ops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_generalize_named_ops/1","ref":"Beaver.MLIR.Transform.html#linalg_generalize_named_ops/1"},{"type":"function","doc":"Inline scalar operands into linalg generic ops","title":"Beaver.MLIR.Transform.linalg_inline_scalar_operands/0","ref":"Beaver.MLIR.Transform.html#linalg_inline_scalar_operands/0"},{"type":"function","doc":"`linalg-inline-scalar-operands`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_inline_scalar_operands/0","ref":"Beaver.MLIR.Transform.html#linalg_inline_scalar_operands/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgInlineScalarOperandsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_inline_scalar_operands/0","ref":"Beaver.MLIR.Transform.html#linalg_inline_scalar_operands/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_inline_scalar_operands/1","ref":"Beaver.MLIR.Transform.html#linalg_inline_scalar_operands/1"},{"type":"function","doc":"Convert from one named linalg op to another.","title":"Beaver.MLIR.Transform.linalg_named_op_conversion/0","ref":"Beaver.MLIR.Transform.html#linalg_named_op_conversion/0"},{"type":"function","doc":"`linalg-named-op-conversion`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_named_op_conversion/0","ref":"Beaver.MLIR.Transform.html#linalg_named_op_conversion/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgNamedOpConversionPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_named_op_conversion/0","ref":"Beaver.MLIR.Transform.html#linalg_named_op_conversion/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_named_op_conversion/1","ref":"Beaver.MLIR.Transform.html#linalg_named_op_conversion/1"},{"type":"function","doc":"Convert generic ops back to named ops","title":"Beaver.MLIR.Transform.linalg_specialize_generic_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_specialize_generic_ops/0"},{"type":"function","doc":"`linalg-specialize-generic-ops`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.linalg_specialize_generic_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_specialize_generic_ops/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LinalgSpecializeGenericOpsPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.linalg_specialize_generic_ops/0","ref":"Beaver.MLIR.Transform.html#linalg_specialize_generic_ops/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.linalg_specialize_generic_ops/1","ref":"Beaver.MLIR.Transform.html#linalg_specialize_generic_ops/1"},{"type":"function","doc":"Hoist loop invariant instructions outside of the loop","title":"Beaver.MLIR.Transform.loop_invariant_code_motion/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_code_motion/0"},{"type":"function","doc":"`loop-invariant-code-motion`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.loop_invariant_code_motion/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_code_motion/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LoopInvariantCodeMotion`","title":"Pass name in TableGen - Beaver.MLIR.Transform.loop_invariant_code_motion/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_code_motion/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.loop_invariant_code_motion/1","ref":"Beaver.MLIR.Transform.html#loop_invariant_code_motion/1"},{"type":"function","doc":"Hoist loop invariant subset ops outside of the loop","title":"Beaver.MLIR.Transform.loop_invariant_subset_hoisting/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_subset_hoisting/0"},{"type":"function","doc":"`loop-invariant-subset-hoisting`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.loop_invariant_subset_hoisting/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_subset_hoisting/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LoopInvariantSubsetHoisting`","title":"Pass name in TableGen - Beaver.MLIR.Transform.loop_invariant_subset_hoisting/0","ref":"Beaver.MLIR.Transform.html#loop_invariant_subset_hoisting/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.loop_invariant_subset_hoisting/1","ref":"Beaver.MLIR.Transform.html#loop_invariant_subset_hoisting/1"},{"type":"function","doc":"Promotes memory slots into values.","title":"Beaver.MLIR.Transform.mem2reg/0","ref":"Beaver.MLIR.Transform.html#mem2reg/0"},{"type":"function","doc":"`mem2reg`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.mem2reg/0","ref":"Beaver.MLIR.Transform.html#mem2reg/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`Mem2Reg`","title":"Pass name in TableGen - Beaver.MLIR.Transform.mem2reg/0","ref":"Beaver.MLIR.Transform.html#mem2reg/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.mem2reg/1","ref":"Beaver.MLIR.Transform.html#mem2reg/1"},{"type":"function","doc":"Attaches an NVVM target attribute to a GPU Module.","title":"Beaver.MLIR.Transform.nvvm_attach_target/0","ref":"Beaver.MLIR.Transform.html#nvvm_attach_target/0"},{"type":"function","doc":"`nvvm-attach-target`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.nvvm_attach_target/0","ref":"Beaver.MLIR.Transform.html#nvvm_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuNVVMAttachTarget`","title":"Pass name in TableGen - Beaver.MLIR.Transform.nvvm_attach_target/0","ref":"Beaver.MLIR.Transform.html#nvvm_attach_target/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.nvvm_attach_target/1","ref":"Beaver.MLIR.Transform.html#nvvm_attach_target/1"},{"type":"function","doc":"Print IR on the debug stream","title":"Beaver.MLIR.Transform.print_ir/0","ref":"Beaver.MLIR.Transform.html#print_ir/0"},{"type":"function","doc":"`print-ir`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.print_ir/0","ref":"Beaver.MLIR.Transform.html#print_ir/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`PrintIRPass`","title":"Pass name in TableGen - Beaver.MLIR.Transform.print_ir/0","ref":"Beaver.MLIR.Transform.html#print_ir/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.print_ir/1","ref":"Beaver.MLIR.Transform.html#print_ir/1"},{"type":"function","doc":"Print statistics of operations","title":"Beaver.MLIR.Transform.print_op_stats/0","ref":"Beaver.MLIR.Transform.html#print_op_stats/0"},{"type":"function","doc":"`print-op-stats`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.print_op_stats/0","ref":"Beaver.MLIR.Transform.html#print_op_stats/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`PrintOpStats`","title":"Pass name in TableGen - Beaver.MLIR.Transform.print_op_stats/0","ref":"Beaver.MLIR.Transform.html#print_op_stats/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.print_op_stats/1","ref":"Beaver.MLIR.Transform.html#print_op_stats/1"},{"type":"function","doc":"Remove dead values","title":"Beaver.MLIR.Transform.remove_dead_values/0","ref":"Beaver.MLIR.Transform.html#remove_dead_values/0"},{"type":"function","doc":"`remove-dead-values`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.remove_dead_values/0","ref":"Beaver.MLIR.Transform.html#remove_dead_values/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`RemoveDeadValues`","title":"Pass name in TableGen - Beaver.MLIR.Transform.remove_dead_values/0","ref":"Beaver.MLIR.Transform.html#remove_dead_values/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.remove_dead_values/1","ref":"Beaver.MLIR.Transform.html#remove_dead_values/1"},{"type":"function","doc":"Attaches a ROCDL target attribute to a GPU Module.","title":"Beaver.MLIR.Transform.rocdl_attach_target/0","ref":"Beaver.MLIR.Transform.html#rocdl_attach_target/0"},{"type":"function","doc":"`rocdl-attach-target`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.rocdl_attach_target/0","ref":"Beaver.MLIR.Transform.html#rocdl_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuROCDLAttachTarget`","title":"Pass name in TableGen - Beaver.MLIR.Transform.rocdl_attach_target/0","ref":"Beaver.MLIR.Transform.html#rocdl_attach_target/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.rocdl_attach_target/1","ref":"Beaver.MLIR.Transform.html#rocdl_attach_target/1"},{"type":"function","doc":"Sparse Conditional Constant Propagation","title":"Beaver.MLIR.Transform.sccp/0","ref":"Beaver.MLIR.Transform.html#sccp/0"},{"type":"function","doc":"`sccp`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.sccp/0","ref":"Beaver.MLIR.Transform.html#sccp/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SCCP`","title":"Pass name in TableGen - Beaver.MLIR.Transform.sccp/0","ref":"Beaver.MLIR.Transform.html#sccp/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.sccp/1","ref":"Beaver.MLIR.Transform.html#sccp/1"},{"type":"function","doc":"Generate new locations from the current IR","title":"Beaver.MLIR.Transform.snapshot_op_locations/0","ref":"Beaver.MLIR.Transform.html#snapshot_op_locations/0"},{"type":"function","doc":"`snapshot-op-locations`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.snapshot_op_locations/0","ref":"Beaver.MLIR.Transform.html#snapshot_op_locations/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`LocationSnapshot`","title":"Pass name in TableGen - Beaver.MLIR.Transform.snapshot_op_locations/0","ref":"Beaver.MLIR.Transform.html#snapshot_op_locations/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.snapshot_op_locations/1","ref":"Beaver.MLIR.Transform.html#snapshot_op_locations/1"},{"type":"function","doc":"Attaches an SPIR-V target attribute to a GPU Module.","title":"Beaver.MLIR.Transform.spirv_attach_target/0","ref":"Beaver.MLIR.Transform.html#spirv_attach_target/0"},{"type":"function","doc":"`spirv-attach-target`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.spirv_attach_target/0","ref":"Beaver.MLIR.Transform.html#spirv_attach_target/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`GpuSPIRVAttachTarget`","title":"Pass name in TableGen - Beaver.MLIR.Transform.spirv_attach_target/0","ref":"Beaver.MLIR.Transform.html#spirv_attach_target/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.spirv_attach_target/1","ref":"Beaver.MLIR.Transform.html#spirv_attach_target/1"},{"type":"function","doc":"Scalar Replacement of Aggregates","title":"Beaver.MLIR.Transform.sroa/0","ref":"Beaver.MLIR.Transform.html#sroa/0"},{"type":"function","doc":"`sroa`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.sroa/0","ref":"Beaver.MLIR.Transform.html#sroa/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SROA`","title":"Pass name in TableGen - Beaver.MLIR.Transform.sroa/0","ref":"Beaver.MLIR.Transform.html#sroa/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.sroa/1","ref":"Beaver.MLIR.Transform.html#sroa/1"},{"type":"function","doc":"Strip debug info from all operations","title":"Beaver.MLIR.Transform.strip_debuginfo/0","ref":"Beaver.MLIR.Transform.html#strip_debuginfo/0"},{"type":"function","doc":"`strip-debuginfo`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.strip_debuginfo/0","ref":"Beaver.MLIR.Transform.html#strip_debuginfo/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`StripDebugInfo`","title":"Pass name in TableGen - Beaver.MLIR.Transform.strip_debuginfo/0","ref":"Beaver.MLIR.Transform.html#strip_debuginfo/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.strip_debuginfo/1","ref":"Beaver.MLIR.Transform.html#strip_debuginfo/1"},{"type":"function","doc":"Eliminate dead symbols","title":"Beaver.MLIR.Transform.symbol_dce/0","ref":"Beaver.MLIR.Transform.html#symbol_dce/0"},{"type":"function","doc":"`symbol-dce`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.symbol_dce/0","ref":"Beaver.MLIR.Transform.html#symbol_dce/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SymbolDCE`","title":"Pass name in TableGen - Beaver.MLIR.Transform.symbol_dce/0","ref":"Beaver.MLIR.Transform.html#symbol_dce/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.symbol_dce/1","ref":"Beaver.MLIR.Transform.html#symbol_dce/1"},{"type":"function","doc":"Mark symbols private","title":"Beaver.MLIR.Transform.symbol_privatize/0","ref":"Beaver.MLIR.Transform.html#symbol_privatize/0"},{"type":"function","doc":"`symbol-privatize`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.symbol_privatize/0","ref":"Beaver.MLIR.Transform.html#symbol_privatize/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`SymbolPrivatize`","title":"Pass name in TableGen - Beaver.MLIR.Transform.symbol_privatize/0","ref":"Beaver.MLIR.Transform.html#symbol_privatize/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.symbol_privatize/1","ref":"Beaver.MLIR.Transform.html#symbol_privatize/1"},{"type":"function","doc":"Sort regions without SSA dominance in topological order","title":"Beaver.MLIR.Transform.topological_sort/0","ref":"Beaver.MLIR.Transform.html#topological_sort/0"},{"type":"function","doc":"`topological-sort`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.topological_sort/0","ref":"Beaver.MLIR.Transform.html#topological_sort/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`TopologicalSort`","title":"Pass name in TableGen - Beaver.MLIR.Transform.topological_sort/0","ref":"Beaver.MLIR.Transform.html#topological_sort/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.topological_sort/1","ref":"Beaver.MLIR.Transform.html#topological_sort/1"},{"type":"function","doc":"Print Graphviz visualization of an operation","title":"Beaver.MLIR.Transform.view_op_graph/0","ref":"Beaver.MLIR.Transform.html#view_op_graph/0"},{"type":"function","doc":"`view-op-graph`","title":"Argument name in MLIR CLI - Beaver.MLIR.Transform.view_op_graph/0","ref":"Beaver.MLIR.Transform.html#view_op_graph/0-argument-name-in-mlir-cli"},{"type":"function","doc":"`ViewOpGraph`","title":"Pass name in TableGen - Beaver.MLIR.Transform.view_op_graph/0","ref":"Beaver.MLIR.Transform.html#view_op_graph/0-pass-name-in-tablegen"},{"type":"function","doc":"","title":"Beaver.MLIR.Transform.view_op_graph/1","ref":"Beaver.MLIR.Transform.html#view_op_graph/1"},{"type":"module","doc":"","title":"Beaver.MLIR.TransformOptions","ref":"Beaver.MLIR.TransformOptions.html"},{"type":"function","doc":"","title":"Beaver.MLIR.TransformOptions.make/1","ref":"Beaver.MLIR.TransformOptions.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.TransformOptions.t/0","ref":"Beaver.MLIR.TransformOptions.html#t:t/0"},{"type":"module","doc":"This module provides functions to work with MLIR's type system, allowing creation of MLIR type.","title":"Beaver.MLIR.Type","ref":"Beaver.MLIR.Type.html"},{"type":"module","doc":"","title":"Type Categories - Beaver.MLIR.Type","ref":"Beaver.MLIR.Type.html#module-type-categories"},{"type":"module","doc":"- `integer/1` (`i32/1`, `i64/1`, etc.)\n- `float/1` (`f32/1`, `f64/1`, etc.)\n- `index/1`\n- `none/1`","title":"Basic Types - Beaver.MLIR.Type","ref":"Beaver.MLIR.Type.html#module-basic-types"},{"type":"module","doc":"- Tensors (`ranked_tensor/2` and `unranked_tensor/1`)\n- `vector/2`\n- `memref/3`\n- `function/3`","title":"Composite Types - Beaver.MLIR.Type","ref":"Beaver.MLIR.Type.html#module-composite-types"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.any_quantized_type?/1","ref":"Beaver.MLIR.Type.html#any_quantized_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.bf16?/1","ref":"Beaver.MLIR.Type.html#bf16?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.calibrated_quantized_type?/1","ref":"Beaver.MLIR.Type.html#calibrated_quantized_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.complex/1","ref":"Beaver.MLIR.Type.html#complex/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.complex?/1","ref":"Beaver.MLIR.Type.html#complex?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_array_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_array_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_opaque_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_opaque_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_pointer_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_pointer_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_ptr_diff_t_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_ptr_diff_t_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_signed_size_t_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_signed_size_t_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_c_size_t_type?/1","ref":"Beaver.MLIR.Type.html#emit_c_size_t_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.emit_cl_value_type?/1","ref":"Beaver.MLIR.Type.html#emit_cl_value_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f16/1","ref":"Beaver.MLIR.Type.html#f16/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f16?/1","ref":"Beaver.MLIR.Type.html#f16?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f32/1","ref":"Beaver.MLIR.Type.html#f32/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f32?/1","ref":"Beaver.MLIR.Type.html#f32?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f64/1","ref":"Beaver.MLIR.Type.html#f64/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f64?/1","ref":"Beaver.MLIR.Type.html#f64?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.f/2","ref":"Beaver.MLIR.Type.html#f/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float4_e2_m1_fn?/1","ref":"Beaver.MLIR.Type.html#float4_e2_m1_fn?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float6_e2_m3_fn?/1","ref":"Beaver.MLIR.Type.html#float6_e2_m3_fn?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float6_e3_m2_fn?/1","ref":"Beaver.MLIR.Type.html#float6_e3_m2_fn?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e3_m4?/1","ref":"Beaver.MLIR.Type.html#float8_e3_m4?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e4_m3?/1","ref":"Beaver.MLIR.Type.html#float8_e4_m3?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e4_m3_b11_fnuz?/1","ref":"Beaver.MLIR.Type.html#float8_e4_m3_b11_fnuz?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e4_m3_fn?/1","ref":"Beaver.MLIR.Type.html#float8_e4_m3_fn?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e4_m3_fnuz?/1","ref":"Beaver.MLIR.Type.html#float8_e4_m3_fnuz?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e5_m2?/1","ref":"Beaver.MLIR.Type.html#float8_e5_m2?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e5_m2_fnuz?/1","ref":"Beaver.MLIR.Type.html#float8_e5_m2_fnuz?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float8_e8_m0_fnu?/1","ref":"Beaver.MLIR.Type.html#float8_e8_m0_fnu?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float/2","ref":"Beaver.MLIR.Type.html#float/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.float?/1","ref":"Beaver.MLIR.Type.html#float?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.function/3","ref":"Beaver.MLIR.Type.html#function/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.function?/1","ref":"Beaver.MLIR.Type.html#function?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.get/2","ref":"Beaver.MLIR.Type.html#get/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.gpu_async_token_type?/1","ref":"Beaver.MLIR.Type.html#gpu_async_token_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i1/1","ref":"Beaver.MLIR.Type.html#i1/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i8/1","ref":"Beaver.MLIR.Type.html#i8/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i16/1","ref":"Beaver.MLIR.Type.html#i16/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i32/1","ref":"Beaver.MLIR.Type.html#i32/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i64/1","ref":"Beaver.MLIR.Type.html#i64/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i128/1","ref":"Beaver.MLIR.Type.html#i128/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.i/2","ref":"Beaver.MLIR.Type.html#i/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.index/1","ref":"Beaver.MLIR.Type.html#index/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.index?/1","ref":"Beaver.MLIR.Type.html#index?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.integer/2","ref":"Beaver.MLIR.Type.html#integer/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.integer?/1","ref":"Beaver.MLIR.Type.html#integer?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.llvm_pointer_type?/1","ref":"Beaver.MLIR.Type.html#llvm_pointer_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.llvm_struct_type?/1","ref":"Beaver.MLIR.Type.html#llvm_struct_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.make/1","ref":"Beaver.MLIR.Type.html#make/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.memref/3","ref":"Beaver.MLIR.Type.html#memref/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.memref!/3","ref":"Beaver.MLIR.Type.html#memref!/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.memref?/1","ref":"Beaver.MLIR.Type.html#memref?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.none/1","ref":"Beaver.MLIR.Type.html#none/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.none?/1","ref":"Beaver.MLIR.Type.html#none?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.nvgpu_tensor_map_descriptor_type?/1","ref":"Beaver.MLIR.Type.html#nvgpu_tensor_map_descriptor_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.opaque?/1","ref":"Beaver.MLIR.Type.html#opaque?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_attribute_type?/1","ref":"Beaver.MLIR.Type.html#pdl_attribute_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_operation_type?/1","ref":"Beaver.MLIR.Type.html#pdl_operation_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_range_type?/1","ref":"Beaver.MLIR.Type.html#pdl_range_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_type?/1","ref":"Beaver.MLIR.Type.html#pdl_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_type_type?/1","ref":"Beaver.MLIR.Type.html#pdl_type_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.pdl_value_type?/1","ref":"Beaver.MLIR.Type.html#pdl_value_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.quantized_type?/1","ref":"Beaver.MLIR.Type.html#quantized_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.ranked_tensor/3","ref":"Beaver.MLIR.Type.html#ranked_tensor/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.ranked_tensor!/3","ref":"Beaver.MLIR.Type.html#ranked_tensor!/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.ranked_tensor?/1","ref":"Beaver.MLIR.Type.html#ranked_tensor?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.shaped?/1","ref":"Beaver.MLIR.Type.html#shaped?/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Type.t/0","ref":"Beaver.MLIR.Type.html#t:t/0"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.tensor?/1","ref":"Beaver.MLIR.Type.html#tensor?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.tf32?/1","ref":"Beaver.MLIR.Type.html#tf32?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.transform_any_op_type?/1","ref":"Beaver.MLIR.Type.html#transform_any_op_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.transform_any_param_type?/1","ref":"Beaver.MLIR.Type.html#transform_any_param_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.transform_any_value_type?/1","ref":"Beaver.MLIR.Type.html#transform_any_value_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.transform_operation_type?/1","ref":"Beaver.MLIR.Type.html#transform_operation_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.transform_param_type?/1","ref":"Beaver.MLIR.Type.html#transform_param_type?/1"},{"type":"function","doc":"Get a tuple type.","title":"Beaver.MLIR.Type.tuple/2","ref":"Beaver.MLIR.Type.html#tuple/2"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Type.tuple([MLIR.Type.i32, MLIR.Type.i32], ctx: ctx) |> MLIR.to_string()\n    \"tuple \"\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.MLIR.Type.tuple/2","ref":"Beaver.MLIR.Type.html#tuple/2-examples"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.tuple?/1","ref":"Beaver.MLIR.Type.html#tuple?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.uniform_quantized_per_axis_type?/1","ref":"Beaver.MLIR.Type.html#uniform_quantized_per_axis_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.uniform_quantized_type?/1","ref":"Beaver.MLIR.Type.html#uniform_quantized_type?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_memref/2","ref":"Beaver.MLIR.Type.html#unranked_memref/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_memref!/2","ref":"Beaver.MLIR.Type.html#unranked_memref!/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_memref?/1","ref":"Beaver.MLIR.Type.html#unranked_memref?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_tensor/2","ref":"Beaver.MLIR.Type.html#unranked_tensor/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_tensor!/2","ref":"Beaver.MLIR.Type.html#unranked_tensor!/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.unranked_tensor?/1","ref":"Beaver.MLIR.Type.html#unranked_tensor?/1"},{"type":"function","doc":"Get a vector type creator.","title":"Beaver.MLIR.Type.vector/3","ref":"Beaver.MLIR.Type.html#vector/3"},{"type":"function","doc":"iex> ctx = MLIR.Context.create()\n    iex> MLIR.Type.vector!([1, 2, 3], MLIR.Type.i32(ctx: ctx)) |> MLIR.to_string()\n    \"vector<1x2x3xi32>\"\n    iex> MLIR.Context.destroy(ctx)","title":"Examples - Beaver.MLIR.Type.vector/3","ref":"Beaver.MLIR.Type.html#vector/3-examples"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.vector!/3","ref":"Beaver.MLIR.Type.html#vector!/3"},{"type":"function","doc":"","title":"Beaver.MLIR.Type.vector?/1","ref":"Beaver.MLIR.Type.html#vector?/1"},{"type":"module","doc":"","title":"Beaver.MLIR.TypeID","ref":"Beaver.MLIR.TypeID.html"},{"type":"function","doc":"","title":"Beaver.MLIR.TypeID.make/1","ref":"Beaver.MLIR.TypeID.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.TypeID.t/0","ref":"Beaver.MLIR.TypeID.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.TypeIDAllocator","ref":"Beaver.MLIR.TypeIDAllocator.html"},{"type":"function","doc":"","title":"Beaver.MLIR.TypeIDAllocator.make/1","ref":"Beaver.MLIR.TypeIDAllocator.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.TypeIDAllocator.t/0","ref":"Beaver.MLIR.TypeIDAllocator.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.TypesCallback","ref":"Beaver.MLIR.TypesCallback.html"},{"type":"function","doc":"","title":"Beaver.MLIR.TypesCallback.make/1","ref":"Beaver.MLIR.TypesCallback.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.TypesCallback.t/0","ref":"Beaver.MLIR.TypesCallback.html#t:t/0"},{"type":"module","doc":"This module handles MLIR values, which represent SSA (Static Single Assignment) values in the IR.\n\nValues can be either block arguments or operation results. That's why this module provides\nfunctions to check if a value is an argument or a result (`argument?/1`, `result?/1`), or to get the owner of a result (`owner/1`).","title":"Beaver.MLIR.Value","ref":"Beaver.MLIR.Value.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Value.argument?/1","ref":"Beaver.MLIR.Value.html#argument?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Value.make/1","ref":"Beaver.MLIR.Value.html#make/1"},{"type":"function","doc":"Return the defining op of this value if this value is a result","title":"Beaver.MLIR.Value.owner/1","ref":"Beaver.MLIR.Value.html#owner/1"},{"type":"function","doc":"Return the defining op of this value. Raises if this value is not a result","title":"Beaver.MLIR.Value.owner!/1","ref":"Beaver.MLIR.Value.html#owner!/1"},{"type":"function","doc":"Returns true if the value is a result of an operation.","title":"Beaver.MLIR.Value.result?/1","ref":"Beaver.MLIR.Value.html#result?/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Value.t/0","ref":"Beaver.MLIR.Value.html#t:t/0"},{"type":"function","doc":"Return the type of this value","title":"Beaver.MLIR.Value.type/1","ref":"Beaver.MLIR.Value.html#type/1"},{"type":"module","doc":"","title":"Beaver.MLIR.WalkOrder","ref":"Beaver.MLIR.WalkOrder.html"},{"type":"function","doc":"","title":"Beaver.MLIR.WalkOrder.make/1","ref":"Beaver.MLIR.WalkOrder.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.WalkOrder.t/0","ref":"Beaver.MLIR.WalkOrder.html#t:t/0"},{"type":"behaviour","doc":"This module defines macro to generate code for an MLIR dialect.\nYou might override `eval_ssa/1` function to introduce your custom op generation","title":"Beaver.MLIR.Dialect","ref":"Beaver.MLIR.Dialect.html"},{"type":"macro","doc":"","title":"Beaver.MLIR.Dialect.define_modules/1","ref":"Beaver.MLIR.Dialect.html#define_modules/1"},{"type":"callback","doc":"","title":"Beaver.MLIR.Dialect.eval_ssa/1","ref":"Beaver.MLIR.Dialect.html#c:eval_ssa/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.make/1","ref":"Beaver.MLIR.Dialect.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.Dialect.t/0","ref":"Beaver.MLIR.Dialect.html#t:t/0"},{"type":"module","doc":"This module defines functions for Ops in Arith dialect.","title":"Beaver.MLIR.Dialect.Arith","ref":"Beaver.MLIR.Dialect.Arith.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.addf/1","ref":"Beaver.MLIR.Dialect.Arith.html#addf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.addi/1","ref":"Beaver.MLIR.Dialect.Arith.html#addi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.addui_extended/1","ref":"Beaver.MLIR.Dialect.Arith.html#addui_extended/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.andi/1","ref":"Beaver.MLIR.Dialect.Arith.html#andi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.bitcast/1","ref":"Beaver.MLIR.Dialect.Arith.html#bitcast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.ceildivsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#ceildivsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.ceildivui/1","ref":"Beaver.MLIR.Dialect.Arith.html#ceildivui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.cmp_f_predicate/1","ref":"Beaver.MLIR.Dialect.Arith.html#cmp_f_predicate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.cmp_i_predicate/1","ref":"Beaver.MLIR.Dialect.Arith.html#cmp_i_predicate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.cmpf/1","ref":"Beaver.MLIR.Dialect.Arith.html#cmpf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.cmpi/1","ref":"Beaver.MLIR.Dialect.Arith.html#cmpi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.constant/1","ref":"Beaver.MLIR.Dialect.Arith.html#constant/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.divf/1","ref":"Beaver.MLIR.Dialect.Arith.html#divf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.divsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#divsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.divui/1","ref":"Beaver.MLIR.Dialect.Arith.html#divui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.extf/1","ref":"Beaver.MLIR.Dialect.Arith.html#extf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.extsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#extsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.extui/1","ref":"Beaver.MLIR.Dialect.Arith.html#extui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.floordivsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#floordivsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.fptosi/1","ref":"Beaver.MLIR.Dialect.Arith.html#fptosi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.fptoui/1","ref":"Beaver.MLIR.Dialect.Arith.html#fptoui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.index_cast/1","ref":"Beaver.MLIR.Dialect.Arith.html#index_cast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.index_castui/1","ref":"Beaver.MLIR.Dialect.Arith.html#index_castui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.maximumf/1","ref":"Beaver.MLIR.Dialect.Arith.html#maximumf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.maxnumf/1","ref":"Beaver.MLIR.Dialect.Arith.html#maxnumf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.maxsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#maxsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.maxui/1","ref":"Beaver.MLIR.Dialect.Arith.html#maxui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.minimumf/1","ref":"Beaver.MLIR.Dialect.Arith.html#minimumf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.minnumf/1","ref":"Beaver.MLIR.Dialect.Arith.html#minnumf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.minsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#minsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.minui/1","ref":"Beaver.MLIR.Dialect.Arith.html#minui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.mulf/1","ref":"Beaver.MLIR.Dialect.Arith.html#mulf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.muli/1","ref":"Beaver.MLIR.Dialect.Arith.html#muli/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.mulsi_extended/1","ref":"Beaver.MLIR.Dialect.Arith.html#mulsi_extended/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.mului_extended/1","ref":"Beaver.MLIR.Dialect.Arith.html#mului_extended/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.negf/1","ref":"Beaver.MLIR.Dialect.Arith.html#negf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.operator_to_predicate/2","ref":"Beaver.MLIR.Dialect.Arith.html#operator_to_predicate/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.ori/1","ref":"Beaver.MLIR.Dialect.Arith.html#ori/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.remf/1","ref":"Beaver.MLIR.Dialect.Arith.html#remf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.remsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#remsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.remui/1","ref":"Beaver.MLIR.Dialect.Arith.html#remui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.select/1","ref":"Beaver.MLIR.Dialect.Arith.html#select/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.shli/1","ref":"Beaver.MLIR.Dialect.Arith.html#shli/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.shrsi/1","ref":"Beaver.MLIR.Dialect.Arith.html#shrsi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.shrui/1","ref":"Beaver.MLIR.Dialect.Arith.html#shrui/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.sitofp/1","ref":"Beaver.MLIR.Dialect.Arith.html#sitofp/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.subf/1","ref":"Beaver.MLIR.Dialect.Arith.html#subf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.subi/1","ref":"Beaver.MLIR.Dialect.Arith.html#subi/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.truncf/1","ref":"Beaver.MLIR.Dialect.Arith.html#truncf/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.trunci/1","ref":"Beaver.MLIR.Dialect.Arith.html#trunci/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.uitofp/1","ref":"Beaver.MLIR.Dialect.Arith.html#uitofp/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Arith.xori/1","ref":"Beaver.MLIR.Dialect.Arith.html#xori/1"},{"type":"module","doc":"This module defines functions for Ops in Builtin dialect.","title":"Beaver.MLIR.Dialect.Builtin","ref":"Beaver.MLIR.Dialect.Builtin.html"},{"type":"macro","doc":"Macro to create a module and insert ops into its body. Beaver.region/1 shouldn't be called because module's one-block region will be created.","title":"Beaver.MLIR.Dialect.Builtin.module/2","ref":"Beaver.MLIR.Dialect.Builtin.html#module/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Builtin.unrealized_conversion_cast/1","ref":"Beaver.MLIR.Dialect.Builtin.html#unrealized_conversion_cast/1"},{"type":"module","doc":"This module defines functions for Ops in CF dialect.","title":"Beaver.MLIR.Dialect.CF","ref":"Beaver.MLIR.Dialect.CF.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.CF.assert/1","ref":"Beaver.MLIR.Dialect.CF.html#assert/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.CF.br/1","ref":"Beaver.MLIR.Dialect.CF.html#br/1"},{"type":"function","doc":"Create cf.cond_br op. Passing atom will lead to defer the creation of this terminator.","title":"Beaver.MLIR.Dialect.CF.cond_br/1","ref":"Beaver.MLIR.Dialect.CF.html#cond_br/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.CF.switch/1","ref":"Beaver.MLIR.Dialect.CF.html#switch/1"},{"type":"module","doc":"This module defines Elixir dialect to represent Elixir AST in MLIR. This is at the moment a placeholder for future development.","title":"Beaver.MLIR.Dialect.Elixir","ref":"Beaver.MLIR.Dialect.Elixir.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Elixir.add/1","ref":"Beaver.MLIR.Dialect.Elixir.html#add/1"},{"type":"module","doc":"This module defines functions for Ops in Func dialect.","title":"Beaver.MLIR.Dialect.Func","ref":"Beaver.MLIR.Dialect.Func.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.call/1","ref":"Beaver.MLIR.Dialect.Func.html#call/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.call_indirect/1","ref":"Beaver.MLIR.Dialect.Func.html#call_indirect/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.constant/1","ref":"Beaver.MLIR.Dialect.Func.html#constant/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.external?/1","ref":"Beaver.MLIR.Dialect.Func.html#external?/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.func/1","ref":"Beaver.MLIR.Dialect.Func.html#func/1"},{"type":"macro","doc":"","title":"Beaver.MLIR.Dialect.Func.func/2","ref":"Beaver.MLIR.Dialect.Func.html#func/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Func.return/1","ref":"Beaver.MLIR.Dialect.Func.html#return/1"},{"type":"module","doc":"This module defines functions for Ops in MemRef dialect.","title":"Beaver.MLIR.Dialect.MemRef","ref":"Beaver.MLIR.Dialect.MemRef.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.alloc/1","ref":"Beaver.MLIR.Dialect.MemRef.html#alloc/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.alloca/1","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.alloca_scope/1","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca_scope/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.alloca_scope_return/1","ref":"Beaver.MLIR.Dialect.MemRef.html#alloca_scope_return/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.assume_alignment/1","ref":"Beaver.MLIR.Dialect.MemRef.html#assume_alignment/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.atomic_rmw/1","ref":"Beaver.MLIR.Dialect.MemRef.html#atomic_rmw/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.atomic_yield/1","ref":"Beaver.MLIR.Dialect.MemRef.html#atomic_yield/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.cast/1","ref":"Beaver.MLIR.Dialect.MemRef.html#cast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.collapse_shape/1","ref":"Beaver.MLIR.Dialect.MemRef.html#collapse_shape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.copy/1","ref":"Beaver.MLIR.Dialect.MemRef.html#copy/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.dealloc/1","ref":"Beaver.MLIR.Dialect.MemRef.html#dealloc/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.dim/1","ref":"Beaver.MLIR.Dialect.MemRef.html#dim/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.dma_start/1","ref":"Beaver.MLIR.Dialect.MemRef.html#dma_start/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.dma_wait/1","ref":"Beaver.MLIR.Dialect.MemRef.html#dma_wait/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.expand_shape/1","ref":"Beaver.MLIR.Dialect.MemRef.html#expand_shape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.extract_aligned_pointer_as_index/1","ref":"Beaver.MLIR.Dialect.MemRef.html#extract_aligned_pointer_as_index/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.extract_strided_metadata/1","ref":"Beaver.MLIR.Dialect.MemRef.html#extract_strided_metadata/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.generic_atomic_rmw/1","ref":"Beaver.MLIR.Dialect.MemRef.html#generic_atomic_rmw/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.get_global/1","ref":"Beaver.MLIR.Dialect.MemRef.html#get_global/1"},{"type":"function","doc":"Create a global.","title":"Beaver.MLIR.Dialect.MemRef.global/1","ref":"Beaver.MLIR.Dialect.MemRef.html#global/1"},{"type":"function","doc":"- `global(binary(), {[:i | :f], [8 | 16 | 32 | 64 | 128]})`: To to serialize a binary to MLIR. By default, it will be a `memref<[byte size]*i8>`.","title":"Special arguments - Beaver.MLIR.Dialect.MemRef.global/1","ref":"Beaver.MLIR.Dialect.MemRef.html#global/1-special-arguments"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.load/1","ref":"Beaver.MLIR.Dialect.MemRef.html#load/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.memory_space_cast/1","ref":"Beaver.MLIR.Dialect.MemRef.html#memory_space_cast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.prefetch/1","ref":"Beaver.MLIR.Dialect.MemRef.html#prefetch/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.rank/1","ref":"Beaver.MLIR.Dialect.MemRef.html#rank/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.realloc/1","ref":"Beaver.MLIR.Dialect.MemRef.html#realloc/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.reinterpret_cast/1","ref":"Beaver.MLIR.Dialect.MemRef.html#reinterpret_cast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.reshape/1","ref":"Beaver.MLIR.Dialect.MemRef.html#reshape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.store/1","ref":"Beaver.MLIR.Dialect.MemRef.html#store/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.subview/1","ref":"Beaver.MLIR.Dialect.MemRef.html#subview/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.transpose/1","ref":"Beaver.MLIR.Dialect.MemRef.html#transpose/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.MemRef.view/1","ref":"Beaver.MLIR.Dialect.MemRef.html#view/1"},{"type":"module","doc":"This module defines functions to query MLIR dialect registry.","title":"Beaver.MLIR.Dialect.Registry","ref":"Beaver.MLIR.Dialect.Registry.html"},{"type":"function","doc":"Get dialects registered","title":"Beaver.MLIR.Dialect.Registry.dialects/1","ref":"Beaver.MLIR.Dialect.Registry.html#dialects/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Registry.normalize_dialect_name/1","ref":"Beaver.MLIR.Dialect.Registry.html#normalize_dialect_name/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Registry.normalize_op_name/1","ref":"Beaver.MLIR.Dialect.Registry.html#normalize_op_name/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Registry.ops/2","ref":"Beaver.MLIR.Dialect.Registry.html#ops/2"},{"type":"module","doc":"This module defines functions for Ops in Tensor dialect.","title":"Beaver.MLIR.Dialect.Tensor","ref":"Beaver.MLIR.Dialect.Tensor.html"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.bitcast/1","ref":"Beaver.MLIR.Dialect.Tensor.html#bitcast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.cast/1","ref":"Beaver.MLIR.Dialect.Tensor.html#cast/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.collapse_shape/1","ref":"Beaver.MLIR.Dialect.Tensor.html#collapse_shape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.concat/1","ref":"Beaver.MLIR.Dialect.Tensor.html#concat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.dim/1","ref":"Beaver.MLIR.Dialect.Tensor.html#dim/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.empty/1","ref":"Beaver.MLIR.Dialect.Tensor.html#empty/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.expand_shape/1","ref":"Beaver.MLIR.Dialect.Tensor.html#expand_shape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.extract/1","ref":"Beaver.MLIR.Dialect.Tensor.html#extract/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.extract_slice/1","ref":"Beaver.MLIR.Dialect.Tensor.html#extract_slice/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.from_elements/1","ref":"Beaver.MLIR.Dialect.Tensor.html#from_elements/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.gather/1","ref":"Beaver.MLIR.Dialect.Tensor.html#gather/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.generate/1","ref":"Beaver.MLIR.Dialect.Tensor.html#generate/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.insert/1","ref":"Beaver.MLIR.Dialect.Tensor.html#insert/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.insert_slice/1","ref":"Beaver.MLIR.Dialect.Tensor.html#insert_slice/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.pack/1","ref":"Beaver.MLIR.Dialect.Tensor.html#pack/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.pad/1","ref":"Beaver.MLIR.Dialect.Tensor.html#pad/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.parallel_insert_slice/1","ref":"Beaver.MLIR.Dialect.Tensor.html#parallel_insert_slice/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.rank/1","ref":"Beaver.MLIR.Dialect.Tensor.html#rank/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.reassociation/1","ref":"Beaver.MLIR.Dialect.Tensor.html#reassociation/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.reassociation_for_reshape/2","ref":"Beaver.MLIR.Dialect.Tensor.html#reassociation_for_reshape/2"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.reshape/1","ref":"Beaver.MLIR.Dialect.Tensor.html#reshape/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.scatter/1","ref":"Beaver.MLIR.Dialect.Tensor.html#scatter/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.splat/1","ref":"Beaver.MLIR.Dialect.Tensor.html#splat/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.unpack/1","ref":"Beaver.MLIR.Dialect.Tensor.html#unpack/1"},{"type":"function","doc":"","title":"Beaver.MLIR.Dialect.Tensor.yield/1","ref":"Beaver.MLIR.Dialect.Tensor.html#yield/1"},{"type":"module","doc":"","title":"Beaver.MLIR.DialectHandle","ref":"Beaver.MLIR.DialectHandle.html"},{"type":"function","doc":"","title":"Beaver.MLIR.DialectHandle.make/1","ref":"Beaver.MLIR.DialectHandle.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.DialectHandle.t/0","ref":"Beaver.MLIR.DialectHandle.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.MLIR.DialectRegistry","ref":"Beaver.MLIR.DialectRegistry.html"},{"type":"function","doc":"","title":"Beaver.MLIR.DialectRegistry.make/1","ref":"Beaver.MLIR.DialectRegistry.html#make/1"},{"type":"type","doc":"","title":"Beaver.MLIR.DialectRegistry.t/0","ref":"Beaver.MLIR.DialectRegistry.html#t:t/0"},{"type":"module","doc":"This module provide higher level interface to primitive data types and MemRefDescriptor C struct in [MemRef](https://mlir.llvm.org/docs/Dialects/MemRef/) dialect.\nIt aims to manage memory with BEAM and help a Erlang/Elixir function play well with function generated by MLIR and other NIFs.","title":"Beaver.Native","ref":"Beaver.Native.html"},{"type":"function","doc":"","title":"Beaver.Native.apply_dirty/3","ref":"Beaver.Native.html#apply_dirty/3"},{"type":"function","doc":"","title":"Beaver.Native.array/3","ref":"Beaver.Native.html#array/3"},{"type":"function","doc":"","title":"Beaver.Native.check!/1","ref":"Beaver.Native.html#check!/1"},{"type":"function","doc":"","title":"Beaver.Native.dump/1","ref":"Beaver.Native.html#dump/1"},{"type":"function","doc":"","title":"Beaver.Native.forward/3","ref":"Beaver.Native.html#forward/3"},{"type":"function","doc":"","title":"Beaver.Native.opaque_ptr/1","ref":"Beaver.Native.html#opaque_ptr/1"},{"type":"function","doc":"","title":"Beaver.Native.ptr/1","ref":"Beaver.Native.html#ptr/1"},{"type":"function","doc":"","title":"Beaver.Native.to_term/1","ref":"Beaver.Native.html#to_term/1"},{"type":"module","doc":"This module defines functions working with C array.","title":"Beaver.Native.Array","ref":"Beaver.Native.Array.html"},{"type":"function","doc":"","title":"Beaver.Native.Array.as_opaque/1","ref":"Beaver.Native.Array.html#as_opaque/1"},{"type":"module","doc":"","title":"Beaver.Native.Bool","ref":"Beaver.Native.Bool.html"},{"type":"function","doc":"","title":"Beaver.Native.Bool.make/1","ref":"Beaver.Native.Bool.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.Bool.t/0","ref":"Beaver.Native.Bool.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.CInt","ref":"Beaver.Native.CInt.html"},{"type":"function","doc":"","title":"Beaver.Native.CInt.make/1","ref":"Beaver.Native.CInt.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.CInt.t/0","ref":"Beaver.Native.CInt.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.CUInt","ref":"Beaver.Native.CUInt.html"},{"type":"function","doc":"","title":"Beaver.Native.CUInt.make/1","ref":"Beaver.Native.CUInt.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.CUInt.t/0","ref":"Beaver.Native.CUInt.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.Complex.F32","ref":"Beaver.Native.Complex.F32.html"},{"type":"function","doc":"","title":"Beaver.Native.Complex.F32.make/1","ref":"Beaver.Native.Complex.F32.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.Complex.F32.t/0","ref":"Beaver.Native.Complex.F32.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.F32","ref":"Beaver.Native.F32.html"},{"type":"function","doc":"","title":"Beaver.Native.F32.make/1","ref":"Beaver.Native.F32.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.F32.t/0","ref":"Beaver.Native.F32.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.F64","ref":"Beaver.Native.F64.html"},{"type":"function","doc":"","title":"Beaver.Native.F64.make/1","ref":"Beaver.Native.F64.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.F64.t/0","ref":"Beaver.Native.F64.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.I16","ref":"Beaver.Native.I16.html"},{"type":"function","doc":"","title":"Beaver.Native.I16.make/1","ref":"Beaver.Native.I16.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.I16.t/0","ref":"Beaver.Native.I16.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.I32","ref":"Beaver.Native.I32.html"},{"type":"function","doc":"","title":"Beaver.Native.I32.make/1","ref":"Beaver.Native.I32.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.I32.t/0","ref":"Beaver.Native.I32.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.I64","ref":"Beaver.Native.I64.html"},{"type":"function","doc":"","title":"Beaver.Native.I64.make/1","ref":"Beaver.Native.I64.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.I64.t/0","ref":"Beaver.Native.I64.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.I8","ref":"Beaver.Native.I8.html"},{"type":"function","doc":"","title":"Beaver.Native.I8.make/1","ref":"Beaver.Native.I8.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.I8.t/0","ref":"Beaver.Native.I8.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.ISize","ref":"Beaver.Native.ISize.html"},{"type":"function","doc":"","title":"Beaver.Native.ISize.make/1","ref":"Beaver.Native.ISize.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.ISize.t/0","ref":"Beaver.Native.ISize.html#t:t/0"},{"type":"module","doc":"A piece of memory managed by BEAM and can by addressed by a generated native function as MLIR MemRef descriptor","title":"Beaver.Native.Memory","ref":"Beaver.Native.Memory.html"},{"type":"function","doc":"return a opaque pointer to the memory","title":"Beaver.Native.Memory.aligned/1","ref":"Beaver.Native.Memory.html#aligned/1"},{"type":"function","doc":"","title":"Beaver.Native.Memory.allocated/1","ref":"Beaver.Native.Memory.html#allocated/1"},{"type":"function","doc":"","title":"Beaver.Native.Memory.deallocate/1","ref":"Beaver.Native.Memory.html#deallocate/1"},{"type":"function","doc":"","title":"Beaver.Native.Memory.dense_strides/1","ref":"Beaver.Native.Memory.html#dense_strides/1"},{"type":"function","doc":"return a opaque pointer to the memory descriptor. Usually used in the invoking of a generated function.\nIf it is a array, will return the pointer of the array to mimic a struct of packed memory descriptors","title":"Beaver.Native.Memory.descriptor_ptr/1","ref":"Beaver.Native.Memory.html#descriptor_ptr/1"},{"type":"function","doc":"","title":"Beaver.Native.Memory.new/2","ref":"Beaver.Native.Memory.html#new/2"},{"type":"module","doc":"","title":"Beaver.Native.OpaqueArray","ref":"Beaver.Native.OpaqueArray.html"},{"type":"function","doc":"","title":"Beaver.Native.OpaqueArray.make/1","ref":"Beaver.Native.OpaqueArray.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.OpaqueArray.t/0","ref":"Beaver.Native.OpaqueArray.html#t:t/0"},{"type":"module","doc":"This module defines functions working with opaque pointer, usually a `void*` in C.","title":"Beaver.Native.OpaquePtr","ref":"Beaver.Native.OpaquePtr.html"},{"type":"function","doc":"","title":"Beaver.Native.OpaquePtr.deallocate/1","ref":"Beaver.Native.OpaquePtr.html#deallocate/1"},{"type":"function","doc":"","title":"Beaver.Native.OpaquePtr.make/1","ref":"Beaver.Native.OpaquePtr.html#make/1"},{"type":"function","doc":"","title":"Beaver.Native.OpaquePtr.null/0","ref":"Beaver.Native.OpaquePtr.html#null/0"},{"type":"type","doc":"","title":"Beaver.Native.OpaquePtr.t/0","ref":"Beaver.Native.OpaquePtr.html#t:t/0"},{"type":"function","doc":"read the N bytes starting from the pointer and returns an Erlang binary","title":"Beaver.Native.OpaquePtr.to_binary/2","ref":"Beaver.Native.OpaquePtr.html#to_binary/2"},{"type":"function","doc":"read the N bytes starting from the pointer and return a resource","title":"Beaver.Native.OpaquePtr.to_resource/3","ref":"Beaver.Native.OpaquePtr.html#to_resource/3"},{"type":"module","doc":"This module defines functions working with pointer in C.","title":"Beaver.Native.Ptr","ref":"Beaver.Native.Ptr.html"},{"type":"module","doc":"","title":"Beaver.Native.U16","ref":"Beaver.Native.U16.html"},{"type":"function","doc":"","title":"Beaver.Native.U16.make/1","ref":"Beaver.Native.U16.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.U16.t/0","ref":"Beaver.Native.U16.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.U32","ref":"Beaver.Native.U32.html"},{"type":"function","doc":"","title":"Beaver.Native.U32.make/1","ref":"Beaver.Native.U32.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.U32.t/0","ref":"Beaver.Native.U32.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.U64","ref":"Beaver.Native.U64.html"},{"type":"function","doc":"","title":"Beaver.Native.U64.make/1","ref":"Beaver.Native.U64.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.U64.t/0","ref":"Beaver.Native.U64.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.U8","ref":"Beaver.Native.U8.html"},{"type":"function","doc":"","title":"Beaver.Native.U8.make/1","ref":"Beaver.Native.U8.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.U8.t/0","ref":"Beaver.Native.U8.html#t:t/0"},{"type":"module","doc":"","title":"Beaver.Native.USize","ref":"Beaver.Native.USize.html"},{"type":"function","doc":"","title":"Beaver.Native.USize.make/1","ref":"Beaver.Native.USize.html#make/1"},{"type":"type","doc":"","title":"Beaver.Native.USize.t/0","ref":"Beaver.Native.USize.html#t:t/0"},{"type":"extras","doc":"# Your first compiler with Beaver!\n\n```elixir\nMix.install([\n  {:beaver, \"~> 0.4\"}\n])\n```","title":"Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html"},{"type":"extras","doc":"Before start coding anything. Let's get some intuition about what a typical compiler is made of.\n\n* IR\n* Pass\n* CodeGen","title":"What makes a compiler - Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html#what-makes-a-compiler"},{"type":"extras","doc":"Most of LLVM tutorial starts with AST and parser. Guess what we are building it with Elixir and it rocks.\nSo we can start with something fun, generating the IR.\n\n```elixir\nuse Beaver\nalias Beaver.MLIR.Dialect.{Func, Arith}\nrequire Func\nctx = MLIR.Context.create()\n\nir =\n  mlir ctx: ctx do\n    module do\n      Func.func some_func(function_type: Type.function([Type.i32()], [Type.i32()])) do\n        region do\n          block _bb_entry(a >>> Type.i32()) do\n            b = Arith.constant(value: Attribute.integer(Type.i32(), 1024)) >>> Type.i32()\n            c = Arith.addi(a, b) >>> Type.i32()\n            Func.return(c) >>> []\n          end\n        end\n      end\n    end\n  end\n\nir |> Beaver.MLIR.to_string() |> IO.puts()\n```\n\nAs you can see, with MLIR we are not working with those low level LLVM instructions you might have seen somewhere else.\nHere we have this `Func.func` and `Func.return` thing looks like a function and return statement in a programming language.\nAnd the `Arith` stuff seems to be doing some arithmetic for us.\nNow you might take some time to look at the IR printed by `IO.puts` and think about it.\n\nIf you find the text full of `%1`, `%2` not so interesting, don't worry.\nThe only thing you need to know is that this is called MLIR's \"textual form\".\nLet's carry on.","title":"A taste of MLIR - Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html#a-taste-of-mlir"},{"type":"extras","doc":"The Next Big Thing™ we are going to do is to convert what we got so far to LLVM IR.\nWhy? Long story short, MLIR is like a cinematic universe.\nInstead of having different hero franchises, we got a bunch of \"dialects\". The `Func`, `Arith` are both dialects.\nThere is a dialect called `LLVM` we haven't seen. `LLVM` is a dialect kind of magical and kind of different from others.\nIt is magical that if we can convert IR to `LLVM`, we can generate native machine code and run it.\n\nThis is how it is done with Beaver:\n\n```elixir\nimport MLIR.Conversion\n\nllvm_ir =\n  ir\n  |> convert_arith_to_llvm\n  |> Beaver.Composer.nested(\"func.func\", \"llvm-request-c-wrappers\")\n  |> convert_func_to_llvm\n  |> Beaver.Composer.run!()\n\nllvm_ir |> Beaver.MLIR.to_string() |> IO.puts()\n```\n\nNow you can see the IR seems to \"grow\" a little. It is called \"lowering\".\nWhat we just did is running two passes `convert_func_to_llvm` and `convert_arith_to_llvm` on our IR.\nSo that the higher level abstraction like `Func` and `Arith` are lowered to LLVM IR,\nwhich is a representation closer to the hardware instruction.\n\nRemember what I told you, if we get to LLVM Dialect, basically we should get native machine code to run right?\nLet's do it!","title":"Entering the LLVM realm - Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html#entering-the-llvm-realm"},{"type":"extras","doc":"```elixir\njit = MLIR.ExecutionEngine.create!(llvm_ir)\n\nreturn = Beaver.Native.I32.make(0)\narguments = [Beaver.Native.I32.make(1024)]\n\nMLIR.ExecutionEngine.invoke!(jit, \"some_func\", arguments, return)\n|> Beaver.Native.to_term()\n```","title":"Run it! - Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html#run-it"},{"type":"extras","doc":"Congratulations! You have just built your first compiler with Beaver.\nThere could be a lot to unpack and here is the summary:\n\n* First we generate some MLIR with the `mlir/1` macro.\n* Then we convert it to LLVM IR with `convert_func_to_llvm` and `convert_arith_to_llvm` passes.\n* Later we create a JIT engine from the generated LLVM IR with `MLIR.ExecutionEngine.create!` and run the native function.\n\nThese three steps are corespondent to what makes a compiler\n\n* IR\n* Pass\n* CodeGen\n\nIn next tutorial we are taking a more programmable approach to generate the IR, converting Elixir AST to MLIR.\nBy doing it we will pick up concepts like region, block, operations appear here but didn't receive much attention for now.\nYou might want to look at the full list of MLIR dialects [here](https://mlir.llvm.org/docs/Dialects/).","title":"Recap - Your first compiler with Beaver!","ref":"your-first-beaver-compiler.html#recap"},{"type":"extras","doc":"# Contributing to Beaver\nThis document describes how to contribute to Beaver by introducing the idea behind how Beaver group its functionalities and how to set up the development environment.","title":"Contributing to Beaver","ref":"contributing.html"},{"type":"extras","doc":"There are three main parts in Beaver. Here is a brief introduction to each part:\n- DSL: The syntax of Beaver SSA expression.\n- Utilities: Work with MLIR in Elixir way.\n- Bindings: Thin wrapper of MLIR CAPI.","title":"Beaver's functionalities - Contributing to Beaver","ref":"contributing.html#beaver-s-functionalities"},{"type":"extras","doc":"Modules including `Beaver`, `Beaver.Env`.\n\nDSL is the core part of Beaver. It uses Elixir's syntax to express MLIR semantics.","title":"DSL - Contributing to Beaver","ref":"contributing.html#dsl"},{"type":"extras","doc":"Modules including `Beaver.Walker`, `Beaver.Composer`\n\nUtilities are the helper functions that help to generate or manipulate MLIR IR. They are implemented in Elixir and is designed to be used in the DSL part to further enhance it and improve ergonomics.","title":"Utilities - Contributing to Beaver","ref":"contributing.html#utilities"},{"type":"extras","doc":"Modules including `Beaver.MLIR`, `Beaver.MLIR.Dialect`, `Beaver.MLIR.Pass`, `Beaver.MLIR.Transform`, `Beaver.MLIR.ExecutionEngine`\n\nBindings are the part that provides the interface to the MLIR CAPIs. It is implemented in Zig and is responsible for calling MLIR functions. Note that Beaver's bindings will try not to use `TableGen` and instead try to make use Elixir and Zig's meta-programming features to generate the bindings.","title":"Bindings - Contributing to Beaver","ref":"contributing.html#bindings"},{"type":"extras","doc":"1. Install Elixir, [see installation guide](https://elixir-lang.org/install.html)\n2. Install Zig, [see installation guide](https://ziglang.org/learn/getting-started/#installing-zig)\n3. Install LLVM/MLIR\n\n- Option 1: Install with pip\n\n  ```bash\n  python3 -m pip install -r dev-requirements.txt\n  export LLVM_CONFIG_PATH=$(python3 -c 'import mlir;print(mlir.__path__[0])')/bin/llvm-config\n  ```\n\n- Option 2: Build from source https://mlir.llvm.org/getting_started/\n  Recommended install commands:\n\n  ```bash\n  cmake -B build -S llvm -G Ninja -DLLVM_ENABLE_PROJECTS=mlir \\\n    -DLLVM_TARGETS_TO_BUILD=\"host\" \\\n    -DCMAKE_C_COMPILER_LAUNCHER=ccache -DCMAKE_CXX_COMPILER_LAUNCHER=ccache \\\n    -DLLVM_ENABLE_ASSERTIONS=ON \\\n    -DLLVM_ENABLE_OCAMLDOC=OFF \\\n    -DLLVM_ENABLE_BINDINGS=OFF \\\n    -DCMAKE_BUILD_TYPE=RelWithDebInfo \\\n    -DCMAKE_INSTALL_PREFIX=${HOME}/llvm-install\n  cmake --build build -t install\n  export LLVM_CONFIG_PATH=$HOME/llvm-install/bin/llvm-config\n  ```\n\n  (Optional) To use Vulkan:\n\n  - Install Vulkan SDK (global installation is required), reference: https://vulkan.lunarg.com/sdk/home\n  - Setting environment variable by adding commands these to your bash/zsh profile:\n\n    ```bash\n    # you might need to change the version here\n    cd $HOME/VulkanSDK/1.3.216.0/\n    source setup-env.sh\n    cd -\n    ```\n\n  - Use `vulkaninfo` and `vkvia` to verify Vulkan is working\n  - Add `-DMLIR_ENABLE_VULKAN_RUNNER=ON` in LLVM CMake config command\n\n4. Develop and run tests\n- Clone this repo and `kinda` in the same directory\n  ```bash\n  git clone https://github.com/beaver-lodge/beaver.git\n  git clone https://github.com/beaver-lodge/kinda.git\n  ```\n- Make sure LLVM environment variable is set properly, as otherwise it might fail to build\n\n  ```bash\n  echo $LLVM_CONFIG_PATH\n  ```\n\n- Build and run Elixir tests\n  ```bash\n  mix deps.get\n  BEAVER_BUILD_CMAKE=1 mix test\n  # run tests with filters\n  mix test --exclude vulkan # use this to skip vulkan tests\n  mix test --only smoke\n  mix test --only nx\n  ```\n\n5. debug\n\n- setting environment variable to control Erlang scheduler number, `ERL_AFLAGS=\"+S 10:5\"`\n- run mix test under LLDB, `scripts/lldb-mix-test`","title":"Development - Contributing to Beaver","ref":"contributing.html#development"},{"type":"extras","doc":"","title":"Release a new version - Contributing to Beaver","ref":"contributing.html#release-a-new-version"},{"type":"extras","doc":"- Bump versions in [`README.md`](README.md) and [`mix.exs`](/mix.exs)","title":"Update Elixir source - Contributing to Beaver","ref":"contributing.html#update-elixir-source"},{"type":"extras","doc":"- Run CI, which generates the new GitHub release uploaded to https://github.com/beaver-lodge/beaver-prebuilt/releases.\n- Update release url in [`mix.exs`](/mix.exs)\n- Run docker image to build for ARM:\n  ```bash\n  docker run -it --rm -v $PWD/..:/src -w /src/beaver --env MIX_BUILD_ROOT='_build/arm' jackalcooper/beaver-livebook-arm64:latest bash scripts/build-for-publish.sh\n  ```","title":"Linux - Contributing to Beaver","ref":"contributing.html#linux"},{"type":"extras","doc":"- Run macOS build with:\n\n  ```bash\n  rm -rf _build/prod\n  bash scripts/build-for-publish.sh\n  ```\n\n- Upload the `beaver-nif-[xxx].tar.gz` file to release","title":"Mac - Contributing to Beaver","ref":"contributing.html#mac"},{"type":"extras","doc":"```\nrm checksum.exs\nmix clean\nmix\nmix elixir_make.checksum --all --ignore-unavailable --print\n```\n\nCheck the version in the output is correct.","title":"Generate `checksum.exs` - Contributing to Beaver","ref":"contributing.html#generate-checksum-exs"},{"type":"extras","doc":"```\nBEAVER_BUILD_CMAKE=1 mix hex.publish\n```","title":"Publish to Hex - Contributing to Beaver","ref":"contributing.html#publish-to-hex"},{"type":"extras","doc":"```bash\npython3 -m pip install cmake-format\ncmake-format -i native/**/CMakeLists.txt native/**/*.cmake\n```","title":"Format CMake files - Contributing to Beaver","ref":"contributing.html#format-cmake-files"},{"type":"extras","doc":"[![Run in Livebook](https://livebook.dev/badge/v1/black.svg)](https://livebook.dev/run?url=https%3A%2F%2Fhexdocs.pm%2Fbeaver%2Fyour-first-beaver-compiler.livemd)\n\n# Beaver 🦫\n\n[![Package](https://img.shields.io/badge/-Package-important)](https://hex.pm/packages/beaver) [![Documentation](https://img.shields.io/badge/-Documentation-blueviolet)](https://hexdocs.pm/beaver)\n[![Check Upstream](https://github.com/beaver-lodge/beaver/actions/workflows/upstream.yml/badge.svg)](https://github.com/beaver-lodge/beaver/actions/workflows/upstream.yml)\n\n**Boost the almighty blue-silver dragon with some magical elixir!** 🧙🧙‍♀️🧙‍♂️","title":"README","ref":"readme.html"},{"type":"extras","doc":"In the de-facto way of using MLIR, we need to work with C/C++, TableGen, CMake and Python (in most of cases). Each language or tool here has some functionalities and convenience we want to leverage. There is nothing wrong choosing the most popular and upstream-supported solution, but having alternative ways to build MLIR-based projects is still valuable or at least worth trying.\n\nElixir could actually be a good fit as a MLIR front end. Elixir has SSA, pattern-matching, pipe-operator. We can use these language features to define MLIR patterns and pass pipeline in a natural and uniformed way. Elixir is strong-typed but not static-typed which makes it a great choice for quickly building prototypes to validate and explore new ideas.\n\nTo build a piece of IR in Beaver:\n\n```elixir\nFunc.func some_func(function_type: Type.function([], [Type.i(32)])) do\n  region do\n    block _() do\n      v0 = Arith.constant(value: Attribute.integer(Type.i(32), 0)) >>> Type.i(32)\n      cond0 = Arith.constant(true) >>> Type.i(1)\n      CF.cond_br(cond0, Beaver.Env.block(bb1), {Beaver.Env.block(bb2), [v0]}) >>> []\n    end\n\n    block bb1() do\n      v1 = Arith.constant(value: Attribute.integer(Type.i(32), 0)) >>> Type.i(32)\n      _add = Arith.addi(v0, v0) >>> Type.i(32)\n      CF.br({Beaver.Env.block(bb2), [v1]}) >>> []\n    end\n\n    block bb2(arg >>> Type.i(32)) do\n      v2 = Arith.constant(value: Attribute.integer(Type.i(32), 0)) >>> Type.i(32)\n      add = Arith.addi(arg, v2) >>> Type.i(32)\n      Func.return(add) >>> []\n    end\n  end\nend\n```\n\nAnd a small example to showcase what it is like to define and run a pass in Beaver (with some monad magic):\n\n```elixir\ndefmodule ToyPass do\n  @moduledoc false\n  use Beaver\n  alias MLIR.Dialect.{Func, TOSA}\n  require Func\n  import Beaver.Pattern\n  use MLIR.Pass, on: \"builtin.module\"\n\n  defpat replace_add_op() do\n    a = value()\n    b = value()\n    res = type()\n    {op, _t} = TOSA.add(a, b) >>> {:op, [res]}\n\n    rewrite op do\n      {r, _} = TOSA.sub(a, b) >>> {:op, [res]}\n      replace(op, with: r)\n    end\n  end\n\n  def run(%MLIR.Operation{} = operation, _state) do\n    with 1 <- Beaver.Walker.regions(operation) |> Enum.count(),\n         {:ok, _} <-\n           MLIR.apply_(MLIR.Module.from_operation(operation), [replace_add_op(benefit: 2)]) do\n      :ok\n    else\n      _ -> raise \"unreachable\"\n    end\n  end\nend\n\nuse Beaver\nimport MLIR.Transform\nctx = MLIR.Context.create()\n~m\"\"\"\nmodule {\n  func.func @tosa_add(%arg0: tensor<1x3xf32>, %arg1: tensor<2x1xf32>) -> tensor<2x3xf32> {\n    %0 = \"tosa.add\"(%arg0, %arg1) : (tensor<1x3xf32>, tensor<2x1xf32>) -> tensor<2x3xf32>\n    return %0 : tensor<2x3xf32>\n  }\n}\n\"\"\".(ctx)\n|> Beaver.Composer.append(ToyPass)\n|> canonicalize\n|> Beaver.Composer.run!()\n```","title":"Motivation - README","ref":"readme.html#motivation"},{"type":"extras","doc":"- Powered by Elixir's composable modularity and meta-programming features, provide a simple, intuitive, and extensible interface for MLIR.\n- Edit-Build-Test-Debug Loop at seconds. Everything in Elixir and Zig are compiled in parallel.\n- Compile Elixir to native/WASM/GPU with the help from MLIR.\n- Revisit and reincarnate symbolic AI in the HW-accelerated world. Erlang/Elixir has [a Prolog root](https://www.erlang.org/blog/beam-compiler-history/#the-prolog-interpreter)!\n- Introduce a new stack to machine learning.\n  - Higher-level: Elixir\n  - Representation: MLIR\n  - Lower-level: Zig","title":"Goals - README","ref":"readme.html#goals"},{"type":"extras","doc":"Beaver is an umbrella species increase biodiversity. We hope this project could enable other compilers and applications in the way a beaver pond becomes the habitat of many other creatures. Many Elixir projects also use animal names as their package names and it is often about raising awareness of endangered species. To read more about why beavers are important to our planet, check out [this National Geographic article](https://www.nationalgeographic.com/animals/article/beavers-climate-change-conservation-news).","title":"Why is it called Beaver? - README","ref":"readme.html#why-is-it-called-beaver"},{"type":"extras","doc":"Beaver is essentially LLVM/MLIR on Erlang/Elixir. It is kind of interesting to see a crossover of two well established communities and four sub-communities. Here are some brief information about each of them.","title":"Quick introduction - README","ref":"readme.html#quick-introduction"},{"type":"extras","doc":"- Explain this MLIR thing to me in one sentence\n\n  MLIR could be regarded as the XML for compilers and an MLIR dialect acts like HTTP standard which gives the generic format real-world semantics and functionalities.\n\n- Check out [the home page](https://mlir.llvm.org/) of MLIR.","title":"For Erlang/Elixir forks - README","ref":"readme.html#for-erlang-elixir-forks"},{"type":"extras","doc":"- What's so good about this programming language Elixir?\n\n  - It gets compiled to Erlang and runs on BEAM (Erlang's VM). So it has all the fault-tolerance and concurrency features of Erlang.\n  - As a Lisp, Elixir has all the good stuff of a Lisp-y language including hygienic macro, protocol-based polymorphism.\n  - Elixir has a powerful [module system](https://elixir-lang.org/getting-started/module-attributes.html) to persist compile-time data and this allows library users to easily adjust runtime behavior.\n  - Minimum, very few keywords. Most of the language is built with itself.\n\n<!-- TODO: some rephrase -->\n\n- Check out [the official guide](https://elixir-lang.org/getting-started/introduction.html) of Elixir.","title":"For LLVM/MLIR forks - README","ref":"readme.html#for-llvm-mlir-forks"},{"type":"extras","doc":"- Tutorial: [Your first compiler with Beaver!](https://hexdocs.pm/beaver/your-first-beaver-compiler.html)\n\n<!-- TODO: single .exs example -->","title":"Getting started - README","ref":"readme.html#getting-started"},{"type":"extras","doc":"The package can be installed\nby adding `beaver` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:beaver, \"~> 0.4.0\"}\n  ]\nend\n```\n\nAdd this to your `.formatter.exs` will have the formatter properly transform the macros introduced by `beaver`\n```elixir\nimport_deps: [:beaver],\n```","title":"Installation - README","ref":"readme.html#installation"},{"type":"extras","doc":"- [Charm](https://github.com/beaver-lodge/charms): Compile a subset of Elixir to native targets.\n- [MLIR Accelerated Nx](https://github.com/beaver-lodge/manx): A backend for [Nx](https://github.com/elixir-nx/nx/).","title":"Projects built on top of Beaver - README","ref":"readme.html#projects-built-on-top-of-beaver"},{"type":"extras","doc":"To implement a MLIR toolkit, we at least need these group of APIs:\n\n- IR API, to create and update Ops and blocks in the IR\n- Pass API, to create and run passes\n- Pattern API, in which you declare the transformation of a specific structure of Ops\n\nWe implement the IR API and Pass API with the help of the [MLIR C API](https://mlir.llvm.org/docs/CAPI/). There are both lower level APIs generated from the C headers and higher level APIs that are more idiomatic in Elixir.\nThe Pattern API is implemented with the help from the [PDL dialect](https://mlir.llvm.org/docs/Dialects/PDLOps/). We are using the lower level IR APIs to compile your Elixir code to PDL. Another way to look at this is that Elixir/Erlang pattern matching is serving as a frontend alternative to [PDLL](https://mlir.llvm.org/docs/PDLL/).","title":"How it works? - README","ref":"readme.html#how-it-works"},{"type":"extras","doc":"","title":"Design principles - README","ref":"readme.html#design-principles"},{"type":"extras","doc":"It is very common to use builder pattern to construct IR, especially in an OO programming language like C++/Python.\nOne problem this approach has is that the compiler code looks very different from the code it is generating.\nBecause Erlang/Elixir is SSA by its nature, in Beaver a MLIR Op's creation is very declarative and its container will transform it with the correct contextual information. By doing this, we could:\n\n- Keep compiler code's structure as close as possible to the generated code, with less noise and more readability.\n- Allow dialects of different targets and semantic to introduce different DSL. For instance, CPU, SIMD, GPU could all have their specialized transformation tailored for their own unique concepts.\n\nOne example:\n\n```elixir\nmodule do\n  v2 = Arith.constant(1) >>> ~t \nend\n# module/1 is a macro, it will transformed the SSA `v2= Arith.constant..` to:\nv2 =\n %Beaver.SSA{}\n  |> Beaver.SSA.put_arguments(value: ~a{1})\n  |> Beaver.SSA.put_block(Beaver.Env.block())\n  |> Beaver.SSA.put_ctx(Beaver.Env.context())\n  |> Beaver.SSA.put_results(~t )\n  |> Arith.constant()\n```\n\nAlso, using the declarative way to construct IR, proper dominance and operand reference is formed naturally.\n\n<!-- TODO: use real code here -->\n\n```elixir\nSomeDialect.some_op do\n  region do\n    block entry() do\n      x = Arith.constant(1) >>> ~t \n      y = Arith.constant(1) >>> ~t \n    end\n  end\n  region do\n    block entry() do\n      z = Arith.addi(x, y) >>> ~t \n    end\n  end\nend\n\n# will be transformed to:\n\nSomeDialect.some_op(\n  regions: fn -> do\n    region = Beaver.Env.region() # first region created\n    block = Beaver.Env.block()\n    x = Arith.constant(...)\n    y = Arith.constant(...)\n\n    region = Beaver.Env.region() # second region created\n    block = Beaver.Env.block()\n    z = Arith.addi([x, y, ...]) # x and y dominate z\n  end\n)\n```","title":"Transformation over builder - README","ref":"readme.html#transformation-over-builder"},{"type":"extras","doc":"There should be a 1:1 mapping between Beaver SSA DSL to MLIR SSA. It is possible to do a roundtrip parsing MLIR text format and dump it to Beaver DSL which is Elixir AST essentially. This makes it possible to easily debug a piece of IR in a more programmable and readable way.\n\nIn Beaver, working with MLIR should be in one format, no matter it is generating, transforming, debugging.","title":"Beaver DSL as higher level AST for MLIR - README","ref":"readme.html#beaver-dsl-as-higher-level-ast-for-mlir"},{"type":"extras","doc":"When possible, lower level C APIs should be wrapped as Elixir struct with support to common Elixir protocols.\nFor instance the iteration over one MLIR operation's operands, results, successors, attributes, regions should be implemented in Elixir's Enumerable protocol.\nThis enable the possibility to use the rich collection of functions in Elixir standard libraries and Hex packages.","title":"High level API in Erlang/Elixir idiom - README","ref":"readme.html#high-level-api-in-erlang-elixir-idiom"},{"type":"extras","doc":"Elixir is a programming language built for all purposes. There are multiple sub-ecosystems in the general Erlang/Elixir ecosystem.\nEach sub-ecosystem appears distinct/unrelated to each other, but they actually complement each other in the real world production.\nTo name a few:\n\n- [Phoenix Framework](https://phoenixframework.org/) for web application and realtime message\n- [Nerves Project](https://www.nerves-project.org/) for embedded device and IoT\n- [Nx](https://github.com/elixir-nx/nx) for tensor and numerical\n\nEach of these sub-ecosystems starts with a seed project/library. Beaver should evolve to become a sub-ecosystem for compilers built with Elixir and MLIR.","title":"Is Beaver a compiler or binding to LLVM/MLIR? - README","ref":"readme.html#is-beaver-a-compiler-or-binding-to-llvm-mlir"},{"type":"extras","doc":"When calling higher-level APIs, it is ideal not to have MLIR context passing around everywhere.\nIf no MLIR context provided, an attribute and type getter should return an anonymous function with MLIR context as argument.\nIn Erlang, all values are copied, so it is very safe to pass around these anonymous functions.\nWhen creating an operation, these functions will be called with the MLIR context in an operation state.\nWith this approach we achieve both succinctness and modularity, not having a global MLIR context.\nUsually a function accepting a MLIR context to create an operation or type is called a \"creator\" in Beaver.","title":"MLIR context management - README","ref":"readme.html#mlir-context-management"},{"type":"extras","doc":"Please refer to [Beaver's contributing guide](/CONTRIBUTING.md)","title":"Development - README","ref":"readme.html#development"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}